@@ -18,7 +18,7 @@ email                : tim@linfiniti.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/*  $Id: plugin.cpp,v 1.22.2.1 2004/12/03 17:17:25 gsherman Exp $ */
+/*  $Id: plugin.cpp,v 1.28.2.2 2005/10/10 21:27:35 timlinux Exp $ */
 
 // includes
 
@@ -60,7 +60,7 @@ email                : tim@linfiniti.com
 #define QGISEXTERN extern "C"
 #endif
 
-static const char * const ident_ = "$Id: plugin.cpp,v 1.22.2.1 2004/12/03 17:17:25 gsherman Exp $";
+static const char * const ident_ = "$Id: plugin.cpp,v 1.28.2.2 2005/10/10 21:27:35 timlinux Exp $";
 
 static const char * const name_ = "CopyrightLabel";
 static const char * const description_ = "This plugin overlays copyright information on the rendered map.";
@@ -74,31 +74,29 @@ static const QgisPlugin::PLUGINTYPE type_ = QgisPlugin::UI;
  * @param qgis Pointer to the QGIS main window
  * @param _qI Pointer to the QGIS interface object
  */
-Plugin::Plugin(QgisApp * theQGisApp, QgisIface * theQgisInterFace):
+QgsCopyrightLabelPlugin::QgsCopyrightLabelPlugin(QgisApp * theQGisApp, 
+						 QgisIface * theQgisInterFace):
         qgisMainWindowPointer(theQGisApp),
         qGisInterface(theQgisInterFace),
         QgisPlugin(name_,description_,version_,type_)
 {}
 
-Plugin::~Plugin()
+QgsCopyrightLabelPlugin::~QgsCopyrightLabelPlugin()
 {}
 
 /*
  * Initialize the GUI interface for the plugin
  */
-void Plugin::initGui()
+void QgsCopyrightLabelPlugin::initGui()
 {
-    // add a menu with 2 items
-    QPopupMenu *pluginMenu = new QPopupMenu(qgisMainWindowPointer);
+    QPopupMenu *pluginMenu = qGisInterface->getPluginMenu(tr("&Decorations"));
+    menuId = pluginMenu->insertItem(QIconSet(icon),tr("&CopyrightLabel"), this, SLOT(run()));
 
-    int menuId = pluginMenu->insertItem(QIconSet(icon),"&CopyrightLabel", this, SLOT(run()));
-    pluginMenu->setWhatsThis(menuId, "Creates a copyright label that is displayed on the map canvas.");
-    menuBarPointer = ((QMainWindow *) qgisMainWindowPointer)->menuBar();
+    pluginMenu->setWhatsThis(menuId, tr("Creates a copyright label that is displayed on the map canvas."));
 
-    menuIdInt = qGisInterface->addMenu("&Decorations", pluginMenu);
     // Create the action for tool
-    myQActionPointer = new QAction("Copyright Label", QIconSet(icon), "&Wmi",0, this, "run");
-    myQActionPointer->setWhatsThis("Creates a copyright label that is displayed on the map canvas.");
+    myQActionPointer = new QAction(tr("Copyright Label"), QIconSet(icon), "&Wmi",0, this, tr("run"));
+    myQActionPointer->setWhatsThis(tr("Creates a copyright label that is displayed on the map canvas."));
     // Connect the action to the run
     connect(myQActionPointer, SIGNAL(activated()), this, SLOT(run()));
     // This calls the renderer everytime the cnavas has drawn itself
@@ -112,7 +110,7 @@ void Plugin::initGui()
     projectRead();
 }
 
-void Plugin::projectRead()
+void QgsCopyrightLabelPlugin::projectRead()
 {
 #ifdef QGISDEBUG
     std::cout << "+++++++++ Copyright plugin - project read slot called...." << std::endl;
@@ -122,23 +120,21 @@ void Plugin::projectRead()
     mQFont.setFamily(QgsProject::instance()->readEntry("CopyrightLabel","/FontName","Arial"));
     mQFont.setPointSize(QgsProject::instance()->readNumEntry("CopyrightLabel","/FontSize",14));
     mLabelQString = QgsProject::instance()->readEntry("CopyrightLabel","/Label","(c) QGIS 2004");
-    mPlacement = QgsProject::instance()->readEntry("CopyrightLabel","/Placement","Bottom Right");
+    mPlacement = QgsProject::instance()->readEntry("CopyrightLabel","/Placement",tr("Bottom Right"));
     mEnable = QgsProject::instance()->readBoolEntry("CopyrightLabel","/Enabled",true);
     // todo - read & store state of font color
     mLabelQColor = QColor(Qt::black);
-
-    refreshCanvas();
 }
 //method defined in interface
-void Plugin::help()
+void QgsCopyrightLabelPlugin::help()
 {
     //implement me!
 }
 
 // Slot called when the buffer menu item is activated
-void Plugin::run()
+void QgsCopyrightLabelPlugin::run()
 {
-    PluginGui *myPluginGui=new PluginGui(qgisMainWindowPointer,"Copyright Label",true,0);
+    QgsCopyrightLabelPluginGui *myPluginGui=new QgsCopyrightLabelPluginGui(qgisMainWindowPointer,tr("Copyright Label"),true,0);
     //listen for when the layer has been made so we can draw it
     //connect(myPluginGui, SIGNAL(drawRasterLayer(QString)), this, SLOT(drawRasterLayer(QString)));
     //connect(myPluginGui, SIGNAL(drawVectorLayer(QString,QString,QString)), this, SLOT(drawVectorLayer(QString,QString,QString)));
@@ -154,12 +150,12 @@ void Plugin::run()
     myPluginGui->show();
 }
 //! Refresh the map display using the mapcanvas exported via the plugin interface
-void Plugin::refreshCanvas()
+void QgsCopyrightLabelPlugin::refreshCanvas()
 {
     qGisInterface->getMapCanvas()->refresh();
 }
 
-void Plugin::renderLabel(QPainter * theQPainter)
+void QgsCopyrightLabelPlugin::renderLabel(QPainter * theQPainter)
 {
     //Large IF statement to enable/disable copyright label
     if (mEnable)
@@ -215,17 +211,22 @@ void Plugin::renderLabel(QPainter * theQPainter)
     }
 }
 // Unload the plugin by cleaning up the GUI
-void Plugin::unload()
+void QgsCopyrightLabelPlugin::unload()
 {
     // remove the GUI
-    menuBarPointer->removeItem(menuIdInt);
+    qGisInterface->removePluginMenuItem(tr("&Decorations"),menuId); 
     qGisInterface->removeToolBarIcon(myQActionPointer);
+    // remove the copyright from the canvas
+    disconnect(qGisInterface->getMapCanvas(), SIGNAL(renderComplete(QPainter *)),
+	       this, SLOT(renderLabel(QPainter *)));
+    refreshCanvas();
+
     delete myQActionPointer;
 }
 
 
 //! change the copyright font
-void Plugin::setFont(QFont theQFont)
+void QgsCopyrightLabelPlugin::setFont(QFont theQFont)
 {
     mQFont = theQFont;
     //save state to the project file.....
@@ -235,14 +236,14 @@ void Plugin::setFont(QFont theQFont)
     refreshCanvas();
 }
 //! change the copyright text
-void Plugin::setLabel(QString theLabelQString)
+void QgsCopyrightLabelPlugin::setLabel(QString theLabelQString)
 {
     mLabelQString = theLabelQString;
     QgsProject::instance()->writeEntry("CopyrightLabel","/Label", mLabelQString  );
     refreshCanvas();
 }
 //! change the copyright text colour
-void Plugin::setColor(QColor theQColor)
+void QgsCopyrightLabelPlugin::setColor(QColor theQColor)
 {
     mLabelQColor = theQColor;
     QgsProject::instance()->writeEntry("CopyrightLabel","/ColorRedPart", mLabelQColor.red());
@@ -252,7 +253,7 @@ void Plugin::setColor(QColor theQColor)
 }
 
 //! set placement of copyright label
-void Plugin::setPlacement(QString theQString)
+void QgsCopyrightLabelPlugin::setPlacement(QString theQString)
 {
     mPlacement = theQString;
     QgsProject::instance()->writeEntry("CopyrightLabel","/Placement", mPlacement);
@@ -260,7 +261,7 @@ void Plugin::setPlacement(QString theQString)
 }
 
 //! set whether copyright label is enabled
-void Plugin::setEnable(bool theBool)
+void QgsCopyrightLabelPlugin::setEnable(bool theBool)
 {
     mEnable = theBool;
     QgsProject::instance()->writeEntry("CopyrightLabel","/Enabled", mEnable );
@@ -279,7 +280,7 @@ void Plugin::setEnable(bool theBool)
 // Class factory to return a new instance of the plugin class
 QGISEXTERN QgisPlugin * classFactory(QgisApp * theQGisAppPointer, QgisIface * theQgisInterfacePointer)
 {
-    return new Plugin(theQGisAppPointer, theQgisInterfacePointer);
+    return new QgsCopyrightLabelPlugin(theQGisAppPointer, theQgisInterfacePointer);
 }
 
 // Return the name of the plugin - note that we do not user class members as
