@@ -16,9 +16,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: plugin.h,v 1.13 2004/11/21 00:45:07 timlinux Exp $ */
-#ifndef PLUGIN
-#define PLUGIN
+ /*  $Id: plugin.h,v 1.15 2005/04/27 05:21:14 g_j_m Exp $ */
+#ifndef QGSCOPYRIGHTLABELPLUGIN
+#define QGSCOPYRIGHTLABELPLUGIN
 #include "../qgisplugin.h"
 #include "../../src/qgisapp.h"
 #include <qwidget.h>
@@ -31,7 +31,7 @@
 * \brief OpenModeller plugin for QGIS
 *
 */
-class Plugin:public QObject, public QgisPlugin
+class QgsCopyrightLabelPlugin:public QObject, public QgisPlugin
 {
   Q_OBJECT public:
       /**
@@ -40,9 +40,9 @@ class Plugin:public QObject, public QgisPlugin
        * @param qgis Pointer to the QgisApp object
        * @param qI Pointer to the QgisIface object.
        */
-      Plugin(QgisApp * , QgisIface * );
+      QgsCopyrightLabelPlugin(QgisApp * , QgisIface * );
   //! Destructor
-  virtual ~ Plugin();
+  virtual ~ QgsCopyrightLabelPlugin();
   void writeEntry(QString theScope, QString theProperty, QVariant theValue);
   public slots:
   //! init the gui
@@ -85,9 +85,7 @@ class Plugin:public QObject, public QgisPlugin
 
   int pluginType;
   //! Id of the plugin's menu. Used for unloading
-  int menuIdInt;
-  //! Pointer to our menu
-  QMenuBar *menuBarPointer;
+  int menuId;
   //! Pionter to QGIS main application object
   QgisApp *qgisMainWindowPointer;
   //! Pointer to the QGIS interface object
