@@ -1,8 +1,8 @@
 /****************************************************************************
-** Plugin meta object code from reading C++ file 'plugin.h'
+** QgsCopyrightLabelPlugin meta object code from reading C++ file 'plugin.h'
 **
-** Created: Tue Nov 30 19:35:19 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:26:23 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,32 +14,32 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
-const char *Plugin::className() const
+const char *QgsCopyrightLabelPlugin::className() const
 {
-    return "Plugin";
+    return "QgsCopyrightLabelPlugin";
 }
 
-QMetaObject *Plugin::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_Plugin( "Plugin", &Plugin::staticMetaObject );
+QMetaObject *QgsCopyrightLabelPlugin::metaObj = 0;
+static QMetaObjectCleanUp cleanUp_QgsCopyrightLabelPlugin( "QgsCopyrightLabelPlugin", &QgsCopyrightLabelPlugin::staticMetaObject );
 
 #ifndef QT_NO_TRANSLATION
-QString Plugin::tr( const char *s, const char *c )
+QString QgsCopyrightLabelPlugin::tr( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "Plugin", s, c, QApplication::DefaultCodec );
+	return qApp->translate( "QgsCopyrightLabelPlugin", s, c, QApplication::DefaultCodec );
     else
 	return QString::fromLatin1( s );
 }
 #ifndef QT_NO_TRANSLATION_UTF8
-QString Plugin::trUtf8( const char *s, const char *c )
+QString QgsCopyrightLabelPlugin::trUtf8( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "Plugin", s, c, QApplication::UnicodeUTF8 );
+	return qApp->translate( "QgsCopyrightLabelPlugin", s, c, QApplication::UnicodeUTF8 );
     else
 	return QString::fromUtf8( s );
 }
@@ -47,7 +47,7 @@ QString Plugin::trUtf8( const char *s, const char *c )
 
 #endif // QT_NO_TRANSLATION
 
-QMetaObject* Plugin::staticMetaObject()
+QMetaObject* QgsCopyrightLabelPlugin::staticMetaObject()
 {
     if ( metaObj )
 	return metaObj;
@@ -97,7 +97,7 @@ QMetaObject* Plugin::staticMetaObject()
 	{ "setEnable(bool)", &slot_11, QMetaData::Public }
     };
     metaObj = QMetaObject::new_metaobject(
-	"Plugin", parentObject,
+	"QgsCopyrightLabelPlugin", parentObject,
 	slot_tbl, 12,
 	0, 0,
 #ifndef QT_NO_PROPERTIES
@@ -105,20 +105,20 @@ QMetaObject* Plugin::staticMetaObject()
 	0, 0,
 #endif // QT_NO_PROPERTIES
 	0, 0 );
-    cleanUp_Plugin.setMetaObject( metaObj );
+    cleanUp_QgsCopyrightLabelPlugin.setMetaObject( metaObj );
     return metaObj;
 }
 
-void* Plugin::qt_cast( const char* clname )
+void* QgsCopyrightLabelPlugin::qt_cast( const char* clname )
 {
-    if ( !qstrcmp( clname, "Plugin" ) )
+    if ( !qstrcmp( clname, "QgsCopyrightLabelPlugin" ) )
 	return this;
     if ( !qstrcmp( clname, "QgisPlugin" ) )
 	return (QgisPlugin*)this;
     return QObject::qt_cast( clname );
 }
 
-bool Plugin::qt_invoke( int _id, QUObject* _o )
+bool QgsCopyrightLabelPlugin::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
     case 0: initGui(); break;
@@ -139,16 +139,16 @@ bool Plugin::qt_invoke( int _id, QUObject* _o )
     return TRUE;
 }
 
-bool Plugin::qt_emit( int _id, QUObject* _o )
+bool QgsCopyrightLabelPlugin::qt_emit( int _id, QUObject* _o )
 {
     return QObject::qt_emit(_id,_o);
 }
 #ifndef QT_NO_PROPERTIES
 
-bool Plugin::qt_property( int id, int f, QVariant* v)
+bool QgsCopyrightLabelPlugin::qt_property( int id, int f, QVariant* v)
 {
     return QObject::qt_property( id, f, v);
 }
 
-bool Plugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool QgsCopyrightLabelPlugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
 #endif // QT_NO_PROPERTIES
