@@ -1,8 +1,8 @@
 /****************************************************************************
-** PluginGui meta object code from reading C++ file 'plugingui.h'
+** QgsCopyrightLabelPluginGui meta object code from reading C++ file 'plugingui.h'
 **
-** Created: Tue Nov 30 19:35:19 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:26:23 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,32 +14,32 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
-const char *PluginGui::className() const
+const char *QgsCopyrightLabelPluginGui::className() const
 {
-    return "PluginGui";
+    return "QgsCopyrightLabelPluginGui";
 }
 
-QMetaObject *PluginGui::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_PluginGui( "PluginGui", &PluginGui::staticMetaObject );
+QMetaObject *QgsCopyrightLabelPluginGui::metaObj = 0;
+static QMetaObjectCleanUp cleanUp_QgsCopyrightLabelPluginGui( "QgsCopyrightLabelPluginGui", &QgsCopyrightLabelPluginGui::staticMetaObject );
 
 #ifndef QT_NO_TRANSLATION
-QString PluginGui::tr( const char *s, const char *c )
+QString QgsCopyrightLabelPluginGui::tr( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGui", s, c, QApplication::DefaultCodec );
+	return qApp->translate( "QgsCopyrightLabelPluginGui", s, c, QApplication::DefaultCodec );
     else
 	return QString::fromLatin1( s );
 }
 #ifndef QT_NO_TRANSLATION_UTF8
-QString PluginGui::trUtf8( const char *s, const char *c )
+QString QgsCopyrightLabelPluginGui::trUtf8( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGui", s, c, QApplication::UnicodeUTF8 );
+	return qApp->translate( "QgsCopyrightLabelPluginGui", s, c, QApplication::UnicodeUTF8 );
     else
 	return QString::fromUtf8( s );
 }
@@ -47,11 +47,11 @@ QString PluginGui::trUtf8( const char *s, const char *c )
 
 #endif // QT_NO_TRANSLATION
 
-QMetaObject* PluginGui::staticMetaObject()
+QMetaObject* QgsCopyrightLabelPluginGui::staticMetaObject()
 {
     if ( metaObj )
 	return metaObj;
-    QMetaObject* parentObject = PluginGuiBase::staticMetaObject();
+    QMetaObject* parentObject = QgsCopyrightLabelPluginGuiBase::staticMetaObject();
     static const QUParameter param_slot_0[] = {
 	{ 0, &static_QUType_bool, 0, QUParameter::In }
     };
@@ -87,7 +87,7 @@ QMetaObject* PluginGui::staticMetaObject()
 	{ "enableCopyrightLabel(bool)", &signal_4, QMetaData::Private }
     };
     metaObj = QMetaObject::new_metaobject(
-	"PluginGui", parentObject,
+	"QgsCopyrightLabelPluginGui", parentObject,
 	slot_tbl, 1,
 	signal_tbl, 5,
 #ifndef QT_NO_PROPERTIES
@@ -95,22 +95,22 @@ QMetaObject* PluginGui::staticMetaObject()
 	0, 0,
 #endif // QT_NO_PROPERTIES
 	0, 0 );
-    cleanUp_PluginGui.setMetaObject( metaObj );
+    cleanUp_QgsCopyrightLabelPluginGui.setMetaObject( metaObj );
     return metaObj;
 }
 
-void* PluginGui::qt_cast( const char* clname )
+void* QgsCopyrightLabelPluginGui::qt_cast( const char* clname )
 {
-    if ( !qstrcmp( clname, "PluginGui" ) )
+    if ( !qstrcmp( clname, "QgsCopyrightLabelPluginGui" ) )
 	return this;
-    return PluginGuiBase::qt_cast( clname );
+    return QgsCopyrightLabelPluginGuiBase::qt_cast( clname );
 }
 
 #include <qobjectdefs.h>
 #include <qsignalslotimp.h>
 
 // SIGNAL changeFont
-void PluginGui::changeFont( QFont t0 )
+void QgsCopyrightLabelPluginGui::changeFont( QFont t0 )
 {
     if ( signalsBlocked() )
 	return;
@@ -123,13 +123,13 @@ void PluginGui::changeFont( QFont t0 )
 }
 
 // SIGNAL changeLabel
-void PluginGui::changeLabel( QString t0 )
+void QgsCopyrightLabelPluginGui::changeLabel( QString t0 )
 {
     activate_signal( staticMetaObject()->signalOffset() + 1, t0 );
 }
 
 // SIGNAL changeColor
-void PluginGui::changeColor( QColor t0 )
+void QgsCopyrightLabelPluginGui::changeColor( QColor t0 )
 {
     if ( signalsBlocked() )
 	return;
@@ -142,28 +142,28 @@ void PluginGui::changeColor( QColor t0 )
 }
 
 // SIGNAL changePlacement
-void PluginGui::changePlacement( QString t0 )
+void QgsCopyrightLabelPluginGui::changePlacement( QString t0 )
 {
     activate_signal( staticMetaObject()->signalOffset() + 3, t0 );
 }
 
 // SIGNAL enableCopyrightLabel
-void PluginGui::enableCopyrightLabel( bool t0 )
+void QgsCopyrightLabelPluginGui::enableCopyrightLabel( bool t0 )
 {
     activate_signal_bool( staticMetaObject()->signalOffset() + 4, t0 );
 }
 
-bool PluginGui::qt_invoke( int _id, QUObject* _o )
+bool QgsCopyrightLabelPluginGui::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
     case 0: setEnabled((bool)static_QUType_bool.get(_o+1)); break;
     default:
-	return PluginGuiBase::qt_invoke( _id, _o );
+	return QgsCopyrightLabelPluginGuiBase::qt_invoke( _id, _o );
     }
     return TRUE;
 }
 
-bool PluginGui::qt_emit( int _id, QUObject* _o )
+bool QgsCopyrightLabelPluginGui::qt_emit( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->signalOffset() ) {
     case 0: changeFont((QFont)(*((QFont*)static_QUType_ptr.get(_o+1)))); break;
@@ -172,16 +172,16 @@ bool PluginGui::qt_emit( int _id, QUObject* _o )
     case 3: changePlacement((QString)static_QUType_QString.get(_o+1)); break;
     case 4: enableCopyrightLabel((bool)static_QUType_bool.get(_o+1)); break;
     default:
-	return PluginGuiBase::qt_emit(_id,_o);
+	return QgsCopyrightLabelPluginGuiBase::qt_emit(_id,_o);
     }
     return TRUE;
 }
 #ifndef QT_NO_PROPERTIES
 
-bool PluginGui::qt_property( int id, int f, QVariant* v)
+bool QgsCopyrightLabelPluginGui::qt_property( int id, int f, QVariant* v)
 {
-    return PluginGuiBase::qt_property( id, f, v);
+    return QgsCopyrightLabelPluginGuiBase::qt_property( id, f, v);
 }
 
-bool PluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool QgsCopyrightLabelPluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
 #endif // QT_NO_PROPERTIES
