@@ -16,7 +16,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: qgsdelimitedtextplugin.h,v 1.5 2004/11/12 13:55:15 timlinux Exp $ */
+ /*  $Id: qgsdelimitedtextplugin.h,v 1.6 2005/04/27 05:21:15 g_j_m Exp $ */
 #ifndef PLUGIN
 #define PLUGIN
 #include "../qgisplugin.h"
@@ -81,9 +81,7 @@ class QgsDelimitedTextPlugin:public QObject, public QgisPlugin
   //! Plugin type as defined in Plugin::PLUGINTYPE
   int pluginType;
   //! Id of the plugin's menu. Used for unloading
-  int menuIdInt;
-  //! Pointer to our menu
-  QMenuBar *menuBarPointer;
+  int menuId;
   //! Pionter to QGIS main application object
   QgisApp *qgisMainWindowPointer;
   //! Pointer to the QGIS interface object
