@@ -18,7 +18,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: qgspggeoprocessing.h,v 1.9 2004/11/13 03:21:55 gsherman Exp $ */
+ /*  $Id: qgspggeoprocessing.h,v 1.10 2005/04/27 05:21:15 g_j_m Exp $ */
 #ifndef QGISQgsPgGeoprocessing_H
 #define QGISQgsPgGeoprocessing_H
 #include "../qgisplugin.h"
@@ -79,8 +79,6 @@ class QgsPgGeoprocessing:public QObject, public QgisPlugin
   
     //! Id of the plugin's menu. Used for unloading
     int menuId;
-    //! Pointer to our menu
-    QMenuBar *menu;
     //! Pionter to QGIS main application object
     QgisApp *qgisMainWindow;
     //! Pointer to the QGIS interface object
