@@ -13,7 +13,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: qgsgrassplugin.h,v 1.6 2004/11/12 13:55:16 timlinux Exp $ */
+ /*  $Id: qgsgrassplugin.h,v 1.10 2005/05/09 19:19:56 g_j_m Exp $ */
 #ifndef QGSGRASSPLUGIN_H
 #define QGSGRASSPLUGIN_H
 #include "../qgisplugin.h"
@@ -22,6 +22,10 @@
 
 #include "../../src/qgisapp.h"
 
+#include <vector>
+
+class QgsGrassTools;
+
 /**
 * \class QgsGrassPlugin
 * \brief OpenModeller plugin for QGIS
@@ -77,10 +81,19 @@ public slots:
   void help();
   //! Display current region
   void displayRegion(QPainter *painter);
+  //! Switch region on/off
+  void switchRegion(bool on);
   //! Change region
   void changeRegion(void);
+  //! Post render
+  void postRender(QPainter *);
+  //! Open tools 
+  void openTools(void);
 
 private:
+  //! Check if given directory contains a GRASS installation
+  static bool isValidGrassBaseDir(QString const gisBase);
+  
   //! Name of the plugin
   QString pluginNameQString;
   //! Version
@@ -90,11 +103,9 @@ private:
   //! Plugin type as defined in QgisPlugin::PLUGINTYPE
   int pluginType;
   //! Id of the plugin's menu. Used for unloading
-  int menuIdInt;
+  std::vector<int> menuId;
   //! Pointer to our toolbar
   QToolBar *toolBarPointer;
-  //! Pointer to our menu
-  QMenuBar *menuBarPointer;
   //! Pionter to QGIS main application object
   QgisApp *qgisMainWindowPointer;
   //! Pointer to the QGIS interface object
@@ -106,6 +117,8 @@ private:
   QAction *mRegionAction;
   //! Region width
   QPen mRegionPen;
+  //! GRASS tools
+  QgsGrassTools *mTools;
 };
 
 #endif // QGSGRASSPLUGIN_H
