@@ -1,9 +1,12 @@
 #include "graticulecreator.h"
 #include <stdio.h>
+#include <cassert>
 #include <qtextstream.h>
 #include <iostream>
+#include <fstream>
 #include <qfileinfo.h>
 #include <qstringlist.h>
+#include <qgis.h>
 GraticuleCreator::GraticuleCreator(QString theOutputFileName, 
                                    double theXIntervalDouble, 
                                    double theYIntervalDouble,
@@ -15,23 +18,31 @@ GraticuleCreator::GraticuleCreator(QString theOutputFileName,
 {
     std::cout << "GraticuleCreator constructor called with " << theOutputFileName
     << " for output file and " << theXIntervalDouble << "," << theYIntervalDouble << " for x,y interval " << std::endl;
-    DBFHandle myDbfHandle;		/* handle for dBase file */
-    SHPHandle myShapeHandle;		/* handle for shape files .shx and .shp */
+    DBFHandle myDbfHandle;    /* handle for dBase file */
+    SHPHandle myShapeHandle;    /* handle for shape files .shx and .shp */
     /* Open and prepare output files */
     myDbfHandle = createDbf(theOutputFileName);
     myShapeHandle = createShapeFile(theOutputFileName);
-    //test the write point routine....
-    //generatePoints(theInputFileName,myDbfHandle,myShapeHandle);
-    generateGraticule(myDbfHandle,
-                      myShapeHandle,
-                      theXIntervalDouble,
-                      theYIntervalDouble,
-                      theXOriginDouble,
-                      theYOriginDouble,
-                      theXEndPointDouble,
-                      theYEndPointDouble);
-    DBFClose( myDbfHandle );
-    SHPClose( myShapeHandle );
+    if (myDbfHandle && myShapeHandle)
+    {
+      writeProjectionFile(theOutputFileName);
+      //test the write point routine....
+      //generatePoints(theInputFileName,myDbfHandle,myShapeHandle);
+      generateGraticule(myDbfHandle,
+                        myShapeHandle,
+                        theXIntervalDouble,
+                        theYIntervalDouble,
+                        theXOriginDouble,
+                        theYOriginDouble,
+                        theXEndPointDouble,
+                       theYEndPointDouble);
+      DBFClose( myDbfHandle );
+      SHPClose( myShapeHandle );
+    }
+    else
+    {
+      std::cout << "Error creating the output files!" << std::endl;
+    }
     return;
 }
 
@@ -43,16 +54,19 @@ DBFHandle GraticuleCreator::createDbf (QString theDbfName )
     QFileInfo myFileInfo( theDbfName );
     QString myBaseString = myFileInfo.dirPath()+QString("/")+myFileInfo.baseName();  // excludes any extension
     //create the dbf
-    myDbfHandle = DBFCreate( myBaseString+".dbf" );
+    myDbfHandle = DBFCreate( (const char *)((myBaseString + ".dbf").local8Bit()) );
+    if (!myDbfHandle)
+    {
+            return NULL;
+    }
     //create an index field named after the base part of the file name
-
-    DBFAddField( myDbfHandle, myBaseString+"_id", FTInteger, 11, 0 );
+    DBFAddField( myDbfHandle,  (const char *)((myBaseString + "_id").local8Bit()), FTInteger, 11, 0 );
     //create a second arbitary attribute field
     DBFAddField( myDbfHandle, "Date", FTString, 12, 0 );
     //close the dbf
     DBFClose( myDbfHandle );
     //reopen
-    myDbfHandle = DBFOpen( myBaseString+".dbf", "r+b" );
+    myDbfHandle = DBFOpen( (const char *)((myBaseString + ".dbf").local8Bit()), "r+b" );
     //exit this fn giving
     return myDbfHandle;
 }
@@ -61,7 +75,7 @@ SHPHandle GraticuleCreator::createShapeFile(QString theFileName )
 {
     SHPHandle myShapeHandle;
     //myShapeHandle = SHPCreate(theFileName, SHPT_POINT );
-    myShapeHandle = SHPCreate(theFileName, SHPT_ARC );
+    myShapeHandle = SHPCreate( (const char *)(theFileName.local8Bit()), SHPT_ARC );
     return myShapeHandle;
 }
 
@@ -89,6 +103,19 @@ void GraticuleCreator::writeDbfRecord (DBFHandle theDbfHandle, int theRecordIdIn
     //DBFWriteStringAttribute(theDbfHandle, theRecordIdInt, 1, theLabel);
 }
 
+void  GraticuleCreator::writeProjectionFile(QString theFileName )
+{
+  // Write a WGS 84 projection file for the shapefile
+  theFileName = theFileName.replace(".shp",".prj");
+  std::ofstream of(theFileName);
+  if(!of.fail())
+  {
+    of << GEOWKT
+      << std::endl; 
+    of.close();
+
+  }
+}
 void GraticuleCreator::writePoint(SHPHandle theShapeHandle, int theRecordInt, double theXDouble, double theYDouble )
 {
     SHPObject * myShapeObject;
@@ -133,45 +160,63 @@ void GraticuleCreator::generateGraticule(DBFHandle theDbfHandle,
   //create the arrays for storing the coordinates
   double * myXArrayDouble;
   double * myYArrayDouble;
-  myXArrayDouble = (double *)malloc(2 * sizeof(double)); //2=no vertices
-  myYArrayDouble = (double *)malloc(2 * sizeof(double));
+  //we want out graticule to be made of short line segments rather tban
+  //long ones that imply span xmin <-> xmax
+  //so that when reprojecting the graticule will warp properly
+  //so first we need to work out how many intersections there are...
+  //
+  
+  long myXIntersectionCount = ((theXEndPointDouble - theXOriginDouble) / theXIntervalDouble)+1;
+  long myYIntersectionCount = ((theYEndPointDouble - theYOriginDouble) / theYIntervalDouble)+1;
+  
   
   //
   //Longitude loop
   //
+  myXArrayDouble = (double *)malloc(myYIntersectionCount * sizeof(double));
+  myYArrayDouble = (double *)malloc(myYIntersectionCount * sizeof(double));
   for (double myXDouble = theXOriginDouble;myXDouble <=theXEndPointDouble;myXDouble+=theXIntervalDouble)
   {
-    
-    myXArrayDouble[0]=myXDouble;
-    myXArrayDouble[1]=myXDouble;
-    myYArrayDouble[0]=theYOriginDouble;
-    myYArrayDouble[1]=theYEndPointDouble;
-
+    long myVertexNo=0;
+    for (double myYDouble=theYOriginDouble;myYDouble<=theYEndPointDouble;myYDouble+=theYIntervalDouble)
+    {
+      myXArrayDouble[myVertexNo]=myXDouble;
+      myYArrayDouble[myVertexNo]=myYDouble;
+      ++myVertexNo;
+    }
     writeDbfRecord(theDbfHandle,myRecordInt,"testing");
-    writeLine(theShapeHandle, myRecordInt, 2, myXArrayDouble, myYArrayDouble); //2=no vertices
-    
+    writeLine(theShapeHandle, myRecordInt, myYIntersectionCount, myXArrayDouble, myYArrayDouble); 
+
     ++myRecordInt;
   }
+  delete myXArrayDouble;
+  delete myYArrayDouble;
 
   //
   //Latitude loop
   //
+  myXArrayDouble = (double *)malloc(myXIntersectionCount * sizeof(double));
+  myYArrayDouble = (double *)malloc(myXIntersectionCount * sizeof(double));
   for (double myYDouble=theYOriginDouble;myYDouble<=theYEndPointDouble;myYDouble+=theYIntervalDouble)
   {
-    
-    myXArrayDouble[0]=theXOriginDouble;
-    myXArrayDouble[1]=theXEndPointDouble;
-    myYArrayDouble[0]=myYDouble;
-    myYArrayDouble[1]=myYDouble;
+    long myVertexNo=0;
+    for (double myXDouble=theXOriginDouble;myXDouble<=theXEndPointDouble;myXDouble+=theXIntervalDouble)
+    {
+      myXArrayDouble[myVertexNo]=myXDouble;
+      myYArrayDouble[myVertexNo]=myYDouble;
+      ++myVertexNo;
+    }
     
     writeDbfRecord(theDbfHandle,myRecordInt,"testing");
-    writeLine(theShapeHandle, myRecordInt, 2, myXArrayDouble, myYArrayDouble); //2=no vertices
+    writeLine(theShapeHandle, myRecordInt,myXIntersectionCount, myXArrayDouble, myYArrayDouble); 
 
     ++myRecordInt;
   }
   
   delete myXArrayDouble;
   delete myYArrayDouble;
+  // write a proj file for the graticule
+  
 }
 
 /* read from fp and generate point shapefile to theDbfHandle/theShapeHandle */
