@@ -13,12 +13,16 @@ int main(int argc, char *argv[])
 {
   QApplication a(argc, argv);
 
+#if defined(Q_OS_MACX) || defined(WIN32)
+  QString PKGDATAPATH = qApp->applicationDirPath() + "/share/qgis";
+#endif
+
   /* Load translationfile */
   QTranslator tor(0);
   tor.load(QString("qgis_") + QTextCodec::locale(), QString(PKGDATAPATH) + "/i18n");
   a.installTranslator(&tor);
   
-  PluginGui *myPluginGui=new PluginGui();
+  QgsGridMakerPluginGui *myPluginGui=new QgsGridMakerPluginGui();
   a.setMainWidget(myPluginGui);
   myPluginGui->show();
 
