@@ -16,9 +16,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: plugin.h,v 1.4 2004/11/12 13:55:17 timlinux Exp $ */
-#ifndef PLUGIN
-#define PLUGIN
+ /*  $Id: plugin.h,v 1.6 2005/04/27 05:21:16 g_j_m Exp $ */
+#ifndef QGSGRIDMAKERPLUGIN
+#define QGSGRIDMAKERPLUGIN
 #include "../qgisplugin.h"
 #include <qwidget.h>
 #include <qgisapp.h>
@@ -28,7 +28,7 @@
 * \brief OpenModeller plugin for QGIS
 *
 */
-class Plugin:public QObject, public QgisPlugin
+class QgsGridMakerPlugin:public QObject, public QgisPlugin
 {
   Q_OBJECT public:
       /** 
@@ -37,7 +37,7 @@ class Plugin:public QObject, public QgisPlugin
        * @param qgis Pointer to the QgisApp object
        * @param qI Pointer to the QgisIface object. 
        */
-      Plugin(QgisApp * , QgisIface * );
+    QgsGridMakerPlugin(QgisApp * , QgisIface * );
   /**
    * Virtual function to return the name of the plugin. The name will be used when presenting a list 
    * of installable plugins to the user
@@ -56,7 +56,7 @@ class Plugin:public QObject, public QgisPlugin
    */
   virtual int type();
   //! Destructor
-  virtual ~ Plugin();
+  virtual ~ QgsGridMakerPlugin();
   public slots:
   //! init the gui
   virtual void initGui();
@@ -82,9 +82,7 @@ class Plugin:public QObject, public QgisPlugin
   //! Plugin type as defined in QgisPlugin::PLUGINTYPE
   int pluginType;
   //! Id of the plugin's menu. Used for unloading
-  int menuIdInt;
-  //! Pointer to our menu
-  QMenuBar *menuBarPointer;
+  int menuId;
   //! Pionter to QGIS main application object
   QgisApp *qgisMainWindowPointer;
   //! Pointer to the QGIS interface object
