@@ -1,8 +1,8 @@
 /****************************************************************************
-** PluginGui meta object code from reading C++ file 'plugingui.h'
+** QgsGridMakerPluginGui meta object code from reading C++ file 'plugingui.h'
 **
-** Created: Tue Nov 30 19:34:56 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:25:40 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,32 +14,32 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
-const char *PluginGui::className() const
+const char *QgsGridMakerPluginGui::className() const
 {
-    return "PluginGui";
+    return "QgsGridMakerPluginGui";
 }
 
-QMetaObject *PluginGui::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_PluginGui( "PluginGui", &PluginGui::staticMetaObject );
+QMetaObject *QgsGridMakerPluginGui::metaObj = 0;
+static QMetaObjectCleanUp cleanUp_QgsGridMakerPluginGui( "QgsGridMakerPluginGui", &QgsGridMakerPluginGui::staticMetaObject );
 
 #ifndef QT_NO_TRANSLATION
-QString PluginGui::tr( const char *s, const char *c )
+QString QgsGridMakerPluginGui::tr( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGui", s, c, QApplication::DefaultCodec );
+	return qApp->translate( "QgsGridMakerPluginGui", s, c, QApplication::DefaultCodec );
     else
 	return QString::fromLatin1( s );
 }
 #ifndef QT_NO_TRANSLATION_UTF8
-QString PluginGui::trUtf8( const char *s, const char *c )
+QString QgsGridMakerPluginGui::trUtf8( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGui", s, c, QApplication::UnicodeUTF8 );
+	return qApp->translate( "QgsGridMakerPluginGui", s, c, QApplication::UnicodeUTF8 );
     else
 	return QString::fromUtf8( s );
 }
@@ -47,11 +47,11 @@ QString PluginGui::trUtf8( const char *s, const char *c )
 
 #endif // QT_NO_TRANSLATION
 
-QMetaObject* PluginGui::staticMetaObject()
+QMetaObject* QgsGridMakerPluginGui::staticMetaObject()
 {
     if ( metaObj )
 	return metaObj;
-    QMetaObject* parentObject = PluginGuiBase::staticMetaObject();
+    QMetaObject* parentObject = QgsGridMakerPluginGuiBase::staticMetaObject();
     static const QUParameter param_signal_0[] = {
 	{ 0, &static_QUType_QString, 0, QUParameter::In }
     };
@@ -67,7 +67,7 @@ QMetaObject* PluginGui::staticMetaObject()
 	{ "drawVectorLayer(QString,QString,QString)", &signal_1, QMetaData::Private }
     };
     metaObj = QMetaObject::new_metaobject(
-	"PluginGui", parentObject,
+	"QgsGridMakerPluginGui", parentObject,
 	0, 0,
 	signal_tbl, 2,
 #ifndef QT_NO_PROPERTIES
@@ -75,19 +75,19 @@ QMetaObject* PluginGui::staticMetaObject()
 	0, 0,
 #endif // QT_NO_PROPERTIES
 	0, 0 );
-    cleanUp_PluginGui.setMetaObject( metaObj );
+    cleanUp_QgsGridMakerPluginGui.setMetaObject( metaObj );
     return metaObj;
 }
 
-void* PluginGui::qt_cast( const char* clname )
+void* QgsGridMakerPluginGui::qt_cast( const char* clname )
 {
-    if ( !qstrcmp( clname, "PluginGui" ) )
+    if ( !qstrcmp( clname, "QgsGridMakerPluginGui" ) )
 	return this;
-    return PluginGuiBase::qt_cast( clname );
+    return QgsGridMakerPluginGuiBase::qt_cast( clname );
 }
 
 // SIGNAL drawRasterLayer
-void PluginGui::drawRasterLayer( QString t0 )
+void QgsGridMakerPluginGui::drawRasterLayer( QString t0 )
 {
     activate_signal( staticMetaObject()->signalOffset() + 0, t0 );
 }
@@ -96,7 +96,7 @@ void PluginGui::drawRasterLayer( QString t0 )
 #include <qsignalslotimp.h>
 
 // SIGNAL drawVectorLayer
-void PluginGui::drawVectorLayer( QString t0, QString t1, QString t2 )
+void QgsGridMakerPluginGui::drawVectorLayer( QString t0, QString t1, QString t2 )
 {
     if ( signalsBlocked() )
 	return;
@@ -110,27 +110,27 @@ void PluginGui::drawVectorLayer( QString t0, QString t1, QString t2 )
     activate_signal( clist, o );
 }
 
-bool PluginGui::qt_invoke( int _id, QUObject* _o )
+bool QgsGridMakerPluginGui::qt_invoke( int _id, QUObject* _o )
 {
-    return PluginGuiBase::qt_invoke(_id,_o);
+    return QgsGridMakerPluginGuiBase::qt_invoke(_id,_o);
 }
 
-bool PluginGui::qt_emit( int _id, QUObject* _o )
+bool QgsGridMakerPluginGui::qt_emit( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->signalOffset() ) {
     case 0: drawRasterLayer((QString)static_QUType_QString.get(_o+1)); break;
     case 1: drawVectorLayer((QString)static_QUType_QString.get(_o+1),(QString)static_QUType_QString.get(_o+2),(QString)static_QUType_QString.get(_o+3)); break;
     default:
-	return PluginGuiBase::qt_emit(_id,_o);
+	return QgsGridMakerPluginGuiBase::qt_emit(_id,_o);
     }
     return TRUE;
 }
 #ifndef QT_NO_PROPERTIES
 
-bool PluginGui::qt_property( int id, int f, QVariant* v)
+bool QgsGridMakerPluginGui::qt_property( int id, int f, QVariant* v)
 {
-    return PluginGuiBase::qt_property( id, f, v);
+    return QgsGridMakerPluginGuiBase::qt_property( id, f, v);
 }
 
-bool PluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool QgsGridMakerPluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
 #endif // QT_NO_PROPERTIES
