@@ -1,8 +1,8 @@
 /****************************************************************************
-** PluginGuiBase meta object code from reading C++ file 'pluginguibase.h'
+** QgsGridMakerPluginGuiBase meta object code from reading C++ file 'pluginguibase.h'
 **
-** Created: Tue Nov 30 19:34:56 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:25:40 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,32 +14,32 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
-const char *PluginGuiBase::className() const
+const char *QgsGridMakerPluginGuiBase::className() const
 {
-    return "PluginGuiBase";
+    return "QgsGridMakerPluginGuiBase";
 }
 
-QMetaObject *PluginGuiBase::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_PluginGuiBase( "PluginGuiBase", &PluginGuiBase::staticMetaObject );
+QMetaObject *QgsGridMakerPluginGuiBase::metaObj = 0;
+static QMetaObjectCleanUp cleanUp_QgsGridMakerPluginGuiBase( "QgsGridMakerPluginGuiBase", &QgsGridMakerPluginGuiBase::staticMetaObject );
 
 #ifndef QT_NO_TRANSLATION
-QString PluginGuiBase::tr( const char *s, const char *c )
+QString QgsGridMakerPluginGuiBase::tr( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGuiBase", s, c, QApplication::DefaultCodec );
+	return qApp->translate( "QgsGridMakerPluginGuiBase", s, c, QApplication::DefaultCodec );
     else
 	return QString::fromLatin1( s );
 }
 #ifndef QT_NO_TRANSLATION_UTF8
-QString PluginGuiBase::trUtf8( const char *s, const char *c )
+QString QgsGridMakerPluginGuiBase::trUtf8( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGuiBase", s, c, QApplication::UnicodeUTF8 );
+	return qApp->translate( "QgsGridMakerPluginGuiBase", s, c, QApplication::UnicodeUTF8 );
     else
 	return QString::fromUtf8( s );
 }
@@ -47,7 +47,7 @@ QString PluginGuiBase::trUtf8( const char *s, const char *c )
 
 #endif // QT_NO_TRANSLATION
 
-QMetaObject* PluginGuiBase::staticMetaObject()
+QMetaObject* QgsGridMakerPluginGuiBase::staticMetaObject()
 {
     if ( metaObj )
 	return metaObj;
@@ -75,7 +75,7 @@ QMetaObject* PluginGuiBase::staticMetaObject()
 	{ "languageChange()", &slot_6, QMetaData::Protected }
     };
     metaObj = QMetaObject::new_metaobject(
-	"PluginGuiBase", parentObject,
+	"QgsGridMakerPluginGuiBase", parentObject,
 	slot_tbl, 7,
 	0, 0,
 #ifndef QT_NO_PROPERTIES
@@ -83,18 +83,18 @@ QMetaObject* PluginGuiBase::staticMetaObject()
 	0, 0,
 #endif // QT_NO_PROPERTIES
 	0, 0 );
-    cleanUp_PluginGuiBase.setMetaObject( metaObj );
+    cleanUp_QgsGridMakerPluginGuiBase.setMetaObject( metaObj );
     return metaObj;
 }
 
-void* PluginGuiBase::qt_cast( const char* clname )
+void* QgsGridMakerPluginGuiBase::qt_cast( const char* clname )
 {
-    if ( !qstrcmp( clname, "PluginGuiBase" ) )
+    if ( !qstrcmp( clname, "QgsGridMakerPluginGuiBase" ) )
 	return this;
     return QDialog::qt_cast( clname );
 }
 
-bool PluginGuiBase::qt_invoke( int _id, QUObject* _o )
+bool QgsGridMakerPluginGuiBase::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
     case 0: pbnOK_clicked(); break;
@@ -110,16 +110,16 @@ bool PluginGuiBase::qt_invoke( int _id, QUObject* _o )
     return TRUE;
 }
 
-bool PluginGuiBase::qt_emit( int _id, QUObject* _o )
+bool QgsGridMakerPluginGuiBase::qt_emit( int _id, QUObject* _o )
 {
     return QDialog::qt_emit(_id,_o);
 }
 #ifndef QT_NO_PROPERTIES
 
-bool PluginGuiBase::qt_property( int id, int f, QVariant* v)
+bool QgsGridMakerPluginGuiBase::qt_property( int id, int f, QVariant* v)
 {
     return QDialog::qt_property( id, f, v);
 }
 
-bool PluginGuiBase::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool QgsGridMakerPluginGuiBase::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
 #endif // QT_NO_PROPERTIES
