@@ -18,7 +18,7 @@ email                : tim@linfiniti.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/*  $Id: plugin.cpp,v 1.24.2.1 2004/12/03 17:17:34 gsherman Exp $ */
+/*  $Id: plugin.cpp,v 1.30.2.13 2005/10/10 21:17:15 timlinux Exp $ */
 
 // includes
 
@@ -45,7 +45,8 @@ email                : tim@linfiniti.com
 
 //non qt includes
 #include <iostream>
-#include <math.h>
+#include <cmath>
+#include <cassert>
 
 //the gui subclass
 #include "plugingui.h"
@@ -60,13 +61,17 @@ email                : tim@linfiniti.com
 #endif
 
 //
-static const char * const ident_ = "$Id: plugin.cpp,v 1.24.2.1 2004/12/03 17:17:34 gsherman Exp $";
+static const char * const ident_ = "$Id: plugin.cpp,v 1.30.2.13 2005/10/10 21:17:15 timlinux Exp $";
 
 static const char * const name_ = "NorthArrow";
 static const char * const description_ = "This plugin displays a north arrow overlayed onto the map.";
 static const char * const version_ = "Version 0.1";
 static const QgisPlugin::PLUGINTYPE type_ = QgisPlugin::UI;
 
+const double QgsNorthArrowPlugin::PI = 3.14159265358979323846;
+//  const double QgsNorthArrowPlugin::DEG2RAD = 0.0174532925199433;
+const double QgsNorthArrowPlugin::TOL = 1e-8;
+
 
 /**
  * Constructor for the plugin. The plugin is passed a pointer to the main app
@@ -74,35 +79,33 @@ static const QgisPlugin::PLUGINTYPE type_ = QgisPlugin::UI;
  * @param qgis Pointer to the QGIS main window
  * @param _qI Pointer to the QGIS interface object
  */
-Plugin::Plugin(QgisApp * theQGisApp, QgisIface * theQgisInterFace):
+QgsNorthArrowPlugin::QgsNorthArrowPlugin(QgisApp * theQGisApp, QgisIface * theQgisInterFace):
     qgisMainWindowPointer(theQGisApp),
     qGisInterface(theQgisInterFace),
     QgisPlugin(name_,description_,version_,type_)
 {
   mRotationInt=0;
+  mAutomatic=true;
   mPlacement=tr("Bottom Left");
 }
 
-Plugin::~Plugin()
+QgsNorthArrowPlugin::~QgsNorthArrowPlugin()
 {
 }
 
-/*
+  /*
  * Initialize the GUI interface for the plugin
  */
-void Plugin::initGui()
+void QgsNorthArrowPlugin::initGui()
 {
-  // add a menu with 2 items
-  QPopupMenu *pluginMenu = new QPopupMenu(qgisMainWindowPointer);
+  QPopupMenu *pluginMenu = qGisInterface->getPluginMenu(tr("&Decorations"));
+  menuId = pluginMenu->insertItem(QIconSet(icon),tr("&NorthArrow"), this, SLOT(run()));
 
-  int menuId = pluginMenu->insertItem(QIconSet(icon),"&NorthArrow", this, SLOT(run()));
-  pluginMenu->setWhatsThis(menuId, "Creates a north arrow that is displayed on the map canvas");
-  menuBarPointer = ((QMainWindow *) qgisMainWindowPointer)->menuBar();
+  pluginMenu->setWhatsThis(menuId, tr("Creates a north arrow that is displayed on the map canvas"));
 
-  menuIdInt = qGisInterface->addMenu("&Decorations", pluginMenu);
   // Create the action for tool
-  myQActionPointer = new QAction("North Arrow", QIconSet(icon), "&Wmi",0, this, "run");
-  myQActionPointer->setWhatsThis("Creates a north arrow that is displayed on the map canvas");
+  myQActionPointer = new QAction(tr("North Arrow"), QIconSet(icon), "&Wmi",0, this, tr("run"));
+  myQActionPointer->setWhatsThis(tr("Creates a north arrow that is displayed on the map canvas"));
   // Connect the action to the run
   connect(myQActionPointer, SIGNAL(activated()), this, SLOT(run()));
   //render the arrow each time the map is rendered
@@ -116,7 +119,7 @@ void Plugin::initGui()
 
 }
 
-void Plugin::projectRead()
+void QgsNorthArrowPlugin::projectRead()
 {
 #ifdef QGISDEBUG
     std::cout << "+++++++++ north arrow plugin - project read slot called...." << std::endl;
@@ -124,40 +127,43 @@ void Plugin::projectRead()
     //default text to start with - try to fetch it from qgsproject
 
     mRotationInt = QgsProject::instance()->readNumEntry("NorthArrow","/Rotation",0);
-    mPlacement = QgsProject::instance()->readEntry("NorthArrow","/Placement","Bottom Left");
+    mPlacement = QgsProject::instance()->readEntry("NorthArrow","/Placement",tr("Bottom Left"));
     mEnable = QgsProject::instance()->readBoolEntry("NorthArrow","/Enabled",true);
-    refreshCanvas();
+    mAutomatic = QgsProject::instance()->readBoolEntry("NorthArrow","/Automatic",true);
 }
 
 //method defined in interface
-void Plugin::help()
+void QgsNorthArrowPlugin::help()
 {
   //implement me!
 }
 
 // Slot called when the buffer menu item is activated
-void Plugin::run()
+void QgsNorthArrowPlugin::run()
 {
-  PluginGui *myPluginGui=new PluginGui(qgisMainWindowPointer,"North Arrow",true,0);
+  QgsNorthArrowPluginGui *myPluginGui = new QgsNorthArrowPluginGui(qgisMainWindowPointer,tr("North Arrow"),true,0);
   //overides function byt the same name created in .ui
   myPluginGui->setRotation(mRotationInt);
   myPluginGui->setPlacement(mPlacement);
   myPluginGui->setEnabled(mEnable);
+  myPluginGui->setAutomatic(mAutomatic);
+
   //listen for when the layer has been made so we can draw it
   connect(myPluginGui, SIGNAL(rotationChanged(int)), this, SLOT(rotationChanged(int)));
   connect(myPluginGui, SIGNAL(changePlacement(QString)), this, SLOT(setPlacement(QString)));
+  connect(myPluginGui, SIGNAL(enableAutomatic(bool)), this, SLOT(setAutomatic(bool)));
   connect(myPluginGui, SIGNAL(enableNorthArrow(bool)), this, SLOT(setEnabled(bool)));
+  connect(myPluginGui, SIGNAL(needToRefresh()), this, SLOT(refreshCanvas()));
   myPluginGui->show();
-
 }
 
 //! Refresh the map display using the mapcanvas exported via the plugin interface
-void Plugin::refreshCanvas()
+void QgsNorthArrowPlugin::refreshCanvas()
 {
   qGisInterface->getMapCanvas()->refresh();
 }
 
-void Plugin::renderNorthArrow(QPainter * theQPainter)
+void QgsNorthArrowPlugin::renderNorthArrow(QPainter * theQPainter)
 {
 #ifdef QGISDEBUG
       std::cout << "Rendering n-arrow"  << std::endl;
@@ -184,8 +190,13 @@ void Plugin::renderNorthArrow(QPainter * theQPainter)
       //           properly about its center
       //(x cos a + y sin a - x, -x sin a + y cos a - y)
       //
-      const double PI = 3.14159265358979323846;
-      double myRadiansDouble = (PI/180) * mRotationInt;
+
+      // could move this call to somewhere else so that it is only
+      // called when the projection or map extent changes
+      if (mAutomatic)
+        calculateNorthDirection();
+
+      double myRadiansDouble = mRotationInt * PI / 180.0;
       int xShift = static_cast<int>((
                                       (centerXDouble * cos(myRadiansDouble)) +
                                       (centerYDouble * sin(myRadiansDouble))
@@ -238,43 +249,162 @@ void Plugin::renderNorthArrow(QPainter * theQPainter)
       QFont myQFont("time", 32, QFont::Bold);
       theQPainter->setFont(myQFont);
       theQPainter->setPen(Qt::black);
-      theQPainter->drawText(10, 20, QString("Pixmap Not Found"));
+      theQPainter->drawText(10, 20, QString(tr("Pixmap Not Found")));
     }
   }
 
 }
 // Unload the plugin by cleaning up the GUI
-void Plugin::unload()
+void QgsNorthArrowPlugin::unload()
 {
   // remove the GUI
-  menuBarPointer->removeItem(menuIdInt);
+  qGisInterface->removePluginMenuItem(tr("&Decorations"),menuId);
   qGisInterface->removeToolBarIcon(myQActionPointer);
+  // remove the northarrow from the canvas
+  disconnect(qGisInterface->getMapCanvas(), SIGNAL(renderComplete(QPainter *)),
+	     this, SLOT(renderNorthArrow(QPainter *)));
+  refreshCanvas();
+
   delete myQActionPointer;
 }
 
 
-void Plugin::rotationChanged(int theInt)
+void QgsNorthArrowPlugin::rotationChanged(int theInt)
 {
   mRotationInt = theInt;
   QgsProject::instance()->writeEntry("NorthArrow","/Rotation", mRotationInt  );
-  refreshCanvas();
 }
 
 //! set placement of north arrow
-void Plugin::setPlacement(QString theQString)
+void QgsNorthArrowPlugin::setPlacement(QString theQString)
 {
   mPlacement = theQString;
   QgsProject::instance()->writeEntry("NorthArrow","/Placement", mPlacement);
-  refreshCanvas();
 }
 
-void Plugin::setEnabled(bool theBool)
+void QgsNorthArrowPlugin::setEnabled(bool theBool)
 {
   mEnable = theBool;
   QgsProject::instance()->writeEntry("NorthArrow","/Enabled", mEnable );
-  refreshCanvas();
 }
 
+void QgsNorthArrowPlugin::setAutomatic(bool theBool)
+{
+  mAutomatic = theBool;
+  QgsProject::instance()->writeEntry("NorthArrow","/Automatic", mAutomatic );
+  if (mAutomatic)
+    calculateNorthDirection();
+}
+
+bool QgsNorthArrowPlugin::calculateNorthDirection()
+{
+  QgsMapCanvas& mapCanvas = *(qGisInterface->getMapCanvas());
+
+  bool goodDirn = false;
+
+  if (mapCanvas.layerCount() > 0)
+  {
+    // Grab an SRS from any layer
+    QgsMapLayer& mapLayer = *(mapCanvas.getZpos(0));
+    if (! mapLayer.coordinateTransform() )
+    {
+       return 0;
+    }
+    QgsSpatialRefSys& outputSRS = mapLayer.coordinateTransform()->destSRS();
+  
+    
+    
+    bool yy = outputSRS.geographicFlag();
+
+    if (outputSRS.isValid() && !outputSRS.geographicFlag())
+    {
+      // Use a geographic SRS to get lat/long to work out direction
+      QgsSpatialRefSys ourSRS;
+      ourSRS.createFromProj4("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
+      assert(ourSRS.isValid());
+
+      QgsCoordinateTransform transform(outputSRS, ourSRS);
+
+      QgsRect extent = mapCanvas.extent();
+      QgsPoint p1(extent.center());
+      // A point a bit above p1. XXX assumes that y increases up!!
+      // May need to involve the maptopixel transform if this proves
+      // to be a problem.
+      QgsPoint p2(p1.x(), p1.y() + extent.height() * 0.25); 
+
+      // project p1 and p2 to geographic coords
+      try
+      {        
+	p1 = transform.transform(p1);
+	p2 = transform.transform(p2);
+      }
+      catch (QgsException &e)
+      {
+	// just give up
+	return false;
+      }
+
+      // Work out the value of the initial heading one takes to go
+      // from point p1 to point p2. The north direction is then that
+      // many degrees anti-clockwise or vertical.
+
+      // Take some care to not divide by zero, etc, and ensure that we
+      // get sensible results for all possible values for p1 and p2.
+
+      goodDirn = true;
+      double angle = 0.0;
+
+      // convert to radians for the equations below
+      p1.multiply(PI/180.0);
+      p2.multiply(PI/180.0);
+
+      double y = sin(p2.x() - p1.x()) * cos(p2.y());
+      double x = cos(p1.y()) * sin(p2.y()) - 
+	         sin(p1.y()) * cos(p2.y()) * cos(p2.x()-p1.x());
+
+      if (y > 0.0)
+      {
+	if (x > TOL) 
+	  angle = atan(y/x);
+	else if (x < -TOL) 
+	  angle = PI - atan(-y/x);
+	else
+	  angle = 0.5 * PI;
+      }
+      else if (y < 0.0)
+      {
+	if (x > TOL)
+	  angle = -atan(-y/x);
+	else if (x < -TOL)
+	  angle = atan(y/x) - PI;
+	else
+	  angle = 1.5 * PI;
+      }
+      else
+      {
+	if (x > TOL)
+	  angle = 0.0;
+	else if (x < -TOL)
+	  angle = PI;
+	else
+        {
+	  angle = 0.0; // p1 = p2
+	  goodDirn = false;
+	}
+      }
+      // And set the angle of the north arrow. Perhaps do something
+      // different if goodDirn = false.
+      mRotationInt = static_cast<int>(floor(fmod(360.0-angle*180.0/PI, 360.0) +0.5));
+    }
+    else
+    {
+      // For geographic SRS and for when there are no layers, set the
+      // direction back to the default
+      mRotationInt = 0;
+    }
+  }
+  return goodDirn;
+}
 
 
 
@@ -288,7 +418,7 @@ void Plugin::setEnabled(bool theBool)
 // Class factory to return a new instance of the plugin class
 QGISEXTERN QgisPlugin * classFactory(QgisApp * theQGisAppPointer, QgisIface * theQgisInterfacePointer)
 {
-  return new Plugin(theQGisAppPointer, theQgisInterfacePointer);
+  return new QgsNorthArrowPlugin(theQGisAppPointer, theQgisInterfacePointer);
 }
 
 // Return the name of the plugin - note that we do not user class members as
