@@ -16,9 +16,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: plugin.h,v 1.11 2004/11/25 23:33:05 timlinux Exp $ */
-#ifndef PLUGIN
-#define PLUGIN
+ /*  $Id: plugin.h,v 1.13.2.5 2005/06/02 17:53:11 telwertowski Exp $ */
+#ifndef QGSNORTHARROWPLUGIN
+#define QGSNORTHARROWPLUGIN
 #include "../qgisplugin.h"
 #include <qwidget.h>
 #include <qpainter.h>
@@ -31,7 +31,7 @@
 * \brief North Arrow plugin for QGIS
 *
 */
-class Plugin:public QObject, public QgisPlugin
+class QgsNorthArrowPlugin:public QObject, public QgisPlugin
 {
   Q_OBJECT public:
       /**
@@ -40,9 +40,9 @@ class Plugin:public QObject, public QgisPlugin
        * @param qgis Pointer to the QgisApp object
        * @param qI Pointer to the QgisIface object.
        */
-      Plugin(QgisApp * , QgisIface * );
+    QgsNorthArrowPlugin(QgisApp * , QgisIface * );
   //! Destructor
-  virtual ~ Plugin();
+  virtual ~QgsNorthArrowPlugin();
   public slots:
   //! init the gui
   virtual void initGui();
@@ -64,23 +64,33 @@ class Plugin:public QObject, public QgisPlugin
   void setPlacement(QString);
   //! enable or disable north arrow
   void setEnabled(bool);
+  //! enable or disable the automatic setting of the arrow direction
+  void setAutomatic(bool);
+  //! try to calculate the direction for the north arrow. Sets the
+  // private class rotation variable. If unable to calculate the
+  // direction, the function returns false and leaves the rotation
+  // variable as is.
+  bool calculateNorthDirection();
 
     private:
 
+  static const double PI;
+  //  static const double DEG2RAD;
+  static const double TOL;
 
   // The amount of rotation for the north arrow
   int mRotationInt;
   int pluginType;
   // enable or disable north arrow
   bool mEnable;
+  //! enable or disable the automatic setting of the arrow direction
+  bool mAutomatic;
   // The placement string
   QString mPlacement;
   //! Id of the plugin's menu. Used for unloading
-  int menuIdInt;
+  int menuId;
   //! Pointer to our toolbar
   QToolBar *toolBarPointer;
-  //! Pointer to our menu
-  QMenuBar *menuBarPointer;
   //! Pionter to QGIS main application object
   QgisApp *qgisMainWindowPointer;
   //! Pointer to the QGIS interface object
