@@ -1,8 +1,8 @@
 /****************************************************************************
-** Plugin meta object code from reading C++ file 'plugin.h'
+** QgsNorthArrowPlugin meta object code from reading C++ file 'plugin.h'
 **
-** Created: Tue Nov 30 19:35:05 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:26:06 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,32 +14,32 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
-const char *Plugin::className() const
+const char *QgsNorthArrowPlugin::className() const
 {
-    return "Plugin";
+    return "QgsNorthArrowPlugin";
 }
 
-QMetaObject *Plugin::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_Plugin( "Plugin", &Plugin::staticMetaObject );
+QMetaObject *QgsNorthArrowPlugin::metaObj = 0;
+static QMetaObjectCleanUp cleanUp_QgsNorthArrowPlugin( "QgsNorthArrowPlugin", &QgsNorthArrowPlugin::staticMetaObject );
 
 #ifndef QT_NO_TRANSLATION
-QString Plugin::tr( const char *s, const char *c )
+QString QgsNorthArrowPlugin::tr( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "Plugin", s, c, QApplication::DefaultCodec );
+	return qApp->translate( "QgsNorthArrowPlugin", s, c, QApplication::DefaultCodec );
     else
 	return QString::fromLatin1( s );
 }
 #ifndef QT_NO_TRANSLATION_UTF8
-QString Plugin::trUtf8( const char *s, const char *c )
+QString QgsNorthArrowPlugin::trUtf8( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "Plugin", s, c, QApplication::UnicodeUTF8 );
+	return qApp->translate( "QgsNorthArrowPlugin", s, c, QApplication::UnicodeUTF8 );
     else
 	return QString::fromUtf8( s );
 }
@@ -47,7 +47,7 @@ QString Plugin::trUtf8( const char *s, const char *c )
 
 #endif // QT_NO_TRANSLATION
 
-QMetaObject* Plugin::staticMetaObject()
+QMetaObject* QgsNorthArrowPlugin::staticMetaObject()
 {
     if ( metaObj )
 	return metaObj;
@@ -74,6 +74,14 @@ QMetaObject* Plugin::staticMetaObject()
 	{ 0, &static_QUType_bool, 0, QUParameter::In }
     };
     static const QUMethod slot_9 = {"setEnabled", 1, param_slot_9 };
+    static const QUParameter param_slot_10[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::In }
+    };
+    static const QUMethod slot_10 = {"setAutomatic", 1, param_slot_10 };
+    static const QUParameter param_slot_11[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::Out }
+    };
+    static const QUMethod slot_11 = {"calculateNorthDirection", 1, param_slot_11 };
     static const QMetaData slot_tbl[] = {
 	{ "initGui()", &slot_0, QMetaData::Public },
 	{ "projectRead()", &slot_1, QMetaData::Public },
@@ -84,31 +92,33 @@ QMetaObject* Plugin::staticMetaObject()
 	{ "unload()", &slot_6, QMetaData::Public },
 	{ "help()", &slot_7, QMetaData::Public },
 	{ "setPlacement(QString)", &slot_8, QMetaData::Public },
-	{ "setEnabled(bool)", &slot_9, QMetaData::Public }
+	{ "setEnabled(bool)", &slot_9, QMetaData::Public },
+	{ "setAutomatic(bool)", &slot_10, QMetaData::Public },
+	{ "calculateNorthDirection()", &slot_11, QMetaData::Public }
     };
     metaObj = QMetaObject::new_metaobject(
-	"Plugin", parentObject,
-	slot_tbl, 10,
+	"QgsNorthArrowPlugin", parentObject,
+	slot_tbl, 12,
 	0, 0,
 #ifndef QT_NO_PROPERTIES
 	0, 0,
 	0, 0,
 #endif // QT_NO_PROPERTIES
 	0, 0 );
-    cleanUp_Plugin.setMetaObject( metaObj );
+    cleanUp_QgsNorthArrowPlugin.setMetaObject( metaObj );
     return metaObj;
 }
 
-void* Plugin::qt_cast( const char* clname )
+void* QgsNorthArrowPlugin::qt_cast( const char* clname )
 {
-    if ( !qstrcmp( clname, "Plugin" ) )
+    if ( !qstrcmp( clname, "QgsNorthArrowPlugin" ) )
 	return this;
     if ( !qstrcmp( clname, "QgisPlugin" ) )
 	return (QgisPlugin*)this;
     return QObject::qt_cast( clname );
 }
 
-bool Plugin::qt_invoke( int _id, QUObject* _o )
+bool QgsNorthArrowPlugin::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
     case 0: initGui(); break;
@@ -121,22 +131,24 @@ bool Plugin::qt_invoke( int _id, QUObject* _o )
     case 7: help(); break;
     case 8: setPlacement((QString)static_QUType_QString.get(_o+1)); break;
     case 9: setEnabled((bool)static_QUType_bool.get(_o+1)); break;
+    case 10: setAutomatic((bool)static_QUType_bool.get(_o+1)); break;
+    case 11: static_QUType_bool.set(_o,calculateNorthDirection()); break;
     default:
 	return QObject::qt_invoke( _id, _o );
     }
     return TRUE;
 }
 
-bool Plugin::qt_emit( int _id, QUObject* _o )
+bool QgsNorthArrowPlugin::qt_emit( int _id, QUObject* _o )
 {
     return QObject::qt_emit(_id,_o);
 }
 #ifndef QT_NO_PROPERTIES
 
-bool Plugin::qt_property( int id, int f, QVariant* v)
+bool QgsNorthArrowPlugin::qt_property( int id, int f, QVariant* v)
 {
     return QObject::qt_property( id, f, v);
 }
 
-bool Plugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool QgsNorthArrowPlugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
 #endif // QT_NO_PROPERTIES
