@@ -1,8 +1,8 @@
 /****************************************************************************
-** PluginGui meta object code from reading C++ file 'plugingui.h'
+** QgsNorthArrowPluginGui meta object code from reading C++ file 'plugingui.h'
 **
-** Created: Tue Nov 30 19:35:05 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:26:06 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,32 +14,32 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
-const char *PluginGui::className() const
+const char *QgsNorthArrowPluginGui::className() const
 {
-    return "PluginGui";
+    return "QgsNorthArrowPluginGui";
 }
 
-QMetaObject *PluginGui::metaObj = 0;
-static QMetaObjectCleanUp cleanUp_PluginGui( "PluginGui", &PluginGui::staticMetaObject );
+QMetaObject *QgsNorthArrowPluginGui::metaObj = 0;
+static QMetaObjectCleanUp cleanUp_QgsNorthArrowPluginGui( "QgsNorthArrowPluginGui", &QgsNorthArrowPluginGui::staticMetaObject );
 
 #ifndef QT_NO_TRANSLATION
-QString PluginGui::tr( const char *s, const char *c )
+QString QgsNorthArrowPluginGui::tr( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGui", s, c, QApplication::DefaultCodec );
+	return qApp->translate( "QgsNorthArrowPluginGui", s, c, QApplication::DefaultCodec );
     else
 	return QString::fromLatin1( s );
 }
 #ifndef QT_NO_TRANSLATION_UTF8
-QString PluginGui::trUtf8( const char *s, const char *c )
+QString QgsNorthArrowPluginGui::trUtf8( const char *s, const char *c )
 {
     if ( qApp )
-	return qApp->translate( "PluginGui", s, c, QApplication::UnicodeUTF8 );
+	return qApp->translate( "QgsNorthArrowPluginGui", s, c, QApplication::UnicodeUTF8 );
     else
 	return QString::fromUtf8( s );
 }
@@ -47,11 +47,11 @@ QString PluginGui::trUtf8( const char *s, const char *c )
 
 #endif // QT_NO_TRANSLATION
 
-QMetaObject* PluginGui::staticMetaObject()
+QMetaObject* QgsNorthArrowPluginGui::staticMetaObject()
 {
     if ( metaObj )
 	return metaObj;
-    QMetaObject* parentObject = PluginGuiBase::staticMetaObject();
+    QMetaObject* parentObject = QgsNorthArrowPluginGuiBase::staticMetaObject();
     static const QUParameter param_slot_0[] = {
 	{ 0, &static_QUType_int, 0, QUParameter::In }
     };
@@ -65,19 +65,26 @@ QMetaObject* PluginGui::staticMetaObject()
     };
     static const QUMethod slot_2 = {"setEnabled", 1, param_slot_2 };
     static const QUParameter param_slot_3[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::In }
+    };
+    static const QUMethod slot_3 = {"setAutomatic", 1, param_slot_3 };
+    static const QUMethod slot_4 = {"setAutomaticDisabled", 0, 0 };
+    static const QUParameter param_slot_5[] = {
 	{ "theInt", &static_QUType_int, 0, QUParameter::In }
     };
-    static const QUMethod slot_3 = {"spinSize_valueChanged", 1, param_slot_3 };
-    static const QUParameter param_slot_4[] = {
+    static const QUMethod slot_5 = {"spinSize_valueChanged", 1, param_slot_5 };
+    static const QUParameter param_slot_6[] = {
 	{ "theInt", &static_QUType_int, 0, QUParameter::In }
     };
-    static const QUMethod slot_4 = {"sliderRotation_valueChanged", 1, param_slot_4 };
+    static const QUMethod slot_6 = {"sliderRotation_valueChanged", 1, param_slot_6 };
     static const QMetaData slot_tbl[] = {
 	{ "setRotation(int)", &slot_0, QMetaData::Public },
 	{ "setPlacement(QString)", &slot_1, QMetaData::Public },
 	{ "setEnabled(bool)", &slot_2, QMetaData::Public },
-	{ "spinSize_valueChanged(int)", &slot_3, QMetaData::Private },
-	{ "sliderRotation_valueChanged(int)", &slot_4, QMetaData::Private }
+	{ "setAutomatic(bool)", &slot_3, QMetaData::Public },
+	{ "setAutomaticDisabled()", &slot_4, QMetaData::Public },
+	{ "spinSize_valueChanged(int)", &slot_5, QMetaData::Private },
+	{ "sliderRotation_valueChanged(int)", &slot_6, QMetaData::Private }
     };
     static const QUParameter param_signal_0[] = {
 	{ 0, &static_QUType_int, 0, QUParameter::In }
@@ -91,80 +98,103 @@ QMetaObject* PluginGui::staticMetaObject()
 	{ 0, &static_QUType_bool, 0, QUParameter::In }
     };
     static const QUMethod signal_2 = {"enableNorthArrow", 1, param_signal_2 };
+    static const QUParameter param_signal_3[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::In }
+    };
+    static const QUMethod signal_3 = {"enableAutomatic", 1, param_signal_3 };
+    static const QUMethod signal_4 = {"needToRefresh", 0, 0 };
     static const QMetaData signal_tbl[] = {
 	{ "rotationChanged(int)", &signal_0, QMetaData::Private },
 	{ "changePlacement(QString)", &signal_1, QMetaData::Private },
-	{ "enableNorthArrow(bool)", &signal_2, QMetaData::Private }
+	{ "enableNorthArrow(bool)", &signal_2, QMetaData::Private },
+	{ "enableAutomatic(bool)", &signal_3, QMetaData::Private },
+	{ "needToRefresh()", &signal_4, QMetaData::Private }
     };
     metaObj = QMetaObject::new_metaobject(
-	"PluginGui", parentObject,
-	slot_tbl, 5,
-	signal_tbl, 3,
+	"QgsNorthArrowPluginGui", parentObject,
+	slot_tbl, 7,
+	signal_tbl, 5,
 #ifndef QT_NO_PROPERTIES
 	0, 0,
 	0, 0,
 #endif // QT_NO_PROPERTIES
 	0, 0 );
-    cleanUp_PluginGui.setMetaObject( metaObj );
+    cleanUp_QgsNorthArrowPluginGui.setMetaObject( metaObj );
     return metaObj;
 }
 
-void* PluginGui::qt_cast( const char* clname )
+void* QgsNorthArrowPluginGui::qt_cast( const char* clname )
 {
-    if ( !qstrcmp( clname, "PluginGui" ) )
+    if ( !qstrcmp( clname, "QgsNorthArrowPluginGui" ) )
 	return this;
-    return PluginGuiBase::qt_cast( clname );
+    return QgsNorthArrowPluginGuiBase::qt_cast( clname );
 }
 
 // SIGNAL rotationChanged
-void PluginGui::rotationChanged( int t0 )
+void QgsNorthArrowPluginGui::rotationChanged( int t0 )
 {
     activate_signal( staticMetaObject()->signalOffset() + 0, t0 );
 }
 
 // SIGNAL changePlacement
-void PluginGui::changePlacement( QString t0 )
+void QgsNorthArrowPluginGui::changePlacement( QString t0 )
 {
     activate_signal( staticMetaObject()->signalOffset() + 1, t0 );
 }
 
 // SIGNAL enableNorthArrow
-void PluginGui::enableNorthArrow( bool t0 )
+void QgsNorthArrowPluginGui::enableNorthArrow( bool t0 )
 {
     activate_signal_bool( staticMetaObject()->signalOffset() + 2, t0 );
 }
 
-bool PluginGui::qt_invoke( int _id, QUObject* _o )
+// SIGNAL enableAutomatic
+void QgsNorthArrowPluginGui::enableAutomatic( bool t0 )
+{
+    activate_signal_bool( staticMetaObject()->signalOffset() + 3, t0 );
+}
+
+// SIGNAL needToRefresh
+void QgsNorthArrowPluginGui::needToRefresh()
+{
+    activate_signal( staticMetaObject()->signalOffset() + 4 );
+}
+
+bool QgsNorthArrowPluginGui::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
     case 0: setRotation((int)static_QUType_int.get(_o+1)); break;
     case 1: setPlacement((QString)static_QUType_QString.get(_o+1)); break;
     case 2: setEnabled((bool)static_QUType_bool.get(_o+1)); break;
-    case 3: spinSize_valueChanged((int)static_QUType_int.get(_o+1)); break;
-    case 4: sliderRotation_valueChanged((int)static_QUType_int.get(_o+1)); break;
+    case 3: setAutomatic((bool)static_QUType_bool.get(_o+1)); break;
+    case 4: setAutomaticDisabled(); break;
+    case 5: spinSize_valueChanged((int)static_QUType_int.get(_o+1)); break;
+    case 6: sliderRotation_valueChanged((int)static_QUType_int.get(_o+1)); break;
     default:
-	return PluginGuiBase::qt_invoke( _id, _o );
+	return QgsNorthArrowPluginGuiBase::qt_invoke( _id, _o );
     }
     return TRUE;
 }
 
-bool PluginGui::qt_emit( int _id, QUObject* _o )
+bool QgsNorthArrowPluginGui::qt_emit( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->signalOffset() ) {
     case 0: rotationChanged((int)static_QUType_int.get(_o+1)); break;
     case 1: changePlacement((QString)static_QUType_QString.get(_o+1)); break;
     case 2: enableNorthArrow((bool)static_QUType_bool.get(_o+1)); break;
+    case 3: enableAutomatic((bool)static_QUType_bool.get(_o+1)); break;
+    case 4: needToRefresh(); break;
     default:
-	return PluginGuiBase::qt_emit(_id,_o);
+	return QgsNorthArrowPluginGuiBase::qt_emit(_id,_o);
     }
     return TRUE;
 }
 #ifndef QT_NO_PROPERTIES
 
-bool PluginGui::qt_property( int id, int f, QVariant* v)
+bool QgsNorthArrowPluginGui::qt_property( int id, int f, QVariant* v)
 {
-    return PluginGuiBase::qt_property( id, f, v);
+    return QgsNorthArrowPluginGuiBase::qt_property( id, f, v);
 }
 
-bool PluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
+bool QgsNorthArrowPluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
 #endif // QT_NO_PROPERTIES
