@@ -18,7 +18,7 @@ email                : tim@linfiniti.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/*  $Id: plugin.cpp,v 1.9 2004/11/12 12:59:37 timlinux Exp $ */
+/*  $Id: plugin.cpp,v 1.12.2.1 2005/09/17 23:32:11 timlinux Exp $ */
 
 // includes
 
@@ -51,7 +51,7 @@ email                : tim@linfiniti.com
 #define QGISEXTERN extern "C"
 #endif
 
-static const char * const sIdent = "$Id: plugin.cpp,v 1.9 2004/11/12 12:59:37 timlinux Exp $";
+static const char * const sIdent = "$Id: plugin.cpp,v 1.12.2.1 2005/09/17 23:32:11 timlinux Exp $";
 static const char * const sName = "[menuitemname]";
 static const char * const sDescription = "[plugindescription]";
 static const char * const sPluginVersion = "Version 0.1";
@@ -69,14 +69,15 @@ static const QgisPlugin::PLUGINTYPE sPluginType = QgisPlugin::UI;
  * @param theQGisApp - Pointer to the QGIS main window
  * @param theQGisInterface - Pointer to the QGIS interface object
  */
-Plugin::Plugin(QgisApp * theQGisApp, QgisIface * theQgisInterface):
+[pluginname]::[pluginname](QgisApp * theQGisApp, 
+				       QgisIface * theQgisInterface):
                  mQGisApp(theQGisApp), 
                  mQGisIface(theQgisInterface),
                  QgisPlugin(sName,sDescription,sPluginVersion,sPluginType)
 {
 }
 
-Plugin::~Plugin()
+[pluginname]::~[pluginname]()
 {
 
 }
@@ -84,12 +85,13 @@ Plugin::~Plugin()
 /*
  * Initialize the GUI interface for the plugin 
  */
-void Plugin::initGui()
+void [pluginname]::initGui()
 {
-  QPopupMenu *pluginMenu = new QPopupMenu(mQGisApp);
-  pluginMenu->insertItem(QIconSet(icon),"&[menuitemname]", this, SLOT(run()));
-  mMenuBarPointer = ((QMainWindow *) mQGisApp)->menuBar();
-  mMenuId = mQGisIface->addMenu("&[menuname]", pluginMenu);
+  QPopupMenu *pluginMenu = mQGisIface->getPluginMenu("&[menuname]");
+  mMenuId = pluginMenu->insertItem(QIconSet(icon),"&[menuitemname]", this, SLOT(run()));
+
+  pluginMenu->setWhatsThis(mMenuId, tr("Replace this with a short description of the what the plugin does"));
+
   // Create the action for tool
   mQActionPointer = new QAction("[menuitemname]", QIconSet(icon), "&icon",0, this, "run");
   // Connect the action to the run
@@ -102,15 +104,15 @@ void Plugin::initGui()
 
 }
 //method defined in interface
-void Plugin::help()
+void [pluginname]::help()
 {
   //implement me!
 }
 
 // Slot called when the buffer menu item is activated
-void Plugin::run()
+void [pluginname]::run()
 {
-  PluginGui *myPluginGui=new PluginGui(mQGisApp,"[menuitemname]",true,0);
+  [pluginname]Gui *myPluginGui=new [pluginname]Gui(mQGisApp,"[menuitemname]",true,0);
   //listen for when the layer has been made so we can draw it
   connect(myPluginGui, SIGNAL(drawRasterLayer(QString)), this, SLOT(drawRasterLayer(QString)));
   connect(myPluginGui, SIGNAL(drawVectorLayer(QString,QString,QString)), this, SLOT(drawVectorLayer(QString,QString,QString)));
@@ -118,10 +120,10 @@ void Plugin::run()
 }
 
 // Unload the plugin by cleaning up the GUI
-void Plugin::unload()
+void [pluginname]::unload()
 {
   // remove the GUI
-  mMenuBarPointer->removeItem(mMenuId);
+  mQGisIface->removePluginMenuItem("&[menuname]",mMenuId);
   mQGisIface->removeToolBarIcon(mQActionPointer);
   delete mQActionPointer;
 }
@@ -140,7 +142,7 @@ void Plugin::unload()
 
 //!draw a raster layer in the qui - intended to respond to signal sent by diolog when it as finished creating
 //layer
-void Plugin::drawRasterLayer(QString theQString)
+void [pluginname]::drawRasterLayer(QString theQString)
 {
   mQGisIface->addRasterLayer(theQString);
 }
@@ -148,7 +150,7 @@ void Plugin::drawRasterLayer(QString theQString)
 //!draw a vector layer in the qui - intended to respond to signal sent by 
 // dialog when it as finished creating a layer. It needs to be given 
 // vectorLayerPath, baseName, providerKey ("ogr" or "postgres");
-void Plugin::drawVectorLayer(QString thePathNameQString, QString theBaseNameQString, QString theProviderQString)
+void [pluginname]::drawVectorLayer(QString thePathNameQString, QString theBaseNameQString, QString theProviderQString)
 {
   mQGisIface->addVectorLayer( thePathNameQString, theBaseNameQString, theProviderQString);
 }
@@ -173,7 +175,7 @@ void Plugin::drawVectorLayer(QString thePathNameQString, QString theBaseNameQStr
 // Class factory to return a new instance of the plugin class
 QGISEXTERN QgisPlugin * classFactory(QgisApp * theQGisAppPointer, QgisIface * theQgisInterfacePointer)
 {
-  return new Plugin(theQGisAppPointer, theQgisInterfacePointer);
+  return new [pluginname](theQGisAppPointer, theQgisInterfacePointer);
 }
 // Return the name of the plugin - note that we do not user class members as
 // the class may not yet be insantiated when this method is called.
