@@ -16,7 +16,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: plugin.h,v 1.5 2004/11/12 13:55:18 timlinux Exp $ */
+ /*  $Id: plugin.h,v 1.7.2.1 2005/09/17 23:32:11 timlinux Exp $ */
 /***************************************************************************
  *   QGIS Programming conventions:
  *   
@@ -34,8 +34,8 @@
  *   DON'T: separate variable names using underscores: my_variable_name (NO!)
  *
  * **************************************************************************/
-#ifndef PLUGIN
-#define PLUGIN
+#ifndef [pluginsentinel]
+#define [pluginsentinel]
 #include "../qgisplugin.h"
 #include <qwidget.h>
 
@@ -47,7 +47,7 @@
 * \brief [name] plugin for QGIS
 * [description]
 */
-class Plugin:public QObject, public QgisPlugin
+class [pluginname]:public QObject, public QgisPlugin
 {
   Q_OBJECT public:
       
@@ -63,9 +63,9 @@ class Plugin:public QObject, public QgisPlugin
   * @param Pointer to the QgisApp object
   * @param Pointer to the QgisIface object. 
    */
-  Plugin(QgisApp * , QgisIface * );
+  [pluginname](QgisApp * , QgisIface * );
   //! Destructor
-  virtual ~ Plugin();
+  virtual ~ [pluginname]();
 
 public slots:
   //! init the gui
@@ -107,8 +107,6 @@ private:
   int mMenuId;
   //! Pointer to our toolbar
   QToolBar *mToolBarPointer;
-  //! Pointer to our menu
-  QMenuBar *mMenuBarPointer;
   //! Pionter to QGIS main application object
   QgisApp *mQGisApp;
   //! Pointer to the QGIS interface object
