@@ -18,14 +18,10 @@ email                : sbr00pwb@users.sourceforge.net
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/*  $Id: plugin.cpp,v 1.19.2.1 2004/12/03 17:17:35 gsherman Exp $ */
+/*  $Id: plugin.cpp,v 1.32.2.3 2005/09/03 21:16:10 g_j_m Exp $ */
 
 // includes
-#ifdef WIN32
 #include <cmath>
-#else
-#include <math.h>
-#endif
 
 #include <qgisapp.h>
 #include <qgsmaplayer.h>
@@ -43,7 +39,7 @@ email                : sbr00pwb@users.sourceforge.net
 #include <qpen.h>
 #include <qgspoint.h>
 #include <qpointarray.h>
-#include <qgscoordinatetransform.h>
+#include <qgsmaptopixel.h>
 #include <qstring.h>
 #include <qfontmetrics.h>
 #include <qfont.h>
@@ -67,7 +63,7 @@ email                : sbr00pwb@users.sourceforge.net
 #define QGISEXTERN extern "C"
 #endif
 
-static const char * const ident_ = "$Id: plugin.cpp,v 1.19.2.1 2004/12/03 17:17:35 gsherman Exp $";
+static const char * const ident_ = "$Id: plugin.cpp,v 1.32.2.3 2005/09/03 21:16:10 g_j_m Exp $";
 
 static const char * const name_ = "ScaleBar";
 static const char * const description_ = "Plugin to draw scale bar on map";
@@ -81,19 +77,19 @@ static const QgisPlugin::PLUGINTYPE type_ = QgisPlugin::UI;
  * @param qgis Pointer to the QGIS main window
  * @param _qI Pointer to the QGIS interface object
  */
-Plugin::Plugin(QgisApp * theQGisApp, QgisIface * theQgisInterFace):
+QgsScaleBarPlugin::QgsScaleBarPlugin(QgisApp * theQGisApp, QgisIface * theQgisInterFace):
 qgisMainWindowPointer(theQGisApp),
     qGisInterface(theQgisInterFace),
 QgisPlugin(name_,description_,version_,type_)
 {
   mPreferredSize = 30;
-  mPlacement = "Top Left";
-  mStyle = "Tick Down";
+  mPlacement = tr("Top Left");
+  mStyle = tr("Tick Down");
   mEnabled = true;
   mSnapping = true;
 }
 
-Plugin::~Plugin()
+QgsScaleBarPlugin::~QgsScaleBarPlugin()
 {
 
 }
@@ -101,19 +97,16 @@ Plugin::~Plugin()
 /*
  * Initialize the GUI interface for the plugin
  */
-void Plugin::initGui()
+void QgsScaleBarPlugin::initGui()
 {
-  // add a menu with 2 items
-  QPopupMenu *pluginMenu = new QPopupMenu(qgisMainWindowPointer);
+  QPopupMenu *pluginMenu = qGisInterface->getPluginMenu(tr("&Decorations"));
+  menuId = pluginMenu->insertItem(QIconSet(icon),tr("&ScaleBar"), this, SLOT(run()));
 
-  int menuId = pluginMenu->insertItem(QIconSet(icon),"&ScaleBar", this, SLOT(run()));
-  pluginMenu->setWhatsThis(menuId, "Creates a scale bar that is displayed on the map canvas");
-  menuBarPointer = ((QMainWindow *) qgisMainWindowPointer)->menuBar();
+  pluginMenu->setWhatsThis(menuId, tr("Creates a scale bar that is displayed on the map canvas"));
 
-  menuIdInt = qGisInterface->addMenu("&Scale Bar", pluginMenu);
   // Create the action for tool
-  myQActionPointer = new QAction("Scale Bar", QIconSet(icon), "&Wmi",0, this, "run");
-  myQActionPointer->setWhatsThis("Creates a scale bar that is displayed on the map canvas");
+  myQActionPointer = new QAction(tr("Scale Bar"), QIconSet(icon), "&Wmi",0, this, tr("run"));
+  myQActionPointer->setWhatsThis(tr("Creates a scale bar that is displayed on the map canvas"));
   // Connect the action to the run
   connect(myQActionPointer, SIGNAL(activated()), this, SLOT(run()));
   //render the scale bar each time the map is rendered
@@ -124,7 +117,7 @@ void Plugin::initGui()
   qGisInterface->addToolBarIcon(myQActionPointer);
 }
 
-void Plugin::projectRead()
+void QgsScaleBarPlugin::projectRead()
 {
 #ifdef QGISDEBUG
     std::cout << "+++++++++ scalebar plugin - project read slot called...." << std::endl;
@@ -140,18 +133,17 @@ void Plugin::projectRead()
     int myGreenInt = QgsProject::instance()->readNumEntry("ScaleBar","/ColorGreenPart",0);
     int myBlueInt = QgsProject::instance()->readNumEntry("ScaleBar","/ColorBluePart",0);
     mColour = QColor(myRedInt,myGreenInt,myBlueInt);
-    refreshCanvas();
 }
 //method defined in interface
-void Plugin::help()
+void QgsScaleBarPlugin::help()
 {
   //implement me!
 }
 
 // Slot called when the  menu item is activated
-void Plugin::run()
+void QgsScaleBarPlugin::run()
 {
-  PluginGui *myPluginGui=new PluginGui(qgisMainWindowPointer,"Scale Bar",true,0);
+  QgsScaleBarPluginGui *myPluginGui=new QgsScaleBarPluginGui(qgisMainWindowPointer,tr("Scale Bar"),true,0);
   myPluginGui->setPreferredSize(mPreferredSize);
   myPluginGui->setSnapping(mSnapping);
   myPluginGui->setPlacement(mPlacement);
@@ -179,7 +171,7 @@ void Plugin::run()
 }
 
 
-void Plugin::refreshCanvas()
+void QgsScaleBarPlugin::refreshCanvas()
 {
   qGisInterface->getMapCanvas()->refresh();
 }
@@ -187,7 +179,7 @@ void Plugin::refreshCanvas()
 
 
 // Actual drawing of Scale Bar
-void Plugin::renderScaleBar(QPainter * theQPainter)
+void QgsScaleBarPlugin::renderScaleBar(QPainter * theQPainter)
 {
   int myBufferSize=1; //softcode this later
 
@@ -196,8 +188,10 @@ void Plugin::renderScaleBar(QPainter * theQPainter)
   int myCanvasHeight = myMetrics.height();
   int myCanvasWidth = myMetrics.width();
 
-  //Get map units per pixel
-  double myMuppDouble=qGisInterface->getMapCanvas()->mupp();
+  //Get map units per pixel. This can be negative at times (to do with
+  //projections) and that just confuses the rest of the code in this
+  //function, so force to a positive number.
+  double myMuppDouble = std::abs(qGisInterface->getMapCanvas()->mupp());
 
   // Exit if the canvas width is 0 or layercount is 0 or QGIS will freeze
   int myLayerCount=qGisInterface->getMapCanvas()->layerCount();
@@ -219,8 +213,8 @@ void Plugin::renderScaleBar(QPainter * theQPainter)
     //If scale bar is very small reset to 1/4 of the canvas wide
     if (myScaleBarWidth < 30)
     {
-      myScaleBarWidth = myMuppDouble * (myCanvasWidth/4);
-      myActualSize = myScaleBarWidth * myMuppDouble;
+      myScaleBarWidth = myCanvasWidth / 4; // pixels
+      myActualSize = myScaleBarWidth * myMuppDouble; // map units
     };
 
     //if scale bar is more than half the canvas wide keep halving until not
@@ -230,38 +224,61 @@ void Plugin::renderScaleBar(QPainter * theQPainter)
     };
     myActualSize = myScaleBarWidth * myMuppDouble;
 
-    // snap to integer < 10 times power of 10
-    if (mSnapping) {
-      int myPowerOf10 = int(pow(10.0, int(log(myActualSize) / log(10.0))));
-#ifdef WIN32
-      // I know this is tacky -- but I'm trying to get this ready
-      // for release
-      // TODO Make this actually round up/down as appropriate
+    // Work out the exponent for the number - e.g, 1234 will give 3,
+    // and .001234 will give -3
+    double myPowerOf10 = floor(log10(myActualSize));
 
-      //myActualSize = ceil(myActualSize / myPowerOf10) * myPowerOf10;
-#else
-      myActualSize = round(myActualSize / myPowerOf10) * myPowerOf10;
-#endif
+    // snap to integer < 10 times power of 10
+    if (mSnapping) 
+    {
+      double scaler = pow(10.0, myPowerOf10);
+      myActualSize = floor((myActualSize / scaler) + 0.5) * scaler;
       myScaleBarWidth = myActualSize / myMuppDouble;
     }
 
     //Get type of map units and set scale bar unit label text
-    int myMapUnits=qGisInterface->getMapCanvas()->mapUnits();
+    QGis::units myMapUnits=qGisInterface->getMapCanvas()->mapUnits();
     QString myScaleBarUnitLabel;
     switch (myMapUnits)
     {
-        case 0: myScaleBarUnitLabel=tr(" metres"); break;
-        case 1: myScaleBarUnitLabel=tr(" feet"); break;
-        case 2: myScaleBarUnitLabel=tr(" degrees"); break;
-        default: std::cout << "Error: not picked up map units - actual value = " << myMapUnits << std::endl;
+    case QGis::METERS: 
+      if (myActualSize > 1000.0)
+      {
+	myScaleBarUnitLabel=tr(" km");
+	myActualSize = myActualSize/1000;
+      }
+      else if (myActualSize < 0.01)
+      {
+	myScaleBarUnitLabel=tr(" mm");
+	myActualSize = myActualSize*1000;
+      }
+      else if (myActualSize < 0.1)
+      {
+        myScaleBarUnitLabel=tr(" cm");
+        myActualSize = myActualSize*100;
+      }
+      else
+	myScaleBarUnitLabel=tr(" m"); 
+      break;
+    case QGis::FEET:
+      if (myActualSize == 1.0)
+	myScaleBarUnitLabel=tr(" foot"); 
+      else
+	myScaleBarUnitLabel=tr(" feet"); 
+      break;
+    case QGis::DEGREES:
+      if (myActualSize == 1.0)
+	myScaleBarUnitLabel=tr(" degree"); 
+      else
+	myScaleBarUnitLabel=tr(" degrees"); 
+      break;
+    case QGis::UNKNOWN:
+      myScaleBarUnitLabel=tr(" unknown");
+    default: 
+      std::cout << "Error: not picked up map units - actual value = " 
+		<< myMapUnits << std::endl;
     };
-    //use km if units are larget and scale bar width is larger then 1000
-    if (myMapUnits==0 && myActualSize > 1000)
-    {
-      myScaleBarUnitLabel=tr(" km");
-      myActualSize = myActualSize/1000;
 
-    }
     //Set font and calculate width of unit label
     int myFontSize = 10; //we use this later for buffering
     QFont myFont( "helvetica", myFontSize );
@@ -484,49 +501,55 @@ void Plugin::renderScaleBar(QPainter * theQPainter)
 
 
 // Unload the plugin by cleaning up the GUI
-void Plugin::unload()
+void QgsScaleBarPlugin::unload()
 {
   // remove the GUI
-  menuBarPointer->removeItem(menuIdInt);
+  qGisInterface->removePluginMenuItem(tr("&Decorations"),menuId);
   qGisInterface->removeToolBarIcon(myQActionPointer);
+
+  // remove the northarrow from the canvas
+  disconnect(qGisInterface->getMapCanvas(), SIGNAL(renderComplete(QPainter *)),
+	     this, SLOT(renderScaleBar(QPainter *)));
+  refreshCanvas();
+
   delete myQActionPointer;
 }
 
 //! set placement of scale bar
-void Plugin::setPlacement(QString theQString)
+void QgsScaleBarPlugin::setPlacement(QString theQString)
 {
   mPlacement = theQString;
   QgsProject::instance()->writeEntry("ScaleBar","/Placement",mPlacement);
 }
 
 //! set preferred size of scale bar
-void Plugin::setPreferredSize(int thePreferredSize)
+void QgsScaleBarPlugin::setPreferredSize(int thePreferredSize)
 {
   mPreferredSize = thePreferredSize;
   QgsProject::instance()->writeEntry("ScaleBar","/PreferredSize",mPreferredSize);
 }
 
 //! set whether the scale bar length should snap to the closes A*10^B
-void Plugin::setSnapping(bool theSnapping)
+void QgsScaleBarPlugin::setSnapping(bool theSnapping)
 {
   mSnapping = theSnapping;
   QgsProject::instance()->writeEntry("ScaleBar","/Snapping",mSnapping);
 }
 
 //! set scale bar enable
-void Plugin::setEnabled(bool theBool)
+void QgsScaleBarPlugin::setEnabled(bool theBool)
 {
   mEnabled = theBool;
   QgsProject::instance()->writeEntry("ScaleBar","/Enabled",mEnabled);
 }
 //! set scale bar enable
-void Plugin::setStyle(QString theStyleQString)
+void QgsScaleBarPlugin::setStyle(QString theStyleQString)
 {
   mStyle = theStyleQString;
    QgsProject::instance()->writeEntry("ScaleBar","/Style",mStyle);
 }
 //! set the scale bar colour
-void Plugin::setColour(QColor theQColor)
+void QgsScaleBarPlugin::setColour(QColor theQColor)
 {
   mColour = theQColor;
   QgsProject::instance()->writeEntry("ScaleBar","/ColorRedPart", mColour.red());
@@ -543,7 +566,7 @@ void Plugin::setColour(QColor theQColor)
 // Class factory to return a new instance of the plugin class
 QGISEXTERN QgisPlugin * classFactory(QgisApp * theQGisAppPointer, QgisIface * theQgisInterfacePointer)
 {
-  return new Plugin(theQGisAppPointer, theQgisInterfacePointer);
+  return new QgsScaleBarPlugin(theQGisAppPointer, theQgisInterfacePointer);
 }
 
 // Return the name of the plugin - note that we do not user class members as
