@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsshapefile.cpp,v 1.9.2.2 2004/12/14 19:20:15 gsherman Exp $ */
+/* $Id: qgsshapefile.cpp,v 1.11.2.3 2005/09/16 23:35:21 timlinux Exp $ */
 
 #include <qapplication.h>
 #include <ogrsf_frmts.h>
@@ -30,6 +30,13 @@
 #include "qgsscangeometries.h"
 #include "../../src/qgis.h"
 
+// for htonl
+#ifdef WIN32
+#include <winsock.h>
+#else
+#include <netinet/in.h>
+#endif    
+
 
 QgsShapeFile::QgsShapeFile(QString name){
   filename = name;
@@ -50,7 +57,11 @@ QgsShapeFile::QgsShapeFile(QString name){
 }
 
 QgsShapeFile::~QgsShapeFile(){
-  delete ogrLayer;
+  if(ogrDataSource != 0)
+  {
+    // don't delete the layer if the datasource is bad -- (causes crash)
+    delete ogrLayer;
+  }
   delete ogrDataSource;
   delete filename;
   delete geom_type;
@@ -123,7 +134,12 @@ QString QgsShapeFile::getFeatureClass(){
   // type. 
   qApp->processEvents();
   isMulti = scanGeometries();
-  OGRFeature *feat = ogrLayer->GetNextFeature();
+  OGRFeature *feat;
+  // skip features without geometry
+  while ((feat = ogrLayer->GetNextFeature()) != NULL) {
+    if (feat->GetGeometryRef())
+      break;
+  }
   if(feat){
     OGRGeometry *geom = feat->GetGeometryRef();
     if(geom){
@@ -152,6 +168,16 @@ QString QgsShapeFile::getFeatureClass(){
       // read header
       DbaseHeader dbh;
       dbf.read((char *)&dbh, sizeof(dbh));
+      // Check byte order
+      if(htonl(1) == 1) 
+      {
+        /* DbaseHeader is stored in little-endian format.
+         * The num_recs, size_hdr and size_rec fields must be byte-swapped when read
+         * on a big-endian processor. Currently only size_hdr is used.
+         */
+        unsigned char *byte = reinterpret_cast<unsigned char *>(&dbh.size_hdr);
+        unsigned char t = *byte; *byte = *(byte+1); *(byte+1) = t;
+      }
 
       Fda fda;
       QString str_type = "varchar(";
@@ -228,21 +254,32 @@ bool QgsShapeFile::insertLayer(QString dbname, QString schema, QString geom_col,
   connect(pro, SIGNAL(cancelled()), this, SLOT(cancelImport()));
   import_cancelled = false;
   bool result = true;
-
+  // Mangle the table name to make it PG compliant by replacing spaces with 
+  // underscores
+  table_name = table_name.replace(" ","_");
   QString query = "CREATE TABLE "+schema+"."+table_name+"(gid int4 PRIMARY KEY, ";
   for(int n=0; n<column_names.size() && result; n++){
     if(!column_names[n][0].isLetter())
       result = false;
     char * esc_str = new char[column_names[n].length()*2+1];
+    std::cerr << "Escaping " << column_names[n] << " to ";
     PQescapeString(esc_str, (const char *)column_names[n].lower(), column_names[n].length());
+    std::cerr << esc_str << std::endl; 
     query += esc_str;
+    std::cerr << query << std::endl; 
     query += " ";
+    std::cerr << query << std::endl; 
     query += column_types[n];
+    std::cerr << query << std::endl; 
     if(n<column_names.size()-1)
+    {
       query += ", ";
+      std::cerr << query << std::endl; 
+    }
     delete[] esc_str;
   }
   query += " )";
+      std::cerr << query << std::endl; 
 
   PGresult *res = PQexec(conn, (const char *)query);
   qWarning(query);
