@@ -16,7 +16,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: qgsspitplugin.cpp,v 1.11.6.1 2004/12/03 17:17:36 gsherman Exp $ */
+ /*  $Id: qgsspitplugin.cpp,v 1.15 2005/04/27 21:37:48 g_j_m Exp $ */
 
 // includes
 #include <iostream>
@@ -42,7 +42,7 @@
 #define QGISEXTERN extern "C"
 #endif
 
-static const char * const ident_ = "$Id: qgsspitplugin.cpp,v 1.11.6.1 2004/12/03 17:17:36 gsherman Exp $";
+static const char * const ident_ = "$Id: qgsspitplugin.cpp,v 1.15 2005/04/27 21:37:48 g_j_m Exp $";
 
 static const char * const name_ = "SPIT";
 static const char * const description_ = "Shapefile to PostgreSQL/PostGIS Import Tool";
@@ -74,18 +74,12 @@ QgsSpitPlugin::~QgsSpitPlugin()
 */
 void QgsSpitPlugin::initGui()
 {
-    // add a menu with 2 items
-    QPopupMenu *pluginMenu = new QPopupMenu(qgisMainWindow);
-    int menuId =  pluginMenu->insertItem(QIconSet(spitIcon),
-         "&Import Shapefiles to PostgreSQL", this, SLOT(spit()));
+    QPopupMenu *pluginMenu = qI->getPluginMenu("&Spit");
+    menuId = pluginMenu->insertItem(QIconSet(spitIcon),"&Import Shapefiles to PostgreSQL", this, SLOT(spit()));
+
     pluginMenu->setWhatsThis(menuId,"Import shapefiles into a PostGIS-enabled PostgreSQL database. "
         "The schema and field names can be customized on import"); 
-  //  pluginMenu->insertItem("&Unload SPIT Plugin", this, SLOT(unload()));
 
-    menu = ((QMainWindow *) qgisMainWindow)->menuBar();
-
-    //menuId = menu->insertItem("&Spit", pluginMenu);
-    menuId = qI->addMenu("&Spit", pluginMenu);
      // Create the action for tool
     spitAction = new QAction("Import Shapefiles to PostgreSQL", QIconSet(spitIcon), "&SPIT",
                                               0, this, "spit");
@@ -110,7 +104,7 @@ void QgsSpitPlugin::spit()
 void QgsSpitPlugin::unload()
 {
     // remove the GUI
-    menu->removeItem(menuId);
+    qI->removePluginMenuItem("&Spit",menuId);
     qI->removeToolBarIcon(spitAction);
     delete spitAction;
 }
