@@ -16,7 +16,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /*  $Id: qgsspitplugin.h,v 1.4 2004/11/12 13:55:19 timlinux Exp $ */
+ /*  $Id: qgsspitplugin.h,v 1.5 2005/04/27 19:58:57 g_j_m Exp $ */
 #ifndef QGSSPITPLUGIN_H
 #define QGSSPITPLUGIN_H
 #include "../qgisplugin.h"
@@ -72,8 +72,6 @@ class QgsSpitPlugin:public QObject, public QgisPlugin
     int menuId;
     //! Pointer to our toolbar
     QToolBar *toolBar;
-    //! Pointer to our menu
-    QMenuBar *menu;
     //! Pionter to QGIS main application object
     QgisApp *qgisMainWindow;
     //! Pointer to the QGIS interface object
