@@ -16,8 +16,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsgpxprovider.cpp,v 1.31 2004/11/29 06:48:24 gsherman Exp $ */
+/* $Id: qgsgpxprovider.cpp,v 1.40.2.3 2005/10/12 04:42:40 gsherman Exp $ */
 
+#include <algorithm>
 #include <cfloat>
 #include <iostream>
 #include <limits>
@@ -31,7 +32,6 @@
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qstringlist.h>
-#include <qdom.h>
 #include <qrect.h>
 
 #include "../../src/qgis.h"
@@ -61,6 +61,9 @@ QgsGPXProvider::QgsGPXProvider(QString uri) : mDataSourceUri(uri),
   // assume that it won't work
   mValid = false;
   
+  // we always use UTF-8
+  mEncoding = QTextCodec::codecForName("utf8");
+  
   // get the filename and the type parameter from the URI
   int fileNameEnd = uri.find('?');
   if (fileNameEnd == -1 || uri.mid(fileNameEnd + 1, 5) != "type=") {
@@ -96,17 +99,19 @@ QgsGPXProvider::QgsGPXProvider(QString uri) : mDataSourceUri(uri),
   // set the selection rectangle to null
   mSelectionRectangle = 0;
   
-  // parse the file
-  data = GPSData::getData(mFileName);
-  if (data == 0)
-    return;
-  mValid = true;
-  
   // resize the cache matrix
   mMinMaxCache=new double*[attributeFields.size()];
   for(int i=0;i<attributeFields.size();i++) {
     mMinMaxCache[i]=new double[2];
   }
+
+  // parse the file
+  data = GPSData::getData(mFileName);
+  if (data == 0) {
+    return;
+  }
+
+  mValid = true;
 }
 
 
@@ -119,12 +124,28 @@ QgsGPXProvider::~QgsGPXProvider() {
 }
 
 
+QString QgsGPXProvider::getProjectionWKT() {
+  return 
+    "GEOGCS[\"WGS 84\", "
+    "  DATUM[\"WGS_1984\", "
+    "    SPHEROID[\"WGS 84\",6378137,298.257223563, "
+    "      AUTHORITY[\"EPSG\",7030]], "
+    "    TOWGS84[0,0,0,0,0,0,0], "
+    "    AUTHORITY[\"EPSG\",6326]], "
+    "  PRIMEM[\"Greenwich\",0,AUTHORITY[\"EPSG\",8901]], "
+    "  UNIT[\"DMSH\",0.0174532925199433,AUTHORITY[\"EPSG\",9108]], "
+    "  AXIS[\"Lat\",NORTH], "
+    "  AXIS[\"Long\",EAST], "
+    "  AUTHORITY[\"EPSG\",4326]]";
+}
+
+
 /**
  * Get the first feature resulting from a select operation
  * @return QgsFeature
  */
 QgsFeature *QgsGPXProvider::getFirstFeature(bool fetchAttributes) {
-  mFid = 0;
+  reset();
   return getNextFeature(fetchAttributes);
 }
 
@@ -160,7 +181,7 @@ QgsFeature *QgsGPXProvider::getNextFeature(bool fetchAttributes) {
 }
 
 
-QgsFeature * QgsGPXProvider::getNextFeature(std::list<int>& attlist) {
+QgsFeature * QgsGPXProvider::getNextFeature(std::list<int> const & attlist) {
   QgsFeature* feature = new QgsFeature(-1);
   bool success = getNextFeature(feature, attlist);
   if (success)
@@ -171,7 +192,7 @@ QgsFeature * QgsGPXProvider::getNextFeature(std::list<int>& attlist) {
 
 
 bool QgsGPXProvider::getNextFeature(QgsFeature* feature, 
-				    std::list<int>& attlist) {
+				    std::list<int> const & attlist) {
   bool result = false;
   
   std::list<int>::const_iterator iter;
@@ -179,13 +200,11 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
   if (mFeatureType == WaypointType) {
     // go through the list of waypoints and return the first one that is in
     // the bounds rectangle
-    int maxFid = data->getNumberOfWaypoints();
-    
-    for (; mFid < maxFid; ++mFid) {
+    for (; mWptIter != data->waypointsEnd(); ++mWptIter) {
       const Waypoint* wpt;
-      wpt = &(data->getWaypoint(mFid));
+      wpt = &(*mWptIter);
       if (boundsCheck(wpt->lon, wpt->lat)) {
-	feature->setFeatureId(mFid);
+	feature->setFeatureId(wpt->id);
 	result = true;
 	
 	// some wkb voodoo
@@ -205,7 +224,11 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
 	    feature->addAttribute(attr[NameAttr], wpt->name);
 	    break;
 	  case 1:
+#ifdef WIN32
+	    if (wpt->ele == -1.79769e+308)
+#else
 	    if (wpt->ele == -std::numeric_limits<double>::max())
+#endif
 	      feature->addAttribute(attr[EleAttr], "");
 	    else
 	      feature->addAttribute(attr[EleAttr], QString("%1").arg(wpt->ele));
@@ -231,7 +254,7 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
 	  }
 	}
 	
-	++mFid;
+	++mWptIter;
 	break;
       }
     }
@@ -240,10 +263,9 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
   else if (mFeatureType == RouteType) {
     // go through the routes and return the first one that is in the bounds
     // rectangle
-    int maxFid = data->getNumberOfRoutes();
-    for (; mFid < maxFid; ++mFid) {
+    for (; mRteIter != data->routesEnd(); ++mRteIter) {
       const Route* rte;
-      rte = &(data->getRoute(mFid));
+      rte = &(*mRteIter);
       
       if (rte->points.size() == 0)
 	continue;
@@ -251,7 +273,7 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
       const QgsRect& b(*mSelectionRectangle);
       if ((rte->xMax >= b.xMin()) && (rte->xMin <= b.xMax()) &&
 	  (rte->yMax >= b.yMin()) && (rte->yMin <= b.yMax())) {
-	feature->setFeatureId(mFid);
+	feature->setFeatureId(rte->id);
 	result = true;
 	
 	// some wkb voodoo
@@ -273,7 +295,11 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
 	  if (*iter == 0)
 	    feature->addAttribute(attr[NameAttr], rte->name);
 	  else if (*iter == 1) {
+#ifdef WIN32
+	    if (rte->number == 2147483647)
+#else
 	    if (rte->number == std::numeric_limits<int>::max())
+#endif
 	      feature->addAttribute(attr[NumAttr], "");
 	    else
 	      feature->addAttribute(attr[NumAttr], QString("%1").arg(rte->number));
@@ -290,7 +316,7 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
 	    feature->addAttribute(attr[URLNameAttr], rte->urlname);
 	}
 	
-	++mFid;
+	++mRteIter;
 	break;
       }
     }
@@ -299,10 +325,9 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
   else if (mFeatureType == TrackType) {
     // go through the tracks and return the first one that is in the bounds
     // rectangle
-    int maxFid = data->getNumberOfTracks();
-    for (; mFid < maxFid; ++mFid) {
+    for (; mTrkIter != data->tracksEnd(); ++mTrkIter) {
       const Track* trk;
-      trk = &(data->getTrack(mFid));
+      trk = &(*mTrkIter);
       
       if (trk->segments.size() == 0)
 	continue;
@@ -312,7 +337,7 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
       const QgsRect& b(*mSelectionRectangle);
       if ((trk->xMax >= b.xMin()) && (trk->xMin <= b.xMax()) &&
 	  (trk->yMax >= b.yMin()) && (trk->yMin <= b.yMax())) {
-	feature->setFeatureId(mFid);
+	feature->setFeatureId(trk->id);
 	result = true;
 	
 	// some wkb voodoo
@@ -334,7 +359,11 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
 	  if (*iter == 0)
 	    feature->addAttribute(attr[NameAttr], trk->name);
 	  else if (*iter == 1) {
+#ifdef WIN32
+	    if (trk->number == 2147483647)
+#else
 	    if (trk->number == std::numeric_limits<int>::max())
+#endif
 	      feature->addAttribute(attr[NumAttr], "");
 	    else
 	      feature->addAttribute(attr[NumAttr], QString("%1").arg(trk->number));
@@ -351,7 +380,7 @@ bool QgsGPXProvider::getNextFeature(QgsFeature* feature,
 	    feature->addAttribute(attr[URLNameAttr], trk->urlname);
 	}
 	
-	++mFid;
+	++mTrkIter;
 	break;
       }
     }
@@ -374,8 +403,6 @@ void QgsGPXProvider::select(QgsRect *rect, bool useIntersect) {
   mSelectionRectangle = new QgsRect(*rect);
   // Select implies an upcoming feature read so we reset the data source
   reset();
-  // Reset the feature id to 0
-  mFid = 0;
 }
 
 
@@ -393,7 +420,8 @@ std::vector<QgsFeature>& QgsGPXProvider::identify(QgsRect * rect) {
   // select the features
   select(rect);
   // temporary fix to get this to compile under windows
-  std::vector<QgsFeature> features;
+  // XXX What the heck is going on here?
+  static std::vector<QgsFeature> features;
   return features;
 }
 
@@ -408,20 +436,7 @@ return gPtr;
 
 }
 */
-int QgsGPXProvider::endian() {
-  char *chkEndian = new char[4];
-  memset(chkEndian, '\0', 4);
-  chkEndian[0] = 0xE8;
 
-  int *ce = (int *) chkEndian;
-  int retVal;
-  if (232 == *ce)
-    retVal = NDR;
-  else
-    retVal = XDR;
-  delete[]chkEndian;
-  return retVal;
-}
 
 
 // Return the extent of the layer
@@ -433,7 +448,8 @@ QgsRect *QgsGPXProvider::extent() {
 /** 
  * Return the feature type
  */
-int QgsGPXProvider::geometryType() {
+int QgsGPXProvider::geometryType() const
+{
   return mGeomType;
 }
 
@@ -441,7 +457,8 @@ int QgsGPXProvider::geometryType() {
 /** 
  * Return the feature type
  */
-long QgsGPXProvider::featureCount() {
+long QgsGPXProvider::featureCount() const
+{
   if (mFeatureType == WaypointType)
     return data->getNumberOfWaypoints();
   if (mFeatureType == RouteType)
@@ -455,19 +472,25 @@ long QgsGPXProvider::featureCount() {
 /**
  * Return the number of fields
  */
-int QgsGPXProvider::fieldCount() {
+int QgsGPXProvider::fieldCount() const
+{
   return attributeFields.size();
 }
 
 
-std::vector<QgsField>& QgsGPXProvider::fields(){
+std::vector<QgsField> const & QgsGPXProvider::fields() const
+{
   return attributeFields;
 }
 
 
 void QgsGPXProvider::reset() {
-  // Reset feature id to 0
-  mFid = 0;
+  if (mFeatureType == WaypointType)
+    mWptIter = data->waypointsBegin();
+  else if (mFeatureType == RouteType)
+    mRteIter = data->routesBegin();
+  else if (mFeatureType == TrackType)
+    mTrkIter = data->tracksBegin();
 }
 
 
@@ -546,20 +569,18 @@ bool QgsGPXProvider::addFeatures(std::list<QgsFeature*> flist) {
   }
   
   // write back to file
-  QDomDocument qdd;
-  data->fillDom(qdd);
   QFile file(mFileName);
   if (!file.open(IO_WriteOnly))
     return false;
   QTextStream ostr(&file);
-  ostr<<qdd.toString();
+  ostr.precision(10);
+  data->writeXML(ostr);
   return true;
 }
 
 
 bool QgsGPXProvider::addFeature(QgsFeature* f) {
   unsigned char* geo = f->getGeometry();
-  int featureId;
   bool success = false;
   GPSObject* obj = NULL;
   const std::vector<QgsFeatureAttribute>& attrs(f->attributeMap());
@@ -585,9 +606,9 @@ bool QgsGPXProvider::addFeature(QgsFeature* f) {
       }
     }
     
-    featureId = data->addWaypoint(wpt);
+    GPSData::WaypointIterator iter = data->addWaypoint(wpt);
     success = true;
-    obj = &(data->getWaypoint(featureId));
+    obj = &(*iter);
   }
   
   // is it a route?
@@ -596,11 +617,17 @@ bool QgsGPXProvider::addFeature(QgsFeature* f) {
     Route rte;
     
     // reset bounds
+#ifdef WIN32
+    rte.xMin = 1.79769e+308;
+    rte.xMax = -1.79769e+308;
+    rte.yMin = 1.79769e+308;
+    rte.yMax = -1.79769e+308;
+#else
     rte.xMin = std::numeric_limits<double>::max();
     rte.xMax = -std::numeric_limits<double>::max();
     rte.yMin = std::numeric_limits<double>::max();
     rte.yMax = -std::numeric_limits<double>::max();
-
+#endif
     // add geometry
     int nPoints;
     std::memcpy(&nPoints, geo + 5, 4);
@@ -628,9 +655,9 @@ bool QgsGPXProvider::addFeature(QgsFeature* f) {
       }
     }
     
-    featureId = data->addRoute(rte);
+    GPSData::RouteIterator iter = data->addRoute(rte);
     success = true;
-    obj = &(data->getRoute(featureId));
+    obj = &(*iter);
   }
   
   // is it a track?
@@ -640,10 +667,17 @@ bool QgsGPXProvider::addFeature(QgsFeature* f) {
     TrackSegment trkseg;
     
     // reset bounds
+#ifdef WIN32
+    trk.xMin = 1.79769e+308;
+    trk.xMax = -1.79769e+308;
+    trk.yMin = 1.79769e+308;
+    trk.yMax = -1.79769e+308;
+#else
     trk.xMin = std::numeric_limits<double>::max();
     trk.xMax = -std::numeric_limits<double>::max();
     trk.yMin = std::numeric_limits<double>::max();
     trk.yMax = -std::numeric_limits<double>::max();
+#endif
 
     // add geometry
     int nPoints;
@@ -673,9 +707,9 @@ bool QgsGPXProvider::addFeature(QgsFeature* f) {
     }
     
     trk.segments.push_back(trkseg);
-    featureId = data->addTrack(trk);
+    GPSData::TrackIterator iter = data->addTrack(trk);
     success = true;
-    obj = &(data->getTrack(featureId));
+    obj = &(*iter);
   }
   
   
@@ -707,6 +741,111 @@ bool QgsGPXProvider::addFeature(QgsFeature* f) {
 }
 
 
+bool QgsGPXProvider::deleteFeatures(std::list<int> const & id) {
+  if (mFeatureType == WaypointType)
+    data->removeWaypoints(id);
+  else if (mFeatureType == RouteType)
+    data->removeRoutes(id);
+  else if (mFeatureType == TrackType)
+    data->removeTracks(id);
+
+  // write back to file
+  QFile file(mFileName);
+  if (!file.open(IO_WriteOnly))
+    return false;
+  QTextStream ostr(&file);
+  ostr.precision(10);
+  data->writeXML(ostr);
+  return true;
+}
+
+
+bool QgsGPXProvider::changeAttributeValues(std::map<int,std::map<QString,QString> > const& attr_map) {
+  std::map<int, std::map<QString, QString> >::const_iterator aIter =
+    attr_map.begin();
+  if (mFeatureType == WaypointType) {
+    GPSData::WaypointIterator wIter = data->waypointsBegin();
+    for (; wIter != data->waypointsEnd() && aIter != attr_map.end(); ++wIter) {
+      if (wIter->id == aIter->first) {
+	changeAttributeValues(*wIter, aIter->second);
+	++aIter;
+      }
+    }
+  }
+  else if (mFeatureType == RouteType) {
+    GPSData::RouteIterator rIter = data->routesBegin();
+    for (; rIter != data->routesEnd() && aIter != attr_map.end(); ++rIter) {
+      if (rIter->id == aIter->first) {
+	changeAttributeValues(*rIter, aIter->second);
+	++aIter;
+      }
+    }
+  }
+  if (mFeatureType == TrackType) {
+    GPSData::TrackIterator tIter = data->tracksBegin();
+    for (; tIter != data->tracksEnd() && aIter != attr_map.end(); ++tIter) {
+      if (tIter->id == aIter->first) {
+	changeAttributeValues(*tIter, aIter->second);
+	++aIter;
+      }
+    }
+  }
+
+  // write back to file
+  QFile file(mFileName);
+  if (!file.open(IO_WriteOnly))
+    return false;
+  QTextStream ostr(&file);
+  ostr.precision(10);
+  data->writeXML(ostr);
+  return true;
+}
+
+
+void QgsGPXProvider::changeAttributeValues(GPSObject& obj, 
+					   const std::map<QString, QString>& attrs) {
+  std::map<QString, QString>::const_iterator aIter;
+  
+  // common attributes
+  if ((aIter = attrs.find(attr[NameAttr])) != attrs.end())
+    obj.name = aIter->second;
+  if ((aIter = attrs.find(attr[CmtAttr])) != attrs.end())
+    obj.cmt = aIter->second;
+  if ((aIter = attrs.find(attr[DscAttr])) != attrs.end())
+    obj.desc = aIter->second;
+  if ((aIter = attrs.find(attr[SrcAttr])) != attrs.end())
+    obj.src = aIter->second;
+  if ((aIter = attrs.find(attr[URLAttr])) != attrs.end())
+    obj.url = aIter->second;
+  if ((aIter = attrs.find(attr[URLNameAttr])) != attrs.end())
+    obj.urlname = aIter->second;
+  
+  // waypoint-specific attributes
+  Waypoint* wpt = dynamic_cast<Waypoint*>(&obj);
+  if (wpt != NULL) {
+    if ((aIter = attrs.find(attr[SymAttr])) != attrs.end())
+      wpt->sym = aIter->second;
+    if ((aIter = attrs.find(attr[EleAttr])) != attrs.end()) {
+      bool eleIsOK;
+      double ele = aIter->second.toDouble(&eleIsOK);
+      if (eleIsOK)
+	wpt->ele = ele;
+    }
+  }
+  
+  // route- and track-specific attributes
+  GPSExtended* ext = dynamic_cast<GPSExtended*>(&obj);
+  if (ext != NULL) {
+    if ((aIter = attrs.find(attr[NumAttr])) != attrs.end()) {
+      bool eleIsOK;
+      int number = aIter->second.toInt(&eleIsOK);
+      if (eleIsOK)
+	ext->number = number;
+    }
+  }
+}
+
+
 QString QgsGPXProvider::getDefaultValue(const QString& attr, QgsFeature* f) {
   if (attr == "source")
     return "Digitized in QGIS";
@@ -732,8 +871,8 @@ bool QgsGPXProvider::boundsCheck(double x, double y)
  * Class factory to return a pointer to a newly created 
  * QgsGPXProvider object
  */
-QGISEXTERN QgsGPXProvider * classFactory(const char *uri) {
-  return new QgsGPXProvider(uri);
+QGISEXTERN QgsGPXProvider * classFactory(const QString *uri) {
+  return new QgsGPXProvider(*uri);
 }
 
 
