@@ -40,10 +40,14 @@ class QgsGPXProvider : public QgsVectorDataProvider {
 public:
   QgsGPXProvider(QString uri=0);
   virtual ~QgsGPXProvider();
-/**
-  * Get the first feature resulting from a select operation
-  * @return QgsFeature
-  */
+  
+  /** Used to ask the layer for its projection as a WKT string. Implements 
+      virtual method of same name in QgsDataProvider. */
+  QString getProjectionWKT();
+  /**
+   * Get the first feature resulting from a select operation
+   * @return QgsFeature
+   */
   QgsFeature * getFirstFeature(bool fetchAttributes=false);
   /** 
   * Get the next feature resutling from a select operation
@@ -51,7 +55,7 @@ public:
   */
   QgsFeature * getNextFeature(bool fetchAttributes=false);
   bool getNextFeature(QgsFeature &feature, bool fetchAttributes=false);
-  QgsFeature * getNextFeature(std::list<int>& attlist);
+  QgsFeature * getNextFeature(std::list<int> const & attlist);
   
   /** Get the feature type. This corresponds to 
       WKBPoint,
@@ -63,15 +67,15 @@ public:
   * as defined in qgis.h
   * This provider will always return WKBPoint
   */
-  int geometryType();
+  int geometryType() const;
   /** 
    * Get the number of features in the layer
    */
-  long featureCount();
+  long featureCount() const;
   /** 
    * Get the number of fields in the layer
    */
-  int fieldCount();
+  int fieldCount() const;
   /**
    * Select features based on a bounding rectangle. Features can be retrieved 
    * with calls to getFirstFeature and getNextFeature.
@@ -99,10 +103,6 @@ public:
    */
   virtual std::vector<QgsFeature>& identify(QgsRect *rect);
   
-  /** Return endian-ness for this layer
-   */  
-  int endian();
-  
   /** Return the extent for this data layer
    */
   virtual QgsRect * extent();
@@ -110,7 +110,7 @@ public:
   /**
    * Get the field information for the layer
    */
-  std::vector<QgsField>& fields();
+  std::vector<QgsField> const & fields() const;
   
   /* Reset the layer (ie move the file pointer to the head
      of the file.
@@ -133,6 +133,14 @@ public:
      @return true in case of success and false in case of failure*/
   bool addFeatures(std::list<QgsFeature*> flist);
   
+  bool deleteFeatures(std::list<int> const & id);
+  
+  bool changeAttributeValues(std::map<int,std::map<QString,QString> > const & 
+			     attr_map);
+  
+  void changeAttributeValues(GPSObject& obj, 
+			     const std::map<QString, QString>& attrs);
+  
   /** Adds one feature (used by addFeatures()) */
   bool QgsGPXProvider::addFeature(QgsFeature* f);
   
@@ -148,14 +156,19 @@ public:
    */
   bool boundsCheck(double x, double y);
 
-  bool supportsFeatureAddition(){return true;}
-
-  QgsDataSourceURI *getURI(){return 0;};
+  int capabilities() const {
+    return AddFeatures | DeleteFeatures | ChangeAttributeValues;
+  }
+  
+  QgsDataSourceURI *getURI()
+  {
+      return 0;
+  }
   
  private:
   
   /** Internal function used by the other getNextFeature() functions. */
-  bool getNextFeature(QgsFeature* feature, std::list<int>& attlist);
+  bool getNextFeature(QgsFeature* feature, std::list<int> const & attlist);
 
   bool mEditable;
   GPSData* data;
@@ -176,13 +189,14 @@ public:
   bool mValid;
   int mGeomType;
   long mNumberFeatures;
-  //! Feature id
-  long mFid;
-  enum ENDIAN
-  {
-    NDR = 1,
-    XDR = 0
-  };
+  
+  //! Current waypoint iterator
+  GPSData::WaypointIterator mWptIter;
+  //! Current route iterator
+  GPSData::RouteIterator mRteIter;
+  //! Current track iterator
+  GPSData::TrackIterator mTrkIter;
+
   /**Flag indicating, if the minmaxcache should be renewed (true) or not (false)*/
   bool mMinMaxCacheDirty;
   /**Matrix storing the minimum and maximum values*/
