@@ -33,6 +33,7 @@
 #include "../../src/qgsfeatureattribute.h"
 
 extern "C" {
+#include <gprojects.h>
 #include <gis.h>
 #include <dbmi.h>
 #include <Vect.h>
@@ -54,7 +55,6 @@ QgsGrassProvider::QgsGrassProvider(QString uri):mDataSourceUri(uri)
     time.start();
 
     mValid = false;
-    checkEndian();
     
     // Parse URI 
     QDir dir ( uri );  // it is not a directory in fact
@@ -276,6 +276,8 @@ QgsFeature *QgsGrassProvider::getFirstFeature(bool fetchAttributes)
 
     if ( isEdited() )
 	return 0;
+    
+    if ( mCidxFieldIndex < 0 ) return 0; // No features, no features in this layer
 
     mNextCidx = 0;
 	
@@ -294,6 +296,8 @@ bool QgsGrassProvider::getNextFeature(QgsFeature &feature, bool fetchAttributes)
 
     if ( isEdited() )
 	return 0;
+    
+    if ( mCidxFieldIndex < 0 ) return 0; // No features, no features in this layer
 
     // TODO once clear how to do that 
     return false;
@@ -314,6 +318,8 @@ QgsFeature *QgsGrassProvider::getNextFeature(bool fetchAttributes)
     if ( isEdited() )
 	return 0;
 
+    if ( mCidxFieldIndex < 0 ) return 0; // No features, no features in this layer
+
     std::list<int> attlist;
 
     if ( fetchAttributes ) {
@@ -326,19 +332,21 @@ QgsFeature *QgsGrassProvider::getNextFeature(bool fetchAttributes)
     return ( getNextFeature(attlist) );
 }
 
-QgsFeature* QgsGrassProvider::getNextFeature(std::list<int>& attlist)
+QgsFeature* QgsGrassProvider::getNextFeature(std::list<int> const& attlist)
 {
     int cat, type, id, idx;
     unsigned char *wkb;
     int wkbsize;
 
-    #ifdef QGISDEBUG
+    #if QGISDEBUG > 3
     std::cout << "QgsGrassProvider::getNextFeature( attlist )" << std::endl;
     #endif
 
     if ( isEdited() )
 	return 0;
     
+    if ( mCidxFieldIndex < 0 ) return 0; // No features, no features in this layer
+    
     // Get next line/area id
     int found = 0;
     while ( mNextCidx < mCidxFieldNumCats ) {
@@ -369,7 +377,7 @@ QgsFeature* QgsGrassProvider::getNextFeature(std::list<int>& attlist)
 	}	    
 	wkb = new unsigned char[wkbsize];
 	unsigned char *wkbp = wkb;
-	wkbp[0] = (unsigned char) mEndian;
+	wkbp[0] = (unsigned char) endian();
 	wkbp += 1;
 
 	/* WKB type */
@@ -393,7 +401,7 @@ QgsFeature* QgsGrassProvider::getNextFeature(std::list<int>& attlist)
 
 	wkbsize = 1+4+4+4+npoints*2*8; // size without islands
 	wkb = new unsigned char[wkbsize];
-	wkb[0] = (unsigned char) mEndian;
+	wkb[0] = (unsigned char) endian();
 	int offset = 1;
 
 	/* WKB type */
@@ -436,7 +444,7 @@ QgsFeature* QgsGrassProvider::getNextFeature(std::list<int>& attlist)
 
     f->setGeometry(wkb, wkbsize);
 
-    QgsGrassProvider::setFeatureAttributes( mLayerId, cat, f, attlist );  
+    setFeatureAttributes( mLayerId, cat, f, attlist );  
     
     return f;
 
@@ -474,6 +482,9 @@ void QgsGrassProvider::select(QgsRect *rect, bool useIntersect)
     if ( mMapVersion < mMaps[mapId].version ) {
         update();
     }
+    if ( attributesOutdated(mapId) ) {
+	loadAttributes (mLayers[mLayerId]);
+    }
 
     resetSelection(0);
     
@@ -558,26 +569,6 @@ std::vector<QgsFeature>& QgsGrassProvider::identify(QgsRect * rect)
     }
 }
 
-/* set endian */
-void QgsGrassProvider::checkEndian()
-{
-	char *chkEndian = new char[4];
-	memset(chkEndian, '\0', 4);
-	chkEndian[0] = 0xE8;
-
-	int *ce = (int *) chkEndian;
-	if (232 == *ce)
-	    mEndian = NDR;
-	else
-	    mEndian = XDR;
-	delete[]chkEndian;
-}
-
-int QgsGrassProvider::endian()
-{
-	return mEndian;
-}
-
 QgsRect *QgsGrassProvider::extent()
 {
     BOUND_BOX box;
@@ -589,20 +580,23 @@ QgsRect *QgsGrassProvider::extent()
 /** 
 * Return the feature type
 */
-int QgsGrassProvider::geometryType(){
+int QgsGrassProvider::geometryType() const
+{
     return mQgisType;
 }
 /** 
 * Return the feature type
 */
-long QgsGrassProvider::featureCount(){
+long QgsGrassProvider::featureCount() const 
+{
     return mNumberFeatures;
 }
 
 /**
 * Return the number of fields
 */
-int QgsGrassProvider::fieldCount(){
+int QgsGrassProvider::fieldCount() const
+{
     #ifdef QGISDEBUG
     std::cerr << "QgsGrassProvider::fieldCount() return:" << mLayers[mLayerId].fields.size() << std::endl;
     #endif
@@ -612,12 +606,27 @@ int QgsGrassProvider::fieldCount(){
 /**
 * Return fields
 */
-std::vector<QgsField>& QgsGrassProvider::fields(){
+std::vector<QgsField> const & QgsGrassProvider::fields() const
+{
       return mLayers[mLayerId].fields;
-
 }
 
-void QgsGrassProvider::reset(){
+void QgsGrassProvider::reset()
+{
+    if ( isEdited() )
+	return;
+
+    int mapId = mLayers[mLayerId].mapId;
+    if ( mapOutdated(mapId) ) {
+        updateMap ( mapId );
+    }
+    if ( mMapVersion < mMaps[mapId].version ) {
+        update();
+    }
+    if ( attributesOutdated(mapId) ) {
+	loadAttributes (mLayers[mLayerId]);
+    }
+    
     resetSelection(1);
     mNextCidx = 0;
 }
@@ -692,6 +701,7 @@ int QgsGrassProvider::openLayer(QString gisdbase, QString location, QString maps
     GLAYER layer;
     layer.valid = false;
     layer.field = field; 
+    layer.nUsers = 1; 
 
     // Open map
     layer.mapId = openMap ( gisdbase, location, mapset, mapName );
@@ -737,7 +747,15 @@ void QgsGrassProvider::loadLayerSourcesFromMap ( GLAYER &layer )
 	}
 	free ( layer.attributes );
     }
+    loadAttributes ( layer );
+}
     
+void QgsGrassProvider::loadAttributes ( GLAYER &layer )
+{
+    #ifdef QGISDEBUG
+    std::cerr << "QgsGrassProvider::loadLayerSourcesFromMap" << std::endl;
+    #endif
+
     // Get field info
     layer.fieldInfo = Vect_get_field( layer.map, layer.field); // should work also with field = 0
 
@@ -745,6 +763,7 @@ void QgsGrassProvider::loadLayerSourcesFromMap ( GLAYER &layer )
     layer.nColumns = 0;
     layer.nAttributes = 0;
     layer.attributes = 0;
+    layer.fields.clear();
     layer.keyColumn = -1;
     if ( layer.fieldInfo == NULL ) {
         #ifdef QGISDEBUG
@@ -846,8 +865,10 @@ void QgsGrassProvider::loadLayerSourcesFromMap ( GLAYER &layer )
 			// Check cat value
 			dbColumn *column = db_get_table_column (databaseTable, layer.keyColumn);
 			dbValue *value = db_get_column_value(column);
+			
+			if ( db_test_value_isnull(value) ) continue;
 			layer.attributes[layer.nAttributes].cat = db_get_value_int (value);
-			if ( layer.attributes[layer.nAttributes].cat < 1 ) continue; 
+			if ( layer.attributes[layer.nAttributes].cat < 0 ) continue; 
 
 			layer.attributes[layer.nAttributes].values = (char **) malloc ( layer.nColumns * sizeof(char*) );
 
@@ -921,12 +942,17 @@ void QgsGrassProvider::loadLayerSourcesFromMap ( GLAYER &layer )
 	    }
 	}
     }
+
+    GMAP *map = &(mMaps[layer.mapId]);
+    
+    QFileInfo di ( map->gisdbase + "/" + map->location + "/" + map->mapset + "/vector/" + map->mapName + "/dbln" );
+    map->lastAttributesModified = di.lastModified();
 }
 
 void QgsGrassProvider::closeLayer( int layerId )
 {
     #ifdef QGISDEBUG
-    std::cerr << "Close layer " << layerId << std::endl;
+    std::cerr << "Close layer " << layerId << " nUsers = " << mLayers[layerId].nUsers << std::endl;
     #endif
 
     // TODO: not tested because delete is never used for providers
@@ -943,6 +969,9 @@ void QgsGrassProvider::closeLayer( int layerId )
 	mLayers[layerId].fields.resize(0);
 	
 	// Attributes
+        #ifdef QGISDEBUG
+        std::cerr << "Delete attribute values" << std::endl;
+        #endif
 	for ( int i = 0; i < mLayers[layerId].nAttributes; i++ ) {
 	    free ( mLayers[layerId].attributes[i].values );
 	}
@@ -968,7 +997,7 @@ int QgsGrassProvider::openMap(QString gisdbase, QString location, QString mapset
 
     // Check if this map is already opened
     for ( int i = 0; i <  mMaps.size(); i++) {
-	if ( mMaps[i].path == tmpPath ) 
+	if ( mMaps[i].valid && mMaps[i].path == tmpPath ) 
 	{
 	    // the map is already opened, return map id
             #ifdef QGISDEBUG
@@ -1008,6 +1037,9 @@ int QgsGrassProvider::openMap(QString gisdbase, QString location, QString mapset
     // could be owerwritten)
     QFileInfo di ( gisdbase + "/" + location + "/" + mapset + "/vector/" + mapName );
     map.lastModified = di.lastModified();
+    
+    di.setFile ( gisdbase + "/" + location + "/" + mapset + "/vector/" + mapName + "/dbln" );
+    map.lastAttributesModified = di.lastModified();
 
     // Open vector
     QgsGrass::resetError(); // to "catch" error after Vect_open_old()
@@ -1051,6 +1083,9 @@ void QgsGrassProvider::updateMap ( int mapId )
     QFileInfo di ( map->gisdbase + "/" + map->location + "/" + map->mapset + "/vector/" + map->mapName );
     map->lastModified = di.lastModified();
 
+    di.setFile ( map->gisdbase + "/" + map->location + "/" + map->mapset + "/vector/" + map->mapName + "/dbln" );
+    map->lastAttributesModified = di.lastModified();
+
     // Reopen vector
     QgsGrass::resetError(); // to "catch" error after Vect_open_old()
     Vect_set_open_level (2);
@@ -1081,7 +1116,7 @@ void QgsGrassProvider::updateMap ( int mapId )
 void QgsGrassProvider::closeMap( int mapId )
 {
     #ifdef QGISDEBUG
-    std::cerr << "Close map " << mapId << std::endl;
+    std::cerr << "Close map " << mapId << " nUsers = " << mMaps[mapId].nUsers << std::endl;
     #endif
 
     // TODO: not tested because delete is never used for providers
@@ -1125,6 +1160,28 @@ bool QgsGrassProvider::mapOutdated( int mapId )
     return false;
 }
 
+bool QgsGrassProvider::attributesOutdated( int mapId )
+{
+    #ifdef QGISDEBUG
+    std::cerr << "QgsGrassProvider::attributesOutdated()" << std::endl;
+    #endif
+
+    GMAP *map = &(mMaps[mapId]);
+    
+    QString dp = map->gisdbase + "/" + map->location + "/" + map->mapset + "/vector/" + map->mapName + "/dbln";
+    QFileInfo di ( dp );
+
+    if ( map->lastAttributesModified < di.lastModified() ) {
+	#ifdef QGISDEBUG
+	std::cerr << "**** The attributes of the map " << mapId << " were modified ****" << std::endl;
+	#endif
+	
+	return true;
+    }
+
+    return false;
+}
+
 /** Set feature attributes */
 void QgsGrassProvider::setFeatureAttributes ( int layerId, int cat, QgsFeature *feature )
 {
@@ -1135,12 +1192,14 @@ void QgsGrassProvider::setFeatureAttributes ( int layerId, int cat, QgsFeature *
 	// find cat
 	GATT key;
 	key.cat = cat;
+    
 	GATT *att = (GATT *) bsearch ( &key, mLayers[layerId].attributes, mLayers[layerId].nAttributes,
 		                       sizeof(GATT), cmpAtt);
 
 	for (int i = 0; i < mLayers[layerId].nColumns; i++) {
 	    if ( att != NULL ) {
-		feature->addAttribute ( mLayers[layerId].fields[i].name(), att->values[i]);
+		QCString cstr( att->values[i] );
+		feature->addAttribute ( mLayers[layerId].fields[i].name(), mEncoding->toUnicode(cstr) );
 	    } else { /* it may happen that attributes are missing -> set to empty string */
 		feature->addAttribute ( mLayers[layerId].fields[i].name(), "");
 	    }
@@ -1152,9 +1211,9 @@ void QgsGrassProvider::setFeatureAttributes ( int layerId, int cat, QgsFeature *
     }
 }
 
-void QgsGrassProvider::setFeatureAttributes ( int layerId, int cat, QgsFeature *feature, std::list<int>& attlist)
+void QgsGrassProvider::setFeatureAttributes ( int layerId, int cat, QgsFeature *feature, std::list<int> const& attlist)
 {
-#ifdef QGISDEBUG
+    #if QGISDEBUG > 3
     std::cerr << "setFeatureAttributes cat = " << cat << std::endl;
     #endif
     if ( mLayers[layerId].nColumns > 0 ) {
@@ -1164,9 +1223,10 @@ void QgsGrassProvider::setFeatureAttributes ( int layerId, int cat, QgsFeature *
 	GATT *att = (GATT *) bsearch ( &key, mLayers[layerId].attributes, mLayers[layerId].nAttributes,
 		                       sizeof(GATT), cmpAtt);
 
-	for (std::list<int>::iterator iter=attlist.begin(); iter!=attlist.end();++iter) {
+	for (std::list<int>::const_iterator iter=attlist.begin(); iter!=attlist.end();++iter) {
 	    if ( att != NULL ) {
-		feature->addAttribute ( mLayers[layerId].fields[*iter].name(), att->values[*iter]);	
+		QCString cstr( att->values[*iter] );
+		feature->addAttribute ( mLayers[layerId].fields[*iter].name(), mEncoding->toUnicode(cstr) );
 	    } else { /* it may happen that attributes are missing -> set to empty string */
 		feature->addAttribute ( mLayers[layerId].fields[*iter].name(), "");	
 	    } 
@@ -1184,6 +1244,30 @@ struct Map_info *QgsGrassProvider::layerMap ( int layerId )
     return ( mMaps[mLayers[layerId].mapId].map );
 }
 
+QString QgsGrassProvider::getProjectionWKT(void)
+{
+    QString WKT;
+
+    struct Cell_head cellhd;
+
+    QgsGrass::setLocation ( mGisdbase, mLocation ); 
+    G_get_default_window(&cellhd);
+    if (cellhd.proj != PROJECTION_XY) {
+        struct Key_Value *projinfo = G_get_projinfo();
+        struct Key_Value *projunits = G_get_projunits();
+	char *wkt = GPJ_grass_to_wkt ( projinfo, projunits,  0, 0 );
+	WKT = QString(wkt);
+	free ( wkt);
+    }
+    
+    return WKT;
+}
+
+int QgsGrassProvider::grassLayer()
+{
+	return mLayerField;
+}
+
 //-----------------------------------------  Edit -------------------------------------------------------
 
 bool QgsGrassProvider::isGrassEditable ( void )
@@ -1206,7 +1290,7 @@ bool QgsGrassProvider::isGrassEditable ( void )
 
 bool QgsGrassProvider::isEdited ( void )
 {
-    #ifdef QGISDEBUG
+    #if QGISDEBUG > 3
     std::cerr << "QgsGrassProvider::isEdited" << std::endl;
     #endif
 
@@ -1246,14 +1330,36 @@ bool QgsGrassProvider::startEdit ( void )
 
     // TODO: Catch error 
      
+    QgsGrass::resetError();
     int level = Vect_open_update ( map->map, (char *) map->mapName.ascii(), (char *) map->mapset.ascii() );
-
     if (  level < 2 ) { 
-	std::cerr << "Cannot open vector for update on level 2." << std::endl;
-	// TODO reopen vector for reading
+	if ( QgsGrass::getError() == QgsGrass::FATAL ) {
+	    std::cerr << "Cannot open GRASS vector for update: " << QgsGrass::getErrorMessage() << std::endl;
+	} else {
+	    std::cerr << "Cannot open GRASS vector for update on level 2." << std::endl;
+	}
+	
+	// reopen vector for reading
+	QgsGrass::resetError();
+	Vect_set_open_level (2);
+        level = Vect_open_old ( map->map, (char *) map->mapName.ascii(), (char *) map->mapset.ascii() );
+    
+	if ( level < 2 ) {
+	    if ( QgsGrass::getError() == QgsGrass::FATAL ) {
+		std::cerr << "Cannot reopen GRASS vector: " << QgsGrass::getErrorMessage() << std::endl;
+	    } else {
+		std::cerr << "Cannot reopen GRASS vector on level 2." << std::endl;
+	    }
+	} else {
+	    map->valid = true;
+	}
+	
 	return false;
     }
 
+    // Write history
+    Vect_hist_command ( map->map );
+
     #ifdef QGISDEBUG
     std::cerr << "Vector successfully reopened for update." << std::endl;
     #endif
@@ -1296,6 +1402,9 @@ bool QgsGrassProvider::closeEdit ( void )
     QFileInfo di ( mGisdbase + "/" + mLocation + "/" + mMapset + "/vector/" + mMapName );
     map->lastModified = di.lastModified();
 
+    di.setFile ( mGisdbase + "/" + mLocation + "/" + mMapset + "/vector/" + mMapset + "/dbln" );
+    map->lastAttributesModified = di.lastModified();
+
     // Reopen vector
     QgsGrass::resetError(); // to "catch" error after Vect_open_old()
     Vect_set_open_level (2);
@@ -1602,6 +1711,7 @@ std::vector<QgsField> *QgsGrassProvider::columns ( int field )
     #ifdef QGISDEBUG
     std::cerr << "Field info found -> open database" << std::endl;
     #endif
+    QgsGrass::setMapset ( mGisdbase, mLocation, mMapset ); 
     dbDriver *driver = db_start_driver_open_database ( fi->driver, fi->database );
 
     if ( driver == NULL ) {
@@ -1673,6 +1783,7 @@ std::vector<QgsFeatureAttribute> *QgsGrassProvider::attributes ( int field, int
     #ifdef QGISDEBUG
     std::cerr << "Field info found -> open database" << std::endl;
     #endif
+    QgsGrass::setMapset ( mGisdbase, mLocation, mMapset ); 
     dbDriver *driver = db_start_driver_open_database ( fi->driver, fi->database );
 
     if ( driver == NULL ) {
@@ -1724,9 +1835,10 @@ std::vector<QgsFeatureAttribute> *QgsGrassProvider::attributes ( int field, int
     for (int i = 0; i < nColumns; i++) {
 	dbColumn *column = db_get_table_column (databaseTable, i);
 	db_convert_column_value_to_string (column, &dbstr);
-	std::cerr << "Value: " << db_get_string(&dbstr) << std::endl;
-        att->push_back ( QgsFeatureAttribute( db_get_column_name(column), 
-		                              db_get_string(&dbstr) ) );
+
+        QString v = mEncoding->toUnicode(db_get_string(&dbstr));
+	std::cerr << "Value: " << v << std::endl;
+        att->push_back ( QgsFeatureAttribute( db_get_column_name(column), v ) );
     }
 
     db_close_cursor (&databaseCursor);
@@ -1757,6 +1869,7 @@ QString *QgsGrassProvider::updateAttributes ( int field, int cat, const QString
     #ifdef QGISDEBUG
     std::cerr << "Field info found -> open database" << std::endl;
     #endif
+    QgsGrass::setMapset ( mGisdbase, mLocation, mMapset ); 
     dbDriver *driver = db_start_driver_open_database ( fi->driver, fi->database );
 
     if ( driver == NULL ) {
@@ -1773,8 +1886,27 @@ QString *QgsGrassProvider::updateAttributes ( int field, int cat, const QString
     db_init_string (&dbstr);
     QString query;
     
-    query.sprintf("update %s set %s where %s = %d", fi->table, values.latin1(), fi->key, cat );
-    db_set_string (&dbstr, (char *)query.latin1());
+    query = "update " + QString(fi->table) + " set " + values + " where " + QString(fi->key) 
+	    + " = " + QString::number(cat);
+
+    #ifdef QGISDEBUG
+    std::cerr << "query: " << query << std::endl;
+    #endif
+
+    // For some strange reason, mEncoding->fromUnicode(query) does not work, 
+    // but probably it is not correct, because Qt widgets will use current locales for input
+    //  -> it is possible to edit only in current locales at present
+    // QCString qcs = mEncoding->fromUnicode(query);
+
+    QCString qcs = query.local8Bit();
+    #ifdef QGISDEBUG
+    std::cerr << "qcs: " << qcs << std::endl;
+    #endif
+    
+    char *cs = new char[qcs.length() + 1];
+    strcpy(cs, (const char *)qcs);
+    db_set_string (&dbstr, cs );
+    delete[] cs;
     
     #ifdef QGISDEBUG
     std::cerr << "SQL: " << db_get_string(&dbstr) << std::endl;
@@ -1846,6 +1978,7 @@ QString *QgsGrassProvider::createTable ( int field, const QString &key, const QS
         fi = Vect_default_field_info ( mMap, field, NULL, GV_MTABLE );
     }
     
+    QgsGrass::setMapset ( mGisdbase, mLocation, mMapset ); 
     dbDriver *driver = db_start_driver_open_database ( fi->driver, fi->database );
 
     if ( driver == NULL ) {
@@ -1913,6 +2046,7 @@ QString *QgsGrassProvider::addColumn ( int field, const QString &column )
     #ifdef QGISDEBUG
     std::cerr << "Field info found -> open database" << std::endl;
     #endif
+    QgsGrass::setMapset ( mGisdbase, mLocation, mMapset ); 
     dbDriver *driver = db_start_driver_open_database ( fi->driver, fi->database );
 
     if ( driver == NULL ) {
@@ -1970,6 +2104,7 @@ QString *QgsGrassProvider::insertAttributes ( int field, int cat )
     #ifdef QGISDEBUG
     std::cerr << "Field info found -> open database" << std::endl;
     #endif
+    QgsGrass::setMapset ( mGisdbase, mLocation, mMapset ); 
     dbDriver *driver = db_start_driver_open_database ( fi->driver, fi->database );
 
     if ( driver == NULL ) {
@@ -2009,7 +2144,7 @@ QString *QgsGrassProvider::insertAttributes ( int field, int cat )
 
 // -------------------------------------------------------------------------------
 
-int QgsGrassProvider::cidxGetNumFields( void ) 
+int QgsGrassProvider::cidxGetNumFields( ) 
 {
     return ( Vect_cidx_get_num_fields(mMap) );
 }
