@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/*  $Id: qgisapp.h,v 1.118 2004/11/20 13:46:58 timlinux Exp $ */
+/*  $Id: qgisapp.h,v 1.136.2.3 2005/09/09 22:08:07 mcoletti Exp $ */
 
 #ifndef QGISAPP_H
 #define QGISAPP_H
@@ -35,6 +35,7 @@ class QListViewItem;
 class QProgressBar;
 class QFileInfo;
 class QgsMapLayer;
+class QSettings;
 class QSocket;
 class QgsProviderRegistry;
 class QgsHelpViewer;
@@ -43,6 +44,8 @@ class QgsMapLayerRegistry;
 class QgsRasterLayer;
 class QCheckBox;
 class QEvent;
+class QgsComposer;
+class QPushButton;
 #ifdef WIN32
 #include "qgisappbase.h"
 #else
@@ -51,6 +54,9 @@ class QEvent;
 #include "qgisiface.h"
 #include "splashscreen.h"
 #include "qgsconfig.h"
+#include "qgsvectordataprovider.h"
+
+#include <map>
 
 static SplashScreen * gSplashScreen ;
 
@@ -80,7 +86,7 @@ public:
     void addVectorLayer(QString vectorLayerPath, QString baseName, QString providerKey);
     /** \brief overloaded vesion of the privat addLayer method that takes a list of
     * filenames instead of prompting user with a dialog.
-
+    @param enc encoding type for the layer 
     @returns true if successfully added layer
 
     @note
@@ -90,11 +96,12 @@ public:
     It's much better to try to just open one file at a time.
 
     */
-    bool addLayer(QStringList const & theLayerQStringList);
+    bool addLayer(QStringList const & theLayerQStringList, const QString& enc);
 
     /** open a vector layer for the given file
 
-      @returns false if unable to open a raster layer for rasterFile
+    
+    @returns false if unable to open a raster layer for rasterFile
 
       @note
 
@@ -138,6 +145,18 @@ public:
 
     //! Remove all layers from the map and legend - reimplements same method from qgisappbase
     void removeAllLayers();
+
+    /** Open a raster or vector file; ignore other files.
+    Used to process a commandline argument or OpenDocument AppleEvent.
+    @returns true if the file is successfully opened
+    */
+    bool openLayer(const QString & fileName);
+
+    /** Open the specified project file; prompt to save previous project if necessary.
+    Used to process a commandline argument or OpenDocument AppleEvent.
+    */
+    void openProject(const QString & fileName);
+
     /** opens a qgis project file
     @returns false if unable to open the project
 
@@ -183,7 +202,13 @@ private:
 
     //! Exit Qgis
     void fileExit();
-
+    
+    //! add this file to the recently opened/saved projects list
+    //  pass settings by reference since creating more than one
+    //! instance simultaneously results in data loss.
+    void saveRecentProjectPath(QString projectPath, QSettings & settings);
+    //! Update file menu with the current list of recently accessed projects
+    void updateRecentProjectPaths();
     //! Set map tool to Zoom out
     void zoomOut();
     //! Set map tool to Zoom in
@@ -198,6 +223,8 @@ private:
     void pan();
     //! Identify feature(s) on the currently selected layer
     void identify();
+    //! Measure distance
+    void measure();
     //! show the attribute table for the currently selected layer
     void attributeTable();
     /**Deletes the selected attributes for the currently selected vector layer*/
@@ -223,6 +250,8 @@ private:
     //! check to see if file is dirty and if so, prompt the user th save it
     int saveDirty();
 
+
+    
 private slots:
 
     //! reimplements widget keyPress event so we can check if cancel was pressed
@@ -266,6 +295,11 @@ private slots:
     void loadPlugin(QString name, QString description, QString mFullPath);
     //! Add a plugin menu to the main Plugins menu
     int addPluginMenu(QString menuText, QPopupMenu *menu);
+
+    QPopupMenu* getPluginMenu(QString menuName);
+
+    void removePluginMenuItem(QString name, int menuId);
+
     //! Add an icon to the plugin toolbar
     int addPluginToolBarIcon (QAction * qAction);
     //! Remove an icon from the plugin toolbar
@@ -278,6 +312,9 @@ private slots:
     void fileSave();
     //! Save project as
     void fileSaveAs();
+    //! Open the project file corresponding to the
+    //! path at the given index in mRecentProjectPaths
+    void openProject(int pathIndex);
     //! Save the map view as an image - user is prompted for image name using a dialog
     void saveMapAsImage();
     //! Open a project
@@ -298,9 +335,6 @@ private slots:
     void hideAllLayers();
     //reimplements method from base (gui) class
     void showAllLayers();
-
-
-
     //! Export current view as a mapserver map file
     void exportMapServer();
     //! Return pointer to the active layer
@@ -317,6 +351,8 @@ private slots:
     void openURL(QString url, bool useQgisDocDirectory=true);
     //! Check qgis version against the qgis version server
     void checkQgisVersion();
+    //!Invoke the custom projection dialog
+    void actionCustomProjection_activated(); 
     //! options dialog slot
     void options();
     //! Whats-this help slot
@@ -333,11 +369,17 @@ private slots:
     void socketError(int e);
     //! Set project properties, including map untis
     void projectProperties();
+    //! Open project properties dialog and show the projections tab
+    void projectPropertiesProjections();
     /*  void urlData(); */
     /** Used to (re)set the zordering of the overview map*/
     void setOverviewZOrder(QgsLegend * );
     //! Kills the splash screen
     void killSplashScreen();
+    //! Show the spatial bookmarks dialog
+    void actionShowBookmarks_activated();
+    //! Create a new spatial bookmark
+    void actionNewBookmark_activated();
 
 public slots:
     void showProgress(int theProgress, int theTotalSteps);
@@ -345,6 +387,10 @@ public slots:
     void showStatusMessage(QString theMessage);
     void setLayerOverviewStatus(QString theLayerId, bool theVisibilityFlag);
     void drawExtentRectangle(QPainter *);
+    void updateMouseCoordinatePrecision();
+    void projectionsEnabled(bool theFlag);
+//    void debugHook();
+    void stopZoom();
 
 signals:
     /** emitted when a key is pressed and we want non widget sublasses to be able
@@ -375,6 +421,9 @@ signals:
     */
     void newProject();
 
+    /** emitted when a new bookmark is added 
+     */
+    void bookmarkAdded();
 private:
 
     /// QgisApp aren't copyable
@@ -382,7 +431,7 @@ private:
 
     /// QgisApp aren't copyable
     QgisApp & operator=( QgisApp const & );
-
+    
     //! A central registry that keeps track of all loaded layers.
     // prefer QgsMapLayerRegistry::instance() to emphasize Singleton
     ///QgsMapLayerRegistry * mMapLayerRegistry;
@@ -394,6 +443,8 @@ private:
     QProgressBar * mProgressBar;
     //! Widget used to suppress rendering
     QCheckBox * mRenderSuppresionCBox;
+    //! Widget in status bar used to show status of on the fly projection
+    QToolButton * mOnTheFlyProjectionStatusButton;
     //! Popup menu
     QPopupMenu * mPopupMenu;
     //! Top level plugin menu
@@ -422,6 +473,8 @@ private:
     QRect *mMapWindow;
     //! Current map tool
     int mMapTool;
+    //! The previously selected non zoom map tool.
+    int mPreviousNonZoomMapTool;
     //QCursor *mCursorZoomIn; //doesnt seem to be used anymore (TS)
     QString mStartupPath;
     //! full path name of the current map file (if it has been saved or loaded)
@@ -445,6 +498,31 @@ private:
     std::map<QString, int>mMenuMapByName;
     //! menu map (key is menu id, value is name)
     std::map<int, QString>mMenuMapById;
+    //! list of recently opened/saved project files
+    QStringList mRecentProjectPaths;
+
+    //! Map composer
+    QgsComposer *mComposer;
+
+    //! How to determine the number of decimal places used to
+    //! display the mouse position
+    bool mMousePrecisionAutomatic;
+    //! The number of decimal places to use if not automatic
+    unsigned int mMousePrecisionDecimalPlaces;
+    //! Flag to indicate how the project properties dialog was summoned
+    bool mShowProjectionTab;
+
+    /** String containing supporting vector file formats 
+
+       Suitable for a QFileDialog file filter.  Build in ctor.
+    */
+    QString mVectorFileFilter;
+
+    /** String containing supporting raster file formats 
+
+       Suitable for a QFileDialog file filter.  Build in ctor.
+    */
+    QString mRasterFileFilter;
 };
 
 #endif
