@@ -301,3 +301,30 @@ void QgisAppBase::zoomToLayerExtent()
 {
 
 }
+
+
+
+
+
+void QgisAppBase::measure()
+{
+
+}
+
+
+void QgisAppBase::actionCustomProjection_activated()
+{
+
+}
+
+
+void QgisAppBase::actionShowBookmarks_activated()
+{
+
+}
+
+
+void QgisAppBase::actionNewBookmark_activated()
+{
+
+}
