@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgisiface.cpp,v 1.24 2004/11/17 16:27:01 mcoletti Exp $ */
+/* $Id: qgisiface.cpp,v 1.25 2005/04/27 05:21:34 g_j_m Exp $ */
 #include <iostream>
 #include <qstring.h>
 #include <qmenubar.h>
@@ -100,6 +100,16 @@ int QgisIface::addMenu(QString menuText, QPopupMenu * menu)
   // add the menu to the master Plugins menu
   return qgis->addPluginMenu(menuText, menu);
 }
+QPopupMenu* QgisIface::getPluginMenu(QString menuName)
+{
+  return qgis->getPluginMenu(menuName);
+}
+
+void QgisIface::removePluginMenuItem(QString name, int menuId)
+{
+  qgis->removePluginMenuItem(name, menuId);
+}
+
 int QgisIface::addToolBarIcon(QAction * qAction)
 {
   // add the menu to the master Plugins menu
