@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgisiface.h,v 1.20 2004/11/17 16:27:02 mcoletti Exp $ */
+/* $Id: qgisiface.h,v 1.21 2005/04/27 05:21:34 g_j_m Exp $ */
 #ifndef QGISIFACE_H
 #define QGISIFACE_H
 #include "qgisinterface.h"
@@ -60,6 +60,11 @@ class QgisIface : public QgisInterface{
         QString activeLayerSource();
         //! Add a menu to the main menu bar of the application, positioned to the left of Help
         int addMenu(QString menuText, QPopupMenu *menu);
+
+	QPopupMenu* getPluginMenu(QString menuName);
+
+	void removePluginMenuItem(QString name, int menuId);
+
         //! Add an icon to the plugins toolbar
         int addToolBarIcon(QAction *qAction);
         //! Remove an icon (action) from the plugin toolbar
