@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsattributetabledisplay.h,v 1.6 2004/10/16 21:59:14 gsherman Exp $ */
+/* $Id: qgsattributetabledisplay.h,v 1.14.2.1 2005/06/11 12:39:43 mhugent Exp $ */
 
 #ifndef QGSATTRIBUTETABLEDISPLAY_H
 #define QGSATTRIBUTETABLEDISPLAY_H
@@ -24,21 +24,34 @@
 #else
 #include "qgsattributetablebase.uic.h"
 #endif
+
 class QgsAttributeTable;
+class QgsVectorLayer;
+class QPopupMenu;
+
 /**
   *@author Gary E.Sherman
   */
 
 class QgsAttributeTableDisplay:public QgsAttributeTableBase
 {
+  Q_OBJECT
   public:
-	QgsAttributeTableDisplay();
-	~QgsAttributeTableDisplay();
-	QgsAttributeTable *table();
-	void setTitle(QString title);
- signals:
-	/**Is emitted before the widget deletes itself*/
-	void deleted();
+    QgsAttributeTableDisplay(QgsVectorLayer* layer);
+    ~QgsAttributeTableDisplay();
+    QgsAttributeTable *table();
+    void setTitle(QString title);
+  protected:
+    QgsVectorLayer* mLayer;
+
+    protected slots:
+      void deleteAttributes();
+    void addAttribute();
+    void startEditing();
+    void stopEditing();
+    void selectedToTop();
+    void invertSelection();
+    void removeSelection();
 };
 
 #endif
