@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgscontinuouscolrenderer.cpp,v 1.31 2004/11/27 19:19:16 gsherman Exp $ */
+/* $Id: qgscontinuouscolrenderer.cpp,v 1.34.2.2 2005/08/08 18:24:58 gsherman Exp $ */
 #include "qgscontinuouscolrenderer.h"
 #include "qgis.h"
 #include "qgsvectorlayer.h"
@@ -22,6 +22,7 @@
 #include "qgslegenditem.h"
 #include "qgscontcoldialog.h"
 #include "qgssymbologyutils.h"
+#include "qgsmarkercatalogue.h"
 #include <qdom.h>
 
 QgsContinuousColRenderer::~QgsContinuousColRenderer()
@@ -56,6 +57,7 @@ void QgsContinuousColRenderer::setMaximumItem(QgsRenderItem * it)
 
 void QgsContinuousColRenderer::initializeSymbology(QgsVectorLayer * layer, QgsDlgVectorLayerProperties * pr)
 {
+    mVectorType = layer->vectorType();
     bool toproperties = false;    //if false: rendererDialog is associated with the vector layer and image is rendered, true: rendererDialog is associated with buffer dialog of vector layer properties and no image is rendered
     if (pr)
     {
@@ -156,7 +158,8 @@ void QgsContinuousColRenderer::initializeSymbology(QgsVectorLayer * layer, QgsDl
     }
 }
 
-void QgsContinuousColRenderer::renderFeature(QPainter * p, QgsFeature * f, QPicture* pic, double* scalefactor, bool selected)
+void QgsContinuousColRenderer::renderFeature(QPainter * p, QgsFeature * f, QPicture* pic, 
+	double* scalefactor, bool selected, int oversampling, double widthScale)
 {
     if ((mMinimumItem && mMaximumItem))
     {
@@ -170,27 +173,17 @@ void QgsContinuousColRenderer::renderFeature(QPainter * p, QgsFeature * f, QPict
   
   QColor mincolor, maxcolor;
   
-  unsigned char *feature = f->getGeometry();
-  int wkbType;
-  // FIX for the endian problem on osx (possibly sparc?)
-  // TODO Restructure this whole wkb reading code to use
-  // wkb structures as defined at (among other places):
-  // http://publib.boulder.ibm.com/infocenter/db2help/index.jsp?topic=/com.ibm.db2.udb.doc/opt/rsbp4121.htm
-  memcpy(&wkbType, (feature+1), sizeof(wkbType));
-
-
-  
-  if (wkbType == QGis::WKBLineString || wkbType == QGis::WKBMultiLineString || wkbType == QGis::WKBPoint)
-        {
+  if ( mVectorType == QGis::Line || mVectorType == QGis::Point )
+  {
       mincolor = mMinimumItem->getSymbol()->pen().color();
       maxcolor = mMaximumItem->getSymbol()->pen().color();
   } 
-  else                    //if(point or polygon)
-        {
+  else                    //if polygon
+  {
       p->setPen(mMinimumItem->getSymbol()->pen());
       mincolor = mMinimumItem->getSymbol()->fillColor();
       maxcolor = mMaximumItem->getSymbol()->fillColor();
-        }
+  }
 
   int red,green,blue;
 
@@ -206,10 +199,39 @@ void QgsContinuousColRenderer::renderFeature(QPainter * p, QgsFeature * f, QPict
       green = int (mincolor.green());
       blue = int (mincolor.blue());
   }
+      
+  if ( mVectorType == QGis::Point && pic) {
+      // TODO we must get always new marker -> slow, but continuous color for points 
+      // probably is not used frequently
 
-  if (wkbType == QGis::WKBLineString || wkbType == QGis::WKBMultiLineString ||wkbType == QGis::WKBPoint)
-        {
-      p->setPen(QPen(QColor(red, green, blue),mMinimumItem->getSymbol()->pen().width()));//make sure the correct line width is used
+      QgsSymbol *sym = mMinimumItem->getSymbol();
+
+      // Use color for both pen and brush (user can add another layer with outpine)
+      // later add support for both pen and brush to dialog
+      QPen pen = sym->pen();
+      pen.setColor ( QColor(red, green, blue) );
+      pen.setWidth ( (int) ( widthScale * pen.width() ) );
+
+      QBrush brush = sym->brush();
+
+      if ( selected ) {
+          pen.setColor ( mSelectionColor );
+          brush.setColor ( mSelectionColor );
+      } else {
+          brush.setColor ( QColor(red, green, blue) );
+      }
+      brush.setStyle ( Qt::SolidPattern );
+      
+      // Always with oversampling 0
+      *pic = QgsMarkerCatalogue::instance()->marker ( sym->pointSymbolName(), sym->pointSize(),
+	                                      pen, brush, 0 );
+
+      if ( scalefactor ) *scalefactor = 1;
+  } 
+  else if ( mVectorType == QGis::Line )
+  {
+      p->setPen( QPen(QColor(red, green, blue),
+		 (int)(widthScale*mMinimumItem->getSymbol()->pen().width()) ));//make sure the correct line width is used
   } 
   else
         {
@@ -231,6 +253,8 @@ void QgsContinuousColRenderer::renderFeature(QPainter * p, QgsFeature * f, QPict
 
 void QgsContinuousColRenderer::readXML(const QDomNode& rnode, QgsVectorLayer& vl)
 {
+    mVectorType = vl.vectorType();
+
     QgsSymbol* lsy = new QgsSymbol(); 
     QgsSymbol* usy = new QgsSymbol();
     QPen lpen, upen;
@@ -290,11 +314,11 @@ void QgsContinuousColRenderer::readXML(const QDomNode& rnode, QgsVectorLayer& vl
 
     QDomElement ufillcelement = usymbol.namedItem("fillcolor").toElement();
     red = ufillcelement.attribute("red").toInt();
-    qWarning("red: " + QString::number(red));
+    qWarning("red: " + QString::number(red).local8Bit());
     green = ufillcelement.attribute("green").toInt();
-    qWarning("green: " + QString::number(green));
+    qWarning("green: " + QString::number(green).local8Bit());
     blue = ufillcelement.attribute("blue").toInt();
-    qWarning("blue: " + QString::number(blue));
+    qWarning("blue: " + QString::number(blue).local8Bit());
     ubrush.setColor(QColor(red, green, blue));
 
     QDomElement ufillpelement = usymbol.namedItem("fillpattern").toElement();
@@ -327,8 +351,9 @@ void QgsContinuousColRenderer::readXML(const QDomNode& rnode, QgsVectorLayer& vl
 
 void QgsContinuousColRenderer::writeXML(std::ostream& xml)
 {
+  // Always use utf8 in XML?
     xml << "\t\t<continuoussymbol>\n";
-    xml << "\t\t\t<classificationfield>" << QString::number(this->classificationField()) <<
+    xml << "\t\t\t<classificationfield>" << QString::number(this->classificationField()).utf8() <<
   "</classificationfield>\n";
 
 
@@ -336,24 +361,24 @@ void QgsContinuousColRenderer::writeXML(std::ostream& xml)
     QgsSymbol *lsymbol = lowestitem->getSymbol();
     xml << "\t\t\t<lowestitem>\n";
     xml << "\t\t\t\t<renderitem>\n";
-    xml << "\t\t\t\t<value>" << lowestitem->value() << "</value>\n";
+    xml << "\t\t\t\t<value>" << lowestitem->value().utf8() << "</value>\n";
     xml << "\t\t\t\t\t<symbol>\n";
     xml << "\t\t\t\t\t\t<outlinecolor red=\"" 
-      << QString::number(lsymbol->pen().color().red()) 
+        << QString::number(lsymbol->pen().color().red()).utf8()
       << "\" green=\"" 
-      << QString::number(lsymbol->pen().color().green())
+        << QString::number(lsymbol->pen().color().green()).utf8()
       <<  "\" blue=\"" 
-      << QString::number(lsymbol->pen().color().blue()) 
+        << QString::number(lsymbol->pen().color().blue()).utf8() 
       << "\" />\n";
-    xml << "\t\t\t\t\t\t<outlinestyle>" << QgsSymbologyUtils::penStyle2QString(lsymbol->pen().style()) << "</outlinestyle>\n";
-    xml << "\t\t\t\t\t\t<outlinewidth>" << QString::number(lsymbol->pen().width()) << "</outlinewidth>\n";
-    xml << "\t\t\t\t\t\t<fillcolor red=\"" << QString::number(lsymbol->brush().color().red()) << "\" green=\"" <<
-  QString::number(lsymbol->brush().color().green()) << "\" blue=\"" <<
-  QString::number(lsymbol->brush().color().blue()) << "\" />\n";
-    xml << "\t\t\t\t\t\t<fillpattern>" << QgsSymbologyUtils::brushStyle2QString(lsymbol->brush().style()) <<
+    xml << "\t\t\t\t\t\t<outlinestyle>" << QgsSymbologyUtils::penStyle2QString(lsymbol->pen().style()).utf8() << "</outlinestyle>\n";
+    xml << "\t\t\t\t\t\t<outlinewidth>" << QString::number(lsymbol->pen().width()).utf8() << "</outlinewidth>\n";
+    xml << "\t\t\t\t\t\t<fillcolor red=\"" << QString::number(lsymbol->brush().color().red()).utf8() << "\" green=\"" <<
+  QString::number(lsymbol->brush().color().green()).utf8() << "\" blue=\"" <<
+  QString::number(lsymbol->brush().color().blue()).utf8() << "\" />\n";
+    xml << "\t\t\t\t\t\t<fillpattern>" << QgsSymbologyUtils::brushStyle2QString(lsymbol->brush().style()).utf8() <<
   "</fillpattern>\n";
     xml << "\t\t\t\t\t</symbol>\n";
-    xml << "\t\t\t\t\t<label>" << lowestitem->label() << "</label>\n";
+    xml << "\t\t\t\t\t<label>" << lowestitem->label().utf8() << "</label>\n";
     xml << "\t\t\t\t</renderitem>\n";
     xml << "\t\t\t</lowestitem>\n";
 
@@ -361,21 +386,21 @@ void QgsContinuousColRenderer::writeXML(std::ostream& xml)
     QgsSymbol *hsymbol = highestitem->getSymbol();
     xml << "\t\t\t<highestitem>\n";
     xml << "\t\t\t\t<renderitem>\n";
-    xml << "\t\t\t\t<value>" << highestitem->value() << "</value>\n";
+    xml << "\t\t\t\t<value>" << highestitem->value().utf8() << "</value>\n";
     xml << "\t\t\t\t\t<symbol>\n";
-    xml << "\t\t\t\t\t\t<outlinecolor red=\"" << QString::number(hsymbol->pen().color().red()) << "\" green=\"" <<
-  QString::number(hsymbol->pen().color().green()) << "\" blue=\"" << QString::number(hsymbol->pen().color().blue()) <<
+    xml << "\t\t\t\t\t\t<outlinecolor red=\"" << QString::number(hsymbol->pen().color().red()).utf8() << "\" green=\"" <<
+  QString::number(hsymbol->pen().color().green()).utf8() << "\" blue=\"" << QString::number(hsymbol->pen().color().blue()).utf8() <<
   "\" />\n";
-    xml << "\t\t\t\t\t\t<outlinestyle>" << QgsSymbologyUtils::penStyle2QString(hsymbol->pen().style()) <<
+    xml << "\t\t\t\t\t\t<outlinestyle>" << QgsSymbologyUtils::penStyle2QString(hsymbol->pen().style()).utf8() <<
   "</outlinestyle>\n";
-    xml << "\t\t\t\t\t\t<outlinewidth>" << QString::number(hsymbol->pen().width()) << "</outlinewidth>\n";
-    xml << "\t\t\t\t\t\t<fillcolor red=\"" << QString::number(hsymbol->brush().color().red()) << "\" green=\"" <<
-  QString::number(hsymbol->brush().color().green()) << "\" blue=\"" <<
-  QString::number(hsymbol->brush().color().blue()) << "\" />\n";
-    xml << "\t\t\t\t\t\t<fillpattern>" << QgsSymbologyUtils::brushStyle2QString(hsymbol->brush().style()) <<
+    xml << "\t\t\t\t\t\t<outlinewidth>" << QString::number(hsymbol->pen().width()).utf8() << "</outlinewidth>\n";
+    xml << "\t\t\t\t\t\t<fillcolor red=\"" << QString::number(hsymbol->brush().color().red()).utf8() << "\" green=\"" <<
+  QString::number(hsymbol->brush().color().green()).utf8() << "\" blue=\"" <<
+  QString::number(hsymbol->brush().color().blue()).utf8() << "\" />\n";
+    xml << "\t\t\t\t\t\t<fillpattern>" << QgsSymbologyUtils::brushStyle2QString(hsymbol->brush().style()).utf8() <<
   "</fillpattern>\n";
     xml << "\t\t\t\t\t</symbol>\n";
-    xml << "\t\t\t\t\t<label>" << highestitem->label() << "</label>\n";
+    xml << "\t\t\t\t\t<label>" << highestitem->label().utf8() << "</label>\n";
     xml << "\t\t\t\t</renderitem>\n";
     xml << "\t\t\t</highestitem>\n";
     xml << "\t\t</continuoussymbol>\n";
@@ -392,3 +417,37 @@ QString QgsContinuousColRenderer::name()
 {
     return "Continuous Color";
 }
+
+bool QgsContinuousColRenderer::writeXML( QDomNode & layer_node, QDomDocument & document )
+{
+    bool returnval=true;
+    QDomElement continuoussymbol=document.createElement("continuoussymbol");
+    layer_node.appendChild(continuoussymbol);
+    QDomElement classificationfield=document.createElement("classificationfield");
+    QDomText classificationfieldtxt=document.createTextNode(QString::number(mClassificationField));
+    classificationfield.appendChild(classificationfieldtxt);
+    continuoussymbol.appendChild(classificationfield);
+    QDomElement lowestitem=document.createElement("lowestitem");
+    continuoussymbol.appendChild(lowestitem);
+    if(mMinimumItem)
+    {
+	mMinimumItem->writeXML(lowestitem,document);
+    }
+    QDomElement highestitem=document.createElement("highestitem");
+    continuoussymbol.appendChild(highestitem);
+    if(mMaximumItem)
+    {
+	mMaximumItem->writeXML(highestitem,document);
+    }
+#ifdef WIN32
+	return true;
+#endif
+}
+
+const std::list<QgsRenderItem*> QgsContinuousColRenderer::items() const
+{
+    std::list<QgsRenderItem*> list;
+    list.push_back(mMinimumItem);
+    list.push_back(mMaximumItem);
+    return list;
+}
