@@ -14,14 +14,14 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgscontinuouscolrenderer.h,v 1.18 2004/10/26 17:28:02 mcoletti Exp $ */
+/* $Id: qgscontinuouscolrenderer.h,v 1.24 2005/04/02 09:42:53 rabla Exp $ */
 #ifndef QGSCONTINUOUSCOLRENDERER_H
 #define QGSCONTINUOUSCOLRENDERER_H
 
 #include "qgsrenderer.h"
 #include "qgsrenderitem.h"
 #include <qpainter.h>
-#include "qgscoordinatetransform.h"
+#include "qgsmaptopixel.h"
 #include "qgspoint.h"
 #include "qgsfeature.h"
 #include <iostream>
@@ -39,7 +39,7 @@ class QgsContinuousColRenderer: public QgsRenderer
        @param pr the property dialog. This is only needed if the renderer is created from the property dialog and not yet associated with the vector layer, otherwise 0*/
     void initializeSymbology(QgsVectorLayer* layer, QgsDlgVectorLayerProperties* pr=0);
     /**Renders the feature using the minimum and maximum value of the classification field*/
-    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected);
+    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected, int oversampling = 1, double widthScale = 1.);
     /**Returns the number of the classification field*/
     int classificationField() const;
     /**Sets the id of the classification field*/
@@ -58,12 +58,17 @@ class QgsContinuousColRenderer: public QgsRenderer
     virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
     /**Writes the contents of the renderer to a configuration file*/
     virtual void writeXML(std::ostream& xml);
+    /**Writes the contents of the renderer to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & layer_node, QDomDocument & document );
     /** Returns true*/
     bool needsAttributes();
     /**Returns a list with the index of the classification attribute*/
     virtual std::list<int> classificationAttributes();
     /**Returns the renderers name*/
-    QString name(); 
+    QString name();
+    /**Return symbology items*/
+    const std::list<QgsRenderItem*> items() const;
  protected:
     /**Number of the classification field (it must be a numerical field)*/
     int mClassificationField;
@@ -71,12 +76,12 @@ class QgsContinuousColRenderer: public QgsRenderer
     QgsRenderItem* mMinimumItem;
     /**Item for the maximum value*/
     QgsRenderItem* mMaximumItem;
-    /**Color to draw selected features*/
-    QColor mSelectionColor;
 };
 
-inline QgsContinuousColRenderer::QgsContinuousColRenderer(): mMinimumItem(0), mMaximumItem(0), mSelectionColor(QColor(255,255,0))
+inline QgsContinuousColRenderer::QgsContinuousColRenderer(): mMinimumItem(0), mMaximumItem(0)
 {
+  //call superclass method to set up selection colour
+  initialiseSelectionColor();
 
 }
 
