@@ -1,5 +1,5 @@
 /***************************************************************************
-                          gsdatasource.h  -  description
+                          qgsdatasource.h  -  description
                              -------------------
     begin                : Sun Jun 30 2002
     copyright            : (C) 2002 by Gary E.Sherman
@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id */
+/* $Id: qgsdatasource.h,v 1.6 2004/10/16 21:59:14 gsherman Exp $ */
 
 #ifndef QGSDATASOURCE_H
 #define QGSDATASOURCE_H
