@@ -14,7 +14,7 @@ email                : sherman at mrcc.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsdbsourceselect.cpp,v 1.36.2.1 2004/12/10 05:18:41 gsherman Exp $ */
+/* $Id: qgsdbsourceselect.cpp,v 1.45.2.8 2005/10/19 00:25:19 g_j_m Exp $ */
 #include <iostream>
 #include <cassert>
 #include <qsettings.h>
@@ -34,6 +34,7 @@ email                : sherman at mrcc.com
 #include "qgsnewconnection.h"
 #include "qgspgquerybuilder.h"
 #include "qgisapp.h"
+#include "qgscontexthelp.h"
 QgsDbSourceSelect::QgsDbSourceSelect(QgisApp * app, QWidget * parent, const char *name):QgsDbSourceSelectBase(parent, name),
                                                                                         qgisApp(app)
 {
@@ -43,7 +44,6 @@ QgsDbSourceSelect::QgsDbSourceSelect(QgisApp * app, QWidget * parent, const char
 
   //disable the 'where clause' box for 0.4 release
   //  groupBox3->hide();
-
 }
 
 QgsDbSourceSelect::~QgsDbSourceSelect()
@@ -96,11 +96,20 @@ void QgsDbSourceSelect::deleteConnection()
     settings.removeEntry(key + "/database");
     settings.removeEntry(key + "/username");
     settings.removeEntry(key + "/password");
+    settings.removeEntry(key + "/port");
+    settings.removeEntry(key + "/save");
+    settings.removeEntry(key);
     //if(!success){
     //  QMessageBox::information(this,"Unable to Remove","Unable to remove the connection " + cmbConnections->currentText());
     //}
     cmbConnections->removeItem(cmbConnections->currentItem());  // populateConnectionList();
   }
+  // Select the first connection in the list, checking to make sure there is
+  // at least one item to select
+  if(cmbConnections->count() > 0)
+  {
+    cmbConnections->setCurrentItem(0);
+  }
 }
 
 void QgsDbSourceSelect::addTables()
@@ -159,82 +168,63 @@ void QgsDbSourceSelect::dbConnect()
   }
   connString += " password=" + password;
 #ifdef QGISDEBUG
-  std::cout << "Connection info: " << connString << std::endl;
+  std::cout << "Connection info: " << connString.local8Bit() << std::endl;
 #endif
   if (makeConnection)
   {
     m_connInfo = connString;  //host + " " + database + " " + username + " " + password;
     //qDebug(m_connInfo);
-    pd = PQconnectdb((const char *) m_connInfo);
+    pd = PQconnectdb(m_connInfo.local8Bit());
     //  std::cout << pd->ErrorMessage();
     if (PQstatus(pd) == CONNECTION_OK)
     {
+      // create the pixmaps for the layer types
+      QPixmap pxPoint(point_layer_xpm);
+      QPixmap pxLine(line_layer_xpm);
+      QPixmap pxPoly(polygon_layer_xpm);
+      //qDebug("Connection succeeded");
+      // tell the DB that we want text encoded in UTF8
+      PQsetClientEncoding(pd, "UNICODE");
+
       // clear the existing entries
       lstTables->clear();
-      // create the pixmaps for the layer types
-      QPixmap pxPoint;
-      pxPoint = QPixmap(point_layer_xpm);
-      QPixmap pxLine;
-      pxLine = QPixmap(line_layer_xpm);
-      QPixmap pxPoly;
-      pxPoly = QPixmap(polygon_layer_xpm);
-      //qDebug("Connection succeeded");
-      // get the list of tables
-      QString sql = "select * from geometry_columns";
-      // where f_table_schema ='" + settings.readEntry(key + "/database") + "'";
-      sql += " order by f_table_name";
-      //qDebug("Fetching tables using: " + sql);
-      PGresult *result = PQexec(pd, (const char *) sql);
-      if (result)
+      // get the list of suitable tables and columns and populate the UI
+      geomCol details;
+      if (getGeometryColumnInfo(pd, details))
       {
-        QString msg;
-        QTextOStream(&msg) << "Fetched " << PQntuples(result) << " tables from database";
-        //qDebug(msg);
-        for (int idx = 0; idx < PQntuples(result); idx++)
-        {
-          QString v = "";
-          if (strlen(PQgetvalue(result, idx, PQfnumber(result, "f_table_catalog"))))
-          {
-            v += PQgetvalue(result, idx, PQfnumber(result, "f_table_catalog"));
-            v += ".";
-          }
-          if (strlen(PQgetvalue(result, idx, PQfnumber(result, "f_table_schema"))))
-          {
-            v += PQgetvalue(result, idx, PQfnumber(result, "f_table_schema"));
-            v += ".";
-          }
-          v += PQgetvalue(result, idx, PQfnumber(result, "f_table_name"));
-          v += " (";
-          v += PQgetvalue(result, idx, PQfnumber(result, "f_geometry_column"));
-          v += ")";
+  geomCol::const_iterator iter = details.begin();
+  for (; iter != details.end(); ++iter)
+  {
+    QPixmap *p = 0;
+    if (iter->second == "POINT" || iter->second == "MULTIPOINT")
+      p = &pxPoint;
+    else if (iter->second == "MULTIPOLYGON" || iter->second == "POLYGON")
+      p = &pxPoly;
+    else if (iter->second == "LINESTRING" || iter->second == "MULTILINESTRING")
+      p = &pxLine;
 
-          QString type = PQgetvalue(result, idx, PQfnumber(result, "type"));
-          QPixmap *p;
-          if (type == "POINT" || type == "MULTIPOINT")
-            p = &pxPoint;
-          else if (type == "MULTIPOLYGON" || type == "POLYGON")
-            p = &pxPoly;
-          else if (type == "LINESTRING" || type == "MULTILINESTRING")
-            p = &pxLine;
-          else
-            p = 0;
-          if (p != 0)
-          {
-            QListViewItem *lItem = new QListViewItem(lstTables);
-            lItem->setText(1,v);
-            lItem->setPixmap(0,*p);
-            lstTables->insertItem(lItem);
-          }
-        }
-        // BEGIN CHANGES ECOS
-        if (cmbConnections->count() > 0)
-          btnAdd->setEnabled(true);
-        // END CHANGES ECOS
-      } else
+    if (p != 0)
+    {
+      QListViewItem *lItem = new QListViewItem(lstTables);
+      lItem->setText(1,iter->first);
+      lItem->setPixmap(0,*p);
+      lstTables->insertItem(lItem);
+    }
+    else
+    {
+      qDebug(("Unknown geometry type of " + iter->second).local8Bit());
+    }
+  }
+      }
+      else
       {
-        qDebug("Unable to get list of spatially enabled tables from geometry_columns table");
+        qDebug("Unable to get list of spatially enabled tables from the database");
         qDebug(PQerrorMessage(pd));
       }
+      // BEGIN CHANGES ECOS
+      if (cmbConnections->count() > 0)
+  btnAdd->setEnabled(true);
+      // END CHANGES ECOS
     } else
     {
       QMessageBox::warning(this, tr("Connection failed"),
@@ -281,3 +271,122 @@ void QgsDbSourceSelect::addLayer(QListBoxItem * item)
   qgisApp->addVectorLayer(m_connInfo, item->text(), "postgres");
   //  lstTables->setSelected(item, false);
 }
+
+bool QgsDbSourceSelect::getGeometryColumnInfo(PGconn *pg, 
+                geomCol& details)
+{
+  bool ok = false;
+
+  QString sql = "select * from geometry_columns";
+  // where f_table_schema ='" + settings.readEntry(key + "/database") + "'";
+  sql += " order by f_table_name";
+  //qDebug("Fetching tables using: " + sql);
+  PGresult *result = PQexec(pg, sql.local8Bit());
+  if (result)
+  {
+    QString msg;
+    QTextOStream(&msg) << "Fetched " << PQntuples(result) << " tables from database";
+    //qDebug(msg);
+    for (int idx = 0; idx < PQntuples(result); idx++)
+    {
+      // Be a bit paranoid and check that the table actually
+      // exists. This is not done as a subquery in the query above
+      // because I can't get it to work correctly when there are tables
+      // with capital letters in the name.
+
+      // Take care to deal with tables with the same name but in different schema.
+      QString tableName = PQgetvalue(result, idx, PQfnumber(result, "f_table_name"));
+      QString schemaName = PQgetvalue(result, idx, PQfnumber(result, "f_table_schema"));
+      sql = "select oid from pg_class where relname = '" + tableName + "'";
+      if (schemaName.length() > 0)
+	sql +=" and relnamespace = (select oid from pg_namespace where nspname = '" +
+	  schemaName + "')";
+
+      PGresult* exists = PQexec(pg, sql.local8Bit());
+      if (PQntuples(exists) == 1)
+  {
+    QString v = "";
+
+    if (schemaName.length() > 0)
+    {
+      v += schemaName;
+      v += ".";
+    }
+
+    v += tableName;
+    v += " (";
+    v += PQgetvalue(result, idx, PQfnumber(result, "f_geometry_column"));
+    v += ")";
+
+    QString type = PQgetvalue(result, idx, PQfnumber(result, "type"));
+    details.push_back(geomPair(v, type));
+  }
+      PQclear(exists);
+    }
+    ok = true;
+  }
+  PQclear(result);
+
+  // Now have a look for geometry columns that aren't in the
+  // geometry_columns table. This code is specific to postgresql,
+  // but an equivalent query should be possible in other
+  // databases.
+  sql = "select pg_class.relname, pg_namespace.nspname, pg_attribute.attname from "
+    "pg_attribute, pg_class, pg_type, pg_namespace where pg_type.typname = 'geometry' and "
+    "pg_attribute.atttypid = pg_type.oid and pg_attribute.attrelid = pg_class.oid "
+    "and cast(pg_class.relname as character varying) not in "
+    "(select f_table_name from geometry_columns) "
+    "and pg_namespace.oid = pg_class.relnamespace "
+    "and pg_class.relkind in ('v', 'r')"; // only from views and relations (tables)
+  
+  result = PQexec(pg, sql.local8Bit());
+
+  for (int i = 0; i < PQntuples(result); i++)
+  {
+    // Have the column name, schema name and the table name. The concept of a
+    // catalog doesn't exist in postgresql so we ignore that, but we
+    // do need to get the geometry type.
+
+    // Make the assumption that the geometry type for the first
+    // row is the same as for all other rows. 
+
+    // Flag these not geometry_columns table tables so that the UI
+    // can indicate this????
+    QString table  = PQgetvalue(result, i, 0); // relname
+    QString schema = PQgetvalue(result, i, 1); // nspname
+    QString column = PQgetvalue(result, i, 2); // attname
+
+    QString query = "select GeometryType(" + column + ") from ";
+    if (schema.length() > 0)
+      query += "\"" + schema + "\".";
+    query += "\"" + table + "\" where " + column + " is not null limit 1";
+
+    PGresult* gresult = PQexec(pg, query.local8Bit());
+    if (PQresultStatus(gresult) != PGRES_TUPLES_OK)
+    {
+      qDebug((tr("Access to relation ") + table + tr(" using sql;\n") + query +
+       tr("\nhas failed. The database said:\n") +
+       PQresultErrorMessage(gresult)).local8Bit());
+    }
+    else
+    {
+      QString type = PQgetvalue(gresult, 0, 0); // GeometryType
+      QString full_desc = "";
+      if (schema.length() > 0)
+  full_desc = schema + ".";
+      full_desc += table + " (" + column + ")";
+      details.push_back(geomPair(full_desc, type));
+    }
+    PQclear(gresult);
+  }
+  ok = true;
+
+  PQclear(result);
+
+  return ok;
+}
+
+void QgsDbSourceSelect::showHelp()
+{
+	QgsContextHelp::run(context_id);
+}
