@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsdbsourceselect.h,v 1.14 2004/11/20 06:00:31 gsherman Exp $ */
+/* $Id: qgsdbsourceselect.h,v 1.16.2.2 2005/07/29 20:47:56 mhugent Exp $ */
 #ifndef QGSDBSOURCESELECT_H
 #define QGSDBSOURCESELECT_H
 #ifdef WIN32
@@ -26,6 +26,10 @@ extern "C"
 {
 #include <libpq-fe.h>
 }
+
+#include <vector>
+#include <utility>
+
 class QListBoxItem;
 class QgisApp;
 /*! \class QgsDbSourceSelect
@@ -39,6 +43,7 @@ class QgsDbSourceSelect : public QgsDbSourceSelectBase
 {
   Q_OBJECT
  public:
+
     //! Constructor
     QgsDbSourceSelect(QgisApp *app=0, QWidget *parent = 0, const char *name = 0);
     //! Destructor
@@ -63,14 +68,24 @@ class QgsDbSourceSelect : public QgsDbSourceSelectBase
     QString connInfo();
     //! Add the layer selected when user double-clicks the mouse
     void addLayer(QListBoxItem *item);
+
     public slots:
       void setSql(QListViewItem *);
+      void showHelp();
  private:
+
+    typedef std::pair<QString, QString> geomPair;
+    typedef std::vector<geomPair > geomCol;
+
+    bool getGeometryColumnInfo(PGconn *pd, 
+			       geomCol& details);
+
     QString m_connInfo;
     QStringList m_selectedTables;
     //! Pointer to the qgis application mainwindow
     QgisApp *qgisApp;
     PGconn *pd;
+    static const int context_id = 1244423922;
 };
 
 
