@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgsdlgvectorlayerproperties.cpp,v 1.40.2.4 2004/12/10 03:54:23 gsherman Exp $ */
+ /* $Id: qgsdlgvectorlayerproperties.cpp,v 1.54.2.10 2005/10/10 20:05:09 gsherman Exp $ */
 #include <qstring.h>
 #include <qlineedit.h>
 #include <qtextedit.h>
@@ -33,7 +33,8 @@
 #include <qwidget.h>
 #include <qgroupbox.h>
 #include <qwhatsthis.h>
-
+#include <qregexp.h>
+#include <qtabwidget.h>
 
 #include "qgis.h"
 #include "qgsrect.h"
@@ -68,100 +69,50 @@
 #ifdef HAVE_POSTGRESQL
 #include "qgspgquerybuilder.h"
 #endif
+#include "qgslayerprojectionselector.h"
+#include <qapplication.h>
 
-QgsDlgVectorLayerProperties::QgsDlgVectorLayerProperties(QgsVectorLayer * lyr, QWidget * parent, const char *name, bool modal):QgsDlgVectorLayerPropertiesBase(parent, name, modal), layer(lyr), rendererDirty(false), bufferDialog(layer->rendererDialog()),
-bufferRenderer(layer->
-               renderer())
+
+QgsDlgVectorLayerProperties::QgsDlgVectorLayerProperties(QgsVectorLayer * lyr, 
+                                                         QWidget * parent, 
+                                                         const char *name, 
+                                                         bool modal)
+    : QgsDlgVectorLayerPropertiesBase(parent, name, modal), 
+      layer(lyr), 
+      rendererDirty(false), 
+      bufferDialog(layer->rendererDialog()),
+      bufferRenderer(layer->renderer())
 {
-
-  // populate the general information
-  QString source = layer->source();
-  source = source.left(source.find("password"));
-  lblSource->setText(source);
-  txtDisplayName->setText(layer->name());
-  // set whats this stuff
-  QWhatsThis::add(lblSource, tr("The source of the data (path name or database connection information)"));
-  QWhatsThis::add(pbnQueryBuilder, tr("This button opens the PostgreSQL query builder and allows you to create a subset of features to display on the map canvas rather than displaying all features in the layer"));
-  QWhatsThis::add(txtSubsetSQL, tr("The query used to limit the features in the layer is shown here. This is currently only supported for PostgreSQL layers. To enter or modify the query, click on the Query Builder button"));
-  QWhatsThis::add(lblGeometryType, tr("Geometry type of the features in this layer"));
-  QWhatsThis::add(lblFeatureCount, tr("The number of features in this layer"));
-  // display type and feature count
-  lblGeometryType->setText(QGis::qgisVectorGeometryType[layer->vectorType()]);
-  //we are dealing with a pg layer here so that we can enable the sql box
-  QgsVectorDataProvider *dp = dynamic_cast<QgsVectorDataProvider *>(layer->getDataProvider());
-  //see if we are dealing with a pg layer here
-  if(layer->providerType() == "postgres")
-  {
-    grpSubset->setEnabled(true);
-    txtSubsetSQL->setText(layer->subsetString());
-    // if the user is allowed to type an adhoc query, the app will crash if the query
-    // is bad. For this reason, the sql box is disabled and the query must be built
-    // using the query builder, either by typing it in by hand or using the buttons, etc
-    // on the builder. If the ability to enter a query directly into the box is required,
-    // a mechanism to check it must be implemented.
-    txtSubsetSQL->setEnabled(false); 
-    pbnQueryBuilder->setEnabled(true);
-  }
-  else
-  {
-    grpSubset->setEnabled(false);
-  }
-  QString numFeatures;
-  numFeatures = numFeatures.setNum(layer->featureCount());
-  lblFeatureCount->setText(numFeatures);
-  QgsRect *extent = dp->extent();
-  QString ll;
-  //QTextOStream (&ll) << extent->xMin() << ", " << extent->yMin();
-  lblLowerLeft->setText(ll.sprintf("%16f, %16f", extent->xMin(), extent->yMin()));
-  QString ur;
-//  QTextOStream (&ur) << extent->xMax() << ", " << extent->yMax();
-  lblUpperRight->setText(ur.sprintf("%16f, %16f", extent->xMax(), extent->yMax()));
-  std::vector<QgsField> fields = dp->fields();
-  // populate the table and the display field drop-down with the field
-  // information
-
-  for (int i = 0; i < fields.size(); i++)
-  {
-    QgsField fld = fields[i];
-    QListViewItem *lvi = new QListViewItem(listViewFields, fld.name(),
-                                           fld.type(), QString("%1").arg(fld.length()),
-                                           QString("%1").arg(fld.precision()));
-    displayFieldComboBox->insertItem( fld.name() );
-  }
-
-  // set up the scale based layer visibility stuff....
-  chkUseScaleDependentRendering->setChecked(lyr->scaleBasedVisibility());
-  spinMinimumScale->setValue(lyr->minScale());
-  spinMaximumScale->setValue(lyr->maxScale());
-
-  // symbology initialization
-  legendtypecombobox->insertItem(tr("Single Symbol"));
-  legendtypecombobox->insertItem(tr("Graduated Symbol"));
-  legendtypecombobox->insertItem(tr("Continuous Color"));
-  legendtypecombobox->insertItem(tr("Unique Value"));
-  if( layer->vectorType()==QGis::Point )
-  {
-      legendtypecombobox->insertItem(tr("Single Marker"));
-      legendtypecombobox->insertItem(tr("Graduated Marker"));
-      legendtypecombobox->insertItem(tr("Unique Value Marker"));
-  }
-
+  // Create the Label dialog tab
   QVBoxLayout *layout = new QVBoxLayout( labelOptionsFrame );
-  labelDialog = new QgsLabelDialog ( layer->label(),labelOptionsFrame);
+  labelDialog = new QgsLabelDialog ( layer->label(), labelOptionsFrame);
   layout->addWidget( labelDialog );
 
-  QGridLayout *actionLayout = new QGridLayout( actionOptionsFrame );
-  actionDialog = new QgsAttributeActionDialog ( layer->actions(), fields,
+  // Create the Actions dialog tab
+  QgsVectorDataProvider *dp = dynamic_cast<QgsVectorDataProvider *>(layer->getDataProvider());
+  QVBoxLayout *actionLayout = new QVBoxLayout( actionOptionsFrame );
+  std::vector<QgsField> fields = dp->fields();
+  actionDialog = new QgsAttributeActionDialog ( layer->actions(), fields, 
                                                 actionOptionsFrame );
-  actionLayout->addWidget( actionDialog,0,0 );
+  actionLayout->addWidget( actionDialog );
 
-  QObject::connect(legendtypecombobox, SIGNAL(activated(const QString &)), this, SLOT(alterLayerDialog(const QString &)));
+  reset();
+  pbnOK->setFocus();
+  if(layer->getDataProvider())//enable spatial index button group if supported by provider
+  {
+      int capabilities=layer->getDataProvider()->capabilities();
+      if(capabilities&QgsVectorDataProvider::CreateSpatialIndex)
+      {
+	  indexGroupBox->setEnabled(true);
+      }
+  }
 
-  //insert the renderer dialog of the vector layer into the widget stack
-  widgetStackRenderers->addWidget(bufferDialog);
-  widgetStackRenderers->raiseWidget(bufferDialog);
+  if ( layer->coordinateTransform() )
+  {
+      leSpatialRefSys->setText(layer->coordinateTransform()->sourceSRS().proj4String());
+  }
 
-}
+} // QgsDlgVectorLayerProperties ctor
 
 QgsDlgVectorLayerProperties::~QgsDlgVectorLayerProperties()
 {
@@ -264,7 +215,7 @@ QgsRenderer *QgsDlgVectorLayerProperties::getBufferRenderer()
 
 void QgsDlgVectorLayerProperties::setLegendType(QString type)
 {
-  legendtypecombobox->setCurrentText(tr(type));
+  legendtypecombobox->setCurrentText(type);
 }
 
 void QgsDlgVectorLayerProperties::setDisplayField(QString name)
@@ -272,12 +223,88 @@ void QgsDlgVectorLayerProperties::setDisplayField(QString name)
   displayFieldComboBox->setCurrentText(name);
 }
 
+//! @note in raster props, this metho d is called sync()
 void QgsDlgVectorLayerProperties::reset( void )
 {
-    actionDialog->init();
-    labelDialog->init();
-    labelCheckBox->setChecked(layer->labelOn());
-}
+  // populate the general information
+  QString source = layer->source();
+  source = source.left(source.find("password"));
+  lblSource->setText(source);
+  txtDisplayName->setText(layer->name());
+  // set whats this stuff
+  QWhatsThis::add(lblSource, tr("The source of the data (path name or database connection information)"));
+  QWhatsThis::add(pbnQueryBuilder, tr("This button opens the PostgreSQL query builder and allows you to create a subset of features to display on the map canvas rather than displaying all features in the layer"));
+  QWhatsThis::add(txtSubsetSQL, tr("The query used to limit the features in the layer is shown here. This is currently only supported for PostgreSQL layers. To enter or modify the query, click on the Query Builder button"));
+
+  //we are dealing with a pg layer here so that we can enable the sql box
+  QgsVectorDataProvider *dp = dynamic_cast<QgsVectorDataProvider *>(layer->getDataProvider());
+  //see if we are dealing with a pg layer here
+  if(layer->providerType() == "postgres")
+  {
+    grpSubset->setEnabled(true);
+    txtSubsetSQL->setText(layer->subsetString());
+    // if the user is allowed to type an adhoc query, the app will crash if the query
+    // is bad. For this reason, the sql box is disabled and the query must be built
+    // using the query builder, either by typing it in by hand or using the buttons, etc
+    // on the builder. If the ability to enter a query directly into the box is required,
+    // a mechanism to check it must be implemented.
+    txtSubsetSQL->setEnabled(false); 
+    pbnQueryBuilder->setEnabled(true);
+  }
+  else
+  {
+    grpSubset->setEnabled(false);
+  }
+
+  //get field list for display field combo
+  std::vector<QgsField> myFields = dp->fields();
+  for (int i = 0; i < myFields.size(); i++)
+  {
+    QgsField myField = myFields[i];            
+    displayFieldComboBox->insertItem( myField.name() );
+  }   
+
+  // set up the scale based layer visibility stuff....
+  chkUseScaleDependentRendering->setChecked(layer->scaleBasedVisibility());
+  spinMinimumScale->setValue((int)layer->minScale());
+  spinMaximumScale->setValue((int)layer->maxScale());
+
+  // symbology initialization
+  if(legendtypecombobox->count()==0)
+    {
+      legendtypecombobox->insertItem(tr("Single Symbol"));
+      if(myFields.size()>0)
+      {
+	  legendtypecombobox->insertItem(tr("Graduated Symbol"));
+	  legendtypecombobox->insertItem(tr("Continuous Color"));
+	  legendtypecombobox->insertItem(tr("Unique Value"));
+      }
+      if( layer->vectorType()==QGis::Point )
+	{
+	  legendtypecombobox->insertItem(tr("Single Marker"));
+	  if(myFields.size()>0)
+	  {
+	      legendtypecombobox->insertItem(tr("Graduated Marker"));
+	      legendtypecombobox->insertItem(tr("Unique Value Marker"));
+	  }
+	}
+    }
+
+  QObject::connect(legendtypecombobox, SIGNAL(activated(const QString &)), this, SLOT(alterLayerDialog(const QString &)));
+
+  //insert the renderer dialog of the vector layer into the widget stack
+  widgetStackRenderers->addWidget(bufferDialog);
+  widgetStackRenderers->raiseWidget(bufferDialog);
+
+  //set the metadata contents
+  teMetadata->setText(getMetadata());
+  actionDialog->init();
+  labelDialog->init();
+  labelCheckBox->setChecked(layer->labelOn());
+
+} // reset()
+
+
 //
 // methods reimplemented from qt designer base class
 //
@@ -308,10 +335,11 @@ void QgsDlgVectorLayerProperties::pbnOK_clicked()
       //restore the right name in the combobox
       if(bufferRenderer)
       {
-          legendtypecombobox->setCurrentText(tr(bufferRenderer->name()));
+          legendtypecombobox->setCurrentText(bufferRenderer->name());
       }
     }
-  reject();
+  //reject();
+  close();
 }
 void QgsDlgVectorLayerProperties::pbnApply_clicked()
 {
@@ -403,7 +431,7 @@ void QgsDlgVectorLayerProperties::pbnQueryBuilder_clicked()
   // create the query builder object using the table name
   // and postgres connection from the provider
   QgsPgQueryBuilder *pqb =
-      new QgsPgQueryBuilder(myPGProvider->getURI());
+      new QgsPgQueryBuilder(myPGProvider->getURI(), this);
        
   // Set the sql in the query builder to the same in the prop dialog
   // (in case the user has already changed it)
@@ -414,8 +442,232 @@ void QgsDlgVectorLayerProperties::pbnQueryBuilder_clicked()
     // if the sql is changed, update it in the prop subset text box
     txtSubsetSQL->setText(pqb->sql());
     //TODO If the sql is changed in the prop dialog, the layer extent should be recalculated
+
+    // The datasource for the layer needs to be updated with the new sql since this gets
+    // saved to the project file. This should happen at the map layer level...
+
   }
   // delete the query builder object
   delete pqb;
 #endif
 }
+
+void QgsDlgVectorLayerProperties::pbnIndex_clicked()
+{
+    QgsVectorDataProvider* pr=layer->getDataProvider();
+    if(pr)
+    {
+	setCursor(Qt::WaitCursor);
+	bool errval=pr->createSpatialIndex();
+	setCursor(Qt::ArrowCursor);
+	if(errval)
+	{
+	    QMessageBox::information(this, tr("Spatial Index"), tr("Creation of spatial index successfull"),QMessageBox::Ok);
+	}
+	else
+	{
+	   QMessageBox::information(this, tr("Spatial Index"), tr("Creation of spatial index failed"),QMessageBox::Ok); 
+	}
+    }
+}
+
+QString QgsDlgVectorLayerProperties::getMetadata()
+{
+  QString myMetadataQString = "<html><body>";
+  myMetadataQString += "<table width=\"100%\">";
+  
+  //-------------
+  
+  myMetadataQString += "<tr><td bgcolor=\"gray\">";
+  myMetadataQString += tr("General:");
+  myMetadataQString += "</td></tr>";
+  //geom type
+  myMetadataQString += "<tr><td bgcolor=\"white\">";
+
+  QGis::VectorType vectorType = layer->vectorType();
+
+  if ( vectorType < 0 || vectorType > QGis::Polygon )
+  {
+      QgsDebug( "Invalid vector type" );
+  }
+  else
+  {
+      QString vectorTypeString( QGis::qgisVectorGeometryType[layer->vectorType()] );
+
+#ifdef QGISDEBUG
+      const char* vectorTypeProbe = vectorTypeString.ascii(); // debugger probe point
+#endif
+
+      myMetadataQString += tr("Geometry type of the features in this layer : ") + 
+          vectorTypeString;
+      myMetadataQString += "</td></tr>";
+  }
+
+  //feature count
+  myMetadataQString += "<tr><td bgcolor=\"white\">";
+  myMetadataQString += tr("The number of features in this layer : ") + 
+                       QString::number(layer->featureCount());
+  myMetadataQString += "</td></tr>";
+
+  //-------------
+
+  QgsRect myExtent = layer->extent();  
+  myMetadataQString += "<tr><td bgcolor=\"gray\">";
+  myMetadataQString += tr("Extents:");
+  myMetadataQString += "</td></tr>";
+  //extents in layer cs  TODO...maybe make a little nested table to improve layout...
+  myMetadataQString += "<tr><td bgcolor=\"white\">";
+  myMetadataQString += tr("In layer spatial reference system units : ") + 
+                       tr("xMin,yMin ") + 
+                       QString::number(myExtent.xMin()) + 
+                       "," + 
+                       QString::number( myExtent.yMin()) +
+                       tr(" : xMax,yMax ") + 
+                       QString::number(myExtent.xMax()) + 
+                       "," + 
+                       QString::number(myExtent.yMax());
+  myMetadataQString += "</td></tr>";
+
+  //extents in project cs
+
+  try
+  {
+    QgsCoordinateTransform * coordinateTransform = layer->coordinateTransform();
+
+    if ( ! coordinateTransform )
+    {
+        throw QgsCsException( string("unable to get layer coordinate transform object") );
+    }
+
+    QgsRect myProjectedExtent = coordinateTransform->transformBoundingBox(layer->extent());
+    myMetadataQString += "<tr><td bgcolor=\"white\">";
+    myMetadataQString += tr("In project spatial reference system units : ") + 
+                         tr("xMin,yMin ") + 
+                         QString::number(myProjectedExtent.xMin()) + 
+                         "," + 
+                         QString::number( myProjectedExtent.yMin()) +
+                         tr(" : xMax,yMax ") + 
+                         QString::number(myProjectedExtent.xMax()) + 
+                         "," + 
+                         QString::number(myProjectedExtent.yMax());
+    myMetadataQString += "</td></tr>";
+
+
+
+    // 
+    // Display layer spatial ref system
+    //
+    myMetadataQString += "<tr><td bgcolor=\"gray\">";
+    myMetadataQString += tr("Layer Spatial Reference System:");
+    myMetadataQString += "</td></tr>";  
+    myMetadataQString += "<tr><td bgcolor=\"white\">";
+    myMetadataQString += coordinateTransform->sourceSRS().proj4String().replace(QRegExp("\"")," \"");                       
+    myMetadataQString += "</td></tr>";
+
+    // 
+    // Display project (output) spatial ref system
+    //  
+    myMetadataQString += "<tr><td bgcolor=\"gray\">";
+    myMetadataQString += tr("Project (Output) Spatial Reference System:");
+    myMetadataQString += "</td></tr>";  
+    myMetadataQString += "<tr><td bgcolor=\"white\">";
+    myMetadataQString += coordinateTransform->destSRS().proj4String().replace(QRegExp("\"")," \"");                       
+    myMetadataQString += "</td></tr>";
+
+  }
+  catch(QgsCsException &cse)
+  {
+    QgsDebug( cse.what() );
+
+    myMetadataQString += "<tr><td bgcolor=\"white\">";
+    myMetadataQString += tr("In project spatial reference system units : ");
+    myMetadataQString += " (Invalid transformation of layer extents) ";
+    myMetadataQString += "</td></tr>";
+
+  }
+
+      
+  //
+  // Add the info about each field in the attribute table
+  //
+  myMetadataQString += "<tr><td bgcolor=\"gray\">";
+  myMetadataQString += tr("Attribute field info:");
+  myMetadataQString += "</td></tr>";
+  myMetadataQString += "<tr><td bgcolor=\"white\">";
+
+  // Start a nested table in this trow
+  myMetadataQString += "<table width=\"100%\">";
+  myMetadataQString += "<tr><th bgcolor=\"black\">";
+  myMetadataQString += "<font color=\"white\">" + tr("Field") + "</font>";
+  myMetadataQString += "</th>";
+  myMetadataQString += "<th bgcolor=\"black\">";
+  myMetadataQString += "<font color=\"white\">" + tr("Type") + "</font>";
+  myMetadataQString += "</th>";
+  myMetadataQString += "<th bgcolor=\"black\">";
+  myMetadataQString += "<font color=\"white\">" + tr("Length") + "</font>";
+  myMetadataQString += "</th>";
+  myMetadataQString += "<th bgcolor=\"black\">";
+  myMetadataQString += "<font color=\"white\">" + tr("Precision") + "</font>";
+  myMetadataQString += "</th>";      
+  myMetadataQString += "<tr>";
+ 
+  //get info for each field by looping through them
+  QgsVectorDataProvider *myDataProvider = dynamic_cast<QgsVectorDataProvider *>(layer->getDataProvider());
+  std::vector<QgsField> myFields = myDataProvider->fields();
+  for (int i = 0; i < myFields.size(); i++)
+  {
+ 
+    QgsField myField = myFields[i];
+    
+    myMetadataQString += "<tr><td bgcolor=\"white\">";
+    myMetadataQString += myField.name();
+    myMetadataQString += "</td>";
+    myMetadataQString += "<td bgcolor=\"white\">";
+    myMetadataQString += myField.type();
+    myMetadataQString += "</td>";
+    myMetadataQString += "<td bgcolor=\"white\">";
+    myMetadataQString += QString("%1").arg(myField.length());
+    myMetadataQString += "</td>";
+    myMetadataQString += "<td bgcolor=\"white\">";
+    myMetadataQString += QString("%1").arg(myField.precision());
+    myMetadataQString += "</td></tr>";
+  } 
+
+  //close field list
+  myMetadataQString += "</table>"; //end of nested table
+  myMetadataQString += "</td></tr>"; //end of stats container table row
+  //
+  // Close the table
+  //
+
+  myMetadataQString += "</table>";
+  myMetadataQString += "</body></html>";
+  return myMetadataQString;
+
+}
+
+
+
+void QgsDlgVectorLayerProperties::pbnChangeSpatialRefSys_clicked()
+{
+    
+
+    QgsLayerProjectionSelector * mySelector = new QgsLayerProjectionSelector(this);
+    long myDefaultSRS =layer->coordinateTransform()->sourceSRS().srsid();
+    if (myDefaultSRS==0)
+    {
+      myDefaultSRS=QgsProject::instance()->readNumEntry("SpatialRefSys","/ProjectSRSID",GEOSRS_ID);
+    }
+    mySelector->setSelectedSRSID(myDefaultSRS);
+    if(mySelector->exec())
+    {
+      layer->coordinateTransform()->sourceSRS().createFromSrsId(mySelector->getCurrentSRSID());
+      layer->coordinateTransform()->initialise();
+    }
+    else
+    {
+      QApplication::restoreOverrideCursor();
+    }
+    delete mySelector;
+    leSpatialRefSys->setText(layer->coordinateTransform()->sourceSRS().proj4String());
+}
