@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgsdlgvectorlayerproperties.h,v 1.12 2004/11/21 02:11:44 timlinux Exp $ */
+ /* $Id: qgsdlgvectorlayerproperties.h,v 1.15 2005/05/22 16:21:28 timlinux Exp $ */
 #ifndef QGSDLGVECTORLAYERPROPERTIES
 #define QGSDLGVECTORLAYERPROPERTIES
 #ifdef WIN32
@@ -58,7 +58,10 @@ class QgsDlgVectorLayerProperties : public QgsDlgVectorLayerPropertiesBase{
   void alterLayerDialog(const QString& string);
   /** Reset to original (vector layer) values */
   void reset();
-
+  /** Get metadata about the layer in nice formatted html */
+  QString getMetadata();
+  
+  
   //
   //methods reimplemented from qt designer base class
   //
@@ -69,7 +72,8 @@ class QgsDlgVectorLayerProperties : public QgsDlgVectorLayerPropertiesBase{
   void pbnApply_clicked();
   void btnHelp_clicked();
   void pbnQueryBuilder_clicked();
-
+  void pbnIndex_clicked();
+  void pbnChangeSpatialRefSys_clicked();
 
   protected:
   QgsVectorLayer *layer;
