@@ -12,17 +12,20 @@ email                : sherman at mrcc.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsfeature.h,v 1.9 2004/11/07 18:52:11 mhugent Exp $ */
+/* $Id: qgsfeature.h,v 1.14.2.1 2005/10/10 20:05:09 gsherman Exp $ */
 
 #ifndef QGSFEATURE_H
 #define QGSFEATURE_H
 
+#include <geos.h>
 #include <qstring.h>
 #include <map>
 #include <vector>
 
 #include "qgsfeatureattribute.h"
 #include "qgis.h"
+#include "qgspoint.h"
+
 class QgsRect;
 
 /** \class QgsFeature - Feature attribute class.
@@ -79,7 +82,15 @@ class QgsFeature {
     /** 
      * Add an attribute to the map
      */
-    void addAttribute(QString const & field, QString const & value);
+    void addAttribute(QString const & field, QString const & value = "");
+
+    /**Deletes an attribute and its value*/
+    void deleteAttribute(const QString& name);
+
+    /**Changes an existing attribute value
+       @param name attribute name
+       @param newval new value*/
+    void changeAttributeValue(const QString& name, const QString& newval);
 
     /**
      * Get the fields for this feature
@@ -94,6 +105,11 @@ class QgsFeature {
      */
     bool isValid() const;
 
+    /**
+     * Validate the feature
+     */
+    bool validate() const;
+
     /** 
      * Set the validity of the feature.
      */
@@ -108,11 +124,21 @@ class QgsFeature {
     /** Set WKB geometry*/
     void setGeometry(unsigned char * geometry, size_t length);
 
-    /**Shows a popup dialog to change attribute values*/
-    void attributeDialog();
+    /**Shows a popup dialog to change attribute values
+     @return true if dialog is accepted, false if rejected*/
+    bool attributeDialog();
 
     /**Test for intersection with a rectangle (uses GEOS)*/
-    bool intersects(QgsRect* r);
+    bool intersects(QgsRect* r) const;
+
+    /**Returns the Vertex closest to a given point*/
+    QgsPoint closestVertex(const QgsPoint& point) const;
+
+    /**Returns the bounding box of this feature*/
+    QgsRect boundingBox() const;
+
+    /**Creates a geos geometry from this features geometry. Note, that the returned object needs to be deleted*/
+    geos::Geometry* geosGeometry() const;
 
   private:
 
