@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsgraduatedmarenderer.h,v 1.9 2004/10/26 17:28:02 mcoletti Exp $ */
+/* $Id: qgsgraduatedmarenderer.h,v 1.13 2005/04/02 09:42:53 rabla Exp $ */
 
 #ifndef QGSGRADUATEDMARENDERER_H
 #define QGSGRADUATEDMARENDERER_H
@@ -36,7 +36,7 @@ class QgsGraduatedMaRenderer: public QgsRenderer
     /**Removes all items*/
     void removeItems();
     virtual void initializeSymbology(QgsVectorLayer* layer, QgsDlgVectorLayerProperties* pr=0);
-    virtual void renderFeature(QPainter* p, QgsFeature* f,QPicture* pic, double* scalefactor, bool selected);
+    virtual void renderFeature(QPainter* p, QgsFeature* f,QPicture* pic, double* scalefactor, bool selected, int oversampling = 1, double widthScale = 1.);
     /**Sets the number of the classicifation field
     \param field the number of the field to classify*/
     void setClassificationField(int field);
@@ -48,11 +48,16 @@ class QgsGraduatedMaRenderer: public QgsRenderer
     virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
     /**Writes the contents of the renderer to a configuration file*/
     virtual void writeXML(std::ostream& xml);
+    /**Writes the contents of the renderer to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & layer_node, QDomDocument & document );
     virtual bool needsAttributes();
     /**Returns a list with the index of the classification attribute*/
     virtual std::list<int> classificationAttributes();
     /**Returns the renderers name*/
     QString name();
+    /**Return symbology items*/
+    const std::list<QgsRenderItem*> items() const;
  protected:
     /**Name of the classification field (it must be a numerical field)*/
     int mClassificationField;
@@ -62,6 +67,8 @@ class QgsGraduatedMaRenderer: public QgsRenderer
 
 inline QgsGraduatedMaRenderer::QgsGraduatedMaRenderer()
 {
+  //call superclass method to set up selection colour
+  initialiseSelectionColor();
 
 }
 
