@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsgraduatedsymrenderer.h,v 1.18 2004/10/26 17:28:02 mcoletti Exp $ */
+/* $Id: qgsgraduatedsymrenderer.h,v 1.24 2005/04/02 09:42:53 rabla Exp $ */
 
 #ifndef QGSGRADUATEDSYMRENDERER_H
 #define QGSGRADUATEDSYMRENDERER_H
@@ -25,7 +25,7 @@
 #include <iostream>
 #include "qgspoint.h"
 #include "qpainter.h"
-#include "qgscoordinatetransform.h"
+#include "qgsmaptopixel.h"
 #include "qgsfeature.h"
 #include "qgsvectorlayer.h"
 #include "qgsdlgvectorlayerproperties.h"
@@ -47,7 +47,7 @@ class QgsGraduatedSymRenderer: public QgsRenderer
      \param p a painter (usually the one from the current map canvas)
      \param f a pointer to a feature to render
      \param t the transform object containing the information how to transform the map coordinates to screen coordinates*/
-    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected);
+    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected, int oversampling = 1, double widthScale = 1.);
     /**Sets the number of the classicifation field
     \param field the number of the field to classify*/
     void setClassificationField(int field);
@@ -61,27 +61,29 @@ class QgsGraduatedSymRenderer: public QgsRenderer
      @param rnode the DOM node to read 
      @param vl the vector layer which will be associated with the renderer*/
     virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
-    /**Writes the contents of the renderer to a configuration file*/
-    virtual void writeXML(std::ostream& xml);
+    /**Writes the contents of the renderer to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & layer_node, QDomDocument & document );
     /** Returns true*/
     bool needsAttributes();
     /**Returns a list with the index to the classification field*/
     virtual std::list<int> classificationAttributes();
     /**Returns the renderers name*/
     QString name();
+    /**Return symbology items*/
+    const std::list<QgsRenderItem*> items() const;
  protected:
     /**Name of the classification field (it must be a numerical field)*/
     int mClassificationField;
     /**List holding the render items for the individual classes*/
     std::list<QgsRangeRenderItem*> mItems;
-    /**Color to draw selected features*/
-    QColor mSelectionColor;
     
 };
 
-inline QgsGraduatedSymRenderer::QgsGraduatedSymRenderer(): mSelectionColor(QColor(255,255,0))
+inline QgsGraduatedSymRenderer::QgsGraduatedSymRenderer()
 {
-
+  //call superclass method to set up selection colour
+  initialiseSelectionColor();
 }
 
 inline void QgsGraduatedSymRenderer::addItem(QgsRangeRenderItem* ri)
