@@ -112,8 +112,18 @@ QgsGraMaExtensionWidget::QgsGraMaExtensionWidget(QWidget* parent, int classfield
         /*Set the default values of the lower and upper bounds according to the chosen mode */
 	if (mMode == QgsGraSyDialog::EQUAL_INTERVAL)
         {
-	    ltextfield->setText(QString::number(minimum + (maximum - minimum) / mNumberOfClasses * (i - 1), 'f', 2));
-	    utextfield->setText(QString::number(minimum + (maximum - minimum) / mNumberOfClasses * i, 'f', 2));
+	  double lower=minimum + (maximum - minimum) / mNumberOfClasses * (i - 1);
+	  double upper=minimum + (maximum - minimum) / mNumberOfClasses * i;
+	  if(i==1)
+	    {
+	      lower-=0.001;
+	    }
+	  if(i==mNumberOfClasses)
+	    {
+	      upper+=0.001;
+	    }
+	    ltextfield->setText(QString::number(lower, 'f', 3));
+	    utextfield->setText(QString::number(upper, 'f', 3));
         }
 
 	
@@ -158,7 +168,7 @@ void QgsGraMaExtensionWidget::selectMarker()
     if(mdialog.exec()==QDialog::Accepted)
     {
 	QString svgfile=mdialog.selectedMarker();
-	((QPushButton *) sender())->setName(svgfile);
+	((QPushButton *) sender())->setName(svgfile.local8Bit());
 	//draw the SVG-Image on the button
 	QPicture pic;
 
@@ -175,7 +185,7 @@ void QgsGraMaExtensionWidget::selectMarker()
 	}
 
 #ifdef QGISDEBUG	
-	qWarning("indexnumber: "+QString::number(indexnumber));
+	qWarning(("indexnumber: "+QString::number(indexnumber)).local8Bit());
 #endif
 	adjustMarker(indexnumber);
     }
