@@ -14,7 +14,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsgrasydialog.cpp,v 1.41.2.4 2004/12/12 23:28:22 mhugent Exp $ */
+/* $Id: qgsgrasydialog.cpp,v 1.46.2.1 2005/08/31 03:45:17 telwertowski Exp $ */
+#include <iostream>
+
 #include "qgsgrasydialog.h"
 #include "qspinbox.h"
 #include "qpushbutton.h"
@@ -48,11 +50,13 @@ QgsGraSyDialog::QgsGraSyDialog(QgsVectorLayer * layer):QgsGraSyDialogBase(), mVe
     QgsVectorDataProvider *provider;
     if (provider = dynamic_cast<QgsVectorDataProvider *>(mVectorLayer->getDataProvider()))
     {
-	std::vector < QgsField > &fields = provider->fields();
+	std::vector < QgsField > const & fields = provider->fields();
 	int fieldnumber = 0;
 	QString str;
 	
-	for (std::vector < QgsField >::iterator it = fields.begin(); it != fields.end(); ++it)
+	for (std::vector < QgsField >::const_iterator it = fields.begin(); 
+             it != fields.end(); 
+             ++it)
         {
 	    QString type = (*it).type();
 	    if (type != "String" && type != "varchar" && type != "geometry")
@@ -115,6 +119,8 @@ QgsGraSyDialog::QgsGraSyDialog(QgsVectorLayer * layer):QgsGraSyDialogBase(), mVe
 		QgsRangeRenderItem* rritem=new QgsRangeRenderItem(sym,item->value(),item->upper_value(),item->label());
 		sym->setPen(item->getSymbol()->pen());
 		sym->setBrush(item->getSymbol()->brush());
+		sym->setNamedPointSymbol(item->getSymbol()->pointSymbolName());
+		sym->setPointSize(item->getSymbol()->pointSize());
 		mEntries.insert(std::make_pair(classbreak,rritem));
 		mClassBreakBox->insertItem(classbreak);
 	}
@@ -122,7 +128,6 @@ QgsGraSyDialog::QgsGraSyDialog(QgsVectorLayer * layer):QgsGraSyDialogBase(), mVe
     }
     
     //do the necessary signal/slot connections
-    //QObject::connect(numberofclassesspinbox, SIGNAL(valueChanged(int)), this, SLOT(adjustNumberOfClasses()));
     QObject::connect(numberofclassesspinbox, SIGNAL(valueChanged(int)), this, SLOT(adjustClassification()));
     QObject::connect(classificationComboBox, SIGNAL(activated(int)), this, SLOT(adjustClassification()));
     QObject::connect(modeComboBox, SIGNAL(activated(int)), this, SLOT(adjustClassification()));
@@ -256,24 +261,23 @@ void QgsGraSyDialog::apply()
 	
 	    QgsSymbol* sy = new QgsSymbol();
 	    
-	    sy->pen().setColor(it->second->getSymbol()->pen().color());
-	    sy->pen().setStyle(it->second->getSymbol()->pen().style());
-	    sy->pen().setWidth(it->second->getSymbol()->pen().width());
+	    sy->setColor(it->second->getSymbol()->pen().color());
+	    sy->setLineStyle(it->second->getSymbol()->pen().style());
+	    sy->setLineWidth(it->second->getSymbol()->pen().width());
+	    
+	    if (mVectorLayer->vectorType() == QGis::Point)
+	    {
+		sy->setNamedPointSymbol(it->second->getSymbol()->pointSymbolName());
+		sy->setPointSize(it->second->getSymbol()->pointSize());
 	     
+	    }
 	    
 	    if (mVectorLayer->vectorType() != QGis::Line)
             {
-		sy->brush().setColor(it->second->getSymbol()->brush().color());
-            }
-	    
-	    if (mVectorLayer->vectorType() == QGis::Polygon)
-            {
-		sy->brush().setStyle(it->second->getSymbol()->brush().style());
-	    } 
-	    else if (mVectorLayer->vectorType() == QGis::Point)
-            {
-		sy->brush().setStyle(Qt::SolidPattern);
+		sy->setFillColor(it->second->getSymbol()->brush().color());
+		sy->setFillStyle(it->second->getSymbol()->brush().style());
             }
+
 	    QString lower_bound = it->second->value();
 	    QString upper_bound = it->second->upper_value();
 	    QString label = it->second->label();
@@ -317,7 +321,9 @@ void QgsGraSyDialog::apply()
 		} 
 		else if (mVectorLayer->vectorType() == QGis::Point)
                 {
-		    p.drawRect(leftspace + symbolwidth / 2, offset + (int) (rowincrement * (i + 0.5)), 5, 5);
+		    //p.drawRect(leftspace + symbolwidth / 2, offset + (int) (rowincrement * (i + 0.5)), 5, 5);
+		    QPixmap pm = sy->getPointSymbolAsPixmap();
+		    p.drawPixmap ( (int) (leftspace+symbolwidth/2-pm.width()/2), (int) (offset+rowincrement*(i+0.5)-pm.height()/2), pm );
                 }
 		p.setPen(Qt::black);
 		p.drawText(leftspace + symbolwidth + wordspace, offset + rowincrement * i + rowheight, legendstring);
@@ -400,6 +406,14 @@ void QgsGraSyDialog::adjustClassification()
 	{
 	    double lower=minimum + (maximum - minimum) / numberofclassesspinbox->value() * i;
 	    double upper=minimum + (maximum - minimum) / numberofclassesspinbox->value() * (i+1);
+	    if(i==0)//make sure all feature attributes are between minimum and maximum value (round off problem)
+	      {
+		lower-=0.001;
+	      }
+	    if(i==numberofclassesspinbox->value()-1)
+	      {
+		upper+=0.001;
+	      }
 	    rritem->setValue(QString::number(lower,'f',3));
 	    rritem->setUpperValue(QString::number(upper,'f',3));
 	    listboxtext=QString::number(lower,'f',3)+" - " +QString::number(upper,'f',3);
@@ -453,18 +467,7 @@ void QgsGraSyDialog::changeCurrentValue()
 	std::map<QString,QgsRangeRenderItem*>::iterator it=mEntries.find(value);
 	if(it!=mEntries.end())
 	{
-	    QPen& pen=it->second->getSymbol()->pen();
-	    QBrush& brush=it->second->getSymbol()->brush();
-	    QColor fcolor(brush.color().red(),brush.color().green(),brush.color().blue());
-	    QColor ocolor(pen.color().red(),pen.color().green(),pen.color().blue());
-	    if(mVectorLayer->vectorType()!=QGis::Line)
-	    {
-		sydialog.setFillColor(fcolor);
-		sydialog.setFillStyle(brush.style());
-	    }
-	    sydialog.setOutlineColor(ocolor);
-	    sydialog.setOutlineStyle(pen.style());
-	    sydialog.setOutlineWidth(pen.width());
+	    sydialog.set(it->second->getSymbol() );
 	    sydialog.setLabel(it->second->label());
 	}
     }
@@ -480,13 +483,7 @@ void QgsGraSyDialog::applySymbologyChanges()
 	std::map<QString,QgsRangeRenderItem*>::iterator it=mEntries.find(value);
 	if(it!=mEntries.end())
 	{
-	    QPen& pen=it->second->getSymbol()->pen();
-	    QBrush& brush=it->second->getSymbol()->brush(); 
-	    pen.setWidth(sydialog.getOutlineWidth());
-	    pen.setColor(sydialog.getOutlineColor());
-	    pen.setStyle(sydialog.getOutlineStyle());
-	    brush.setColor(sydialog.getFillColor());
-	    brush.setStyle(sydialog.getFillStyle());
+	    sydialog.apply( it->second->getSymbol() );
 	    it->second->setLabel(sydialog.label());
 	}
     }
@@ -501,7 +498,7 @@ void QgsGraSyDialog::changeClass(QListBoxItem* item)
     {
 	rritem=iter->second;
     }
-    QgsLUDialog dialog;
+    QgsLUDialog dialog(this);
     
     if(rritem)
     {
