@@ -15,8 +15,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsidentifyresults.cpp,v 1.10 2004/11/30 15:33:13 larsl Exp $ */
+/* $Id: qgsidentifyresults.cpp,v 1.14 2005/04/13 06:56:23 telwertowski Exp $ */
 #include <iostream>
+#include <qapplication.h>
 #include <qlistview.h>
 #include <qsettings.h>
 #include <qpoint.h>
@@ -27,12 +28,19 @@
 
 #include "qgsidentifyresults.h"
 
-QgsIdentifyResults::QgsIdentifyResults(const QgsAttributeAction& aa) : mActions(aa), mClickedOnValue(0), mActionPopup(0)
+QgsIdentifyResults::QgsIdentifyResults(const QgsAttributeAction& aa, QWidget *parent, 
+    const char * name, WFlags f) :
+  QgsIdentifyResultsBase ( parent, name, f),
+  mActions(aa), mClickedOnValue(0), mActionPopup(0)
 {
+  lstResults->setResizeMode(QListView::AllColumns);
+
+  connect ( lstResults, SIGNAL(clicked(QListViewItem *)), this, SLOT(clicked(QListViewItem *)));
 }
 
 QgsIdentifyResults::~QgsIdentifyResults()
 {
+  saveWindowLocation();
   delete mActionPopup;
 }
 // Slot called when user clicks the Close button
@@ -54,12 +62,12 @@ void QgsIdentifyResults::closeEvent(QCloseEvent *e)
 // actions that can be applied to the data in the identify results
 // dialog box.
 void QgsIdentifyResults::popupContextMenu(QListViewItem* item, 
-					  const QPoint& p, int i)
+    const QPoint& p, int i)
 {
   // if the user clicked below the end of the attribute list, just return
   if (item == NULL)
     return;
-  
+
   // The assumption is made that an instance of QgsIdentifyResults is
   // created for each new Identify Results dialog box, and that the
   // contents of the popup menu doesn't change during the time that
@@ -73,11 +81,11 @@ void QgsIdentifyResults::popupContextMenu(QListViewItem* item,
     mActionPopup->insertItem(popupLabel);
     mActionPopup->insertSeparator();
 
-    QgsAttributeAction::aIter	iter = mActions.begin();
+    QgsAttributeAction::aIter iter = mActions.begin();
     for (int j = 0; iter != mActions.end(); ++iter, ++j)
     {
       int id = mActionPopup->insertItem(iter->name(), this, 
-					SLOT(popupItemSelected(int)));
+          SLOT(popupItemSelected(int)));
       mActionPopup->setItemParameter(id, j);
     }
   }
@@ -99,7 +107,8 @@ void QgsIdentifyResults::popupContextMenu(QListViewItem* item,
   mValues.clear();
   int j = 0;
   while (child != 0)
-    {
+  {
+    if ( child->text(2) != "action" ) {
       mValues.push_back(std::make_pair(child->text(0), child->text(1)));
       // Need to do the comparison on the text strings rather than the
       // pointers because if the user clicked on the parent, we need
@@ -107,10 +116,11 @@ void QgsIdentifyResults::popupContextMenu(QListViewItem* item,
       // identify results dialog box is just one of the children
       // that has been chosen by some method).
       if (child->text(0) == item->text(0))
-	mClickedOnValue = j;
+        mClickedOnValue = j;
       ++j;
-      child = child->nextSibling();
     }
+    child = child->nextSibling();
+  }
 
   mActionPopup->popup(p);
 }
@@ -145,6 +155,27 @@ void QgsIdentifyResults::addAttribute(QListViewItem * fnode, QString field, QStr
 {
   new QListViewItem(fnode, field, value);
 }
+void QgsIdentifyResults::addAttribute(QString field, QString value)
+{
+  new QListViewItem(lstResults, field, value);
+}
+
+void QgsIdentifyResults::addAction(QListViewItem * fnode, int id, QString field, QString value)
+{
+  QListViewItem *item = new QListViewItem(fnode, field, value, "action", QString::number(id) );
+
+  QString appDir;
+#if defined(WIN32) || defined(Q_OS_MACX)
+  appDir = qApp->applicationDirPath();
+#else
+  appDir = PREFIX;
+#endif
+
+  QString img = appDir + "/share/qgis/themes/default/action.png";
+
+  QPixmap pm ( img );
+  item->setPixmap ( 0, pm ); 
+}
 
 /** Add a feature node to the list */
 QListViewItem *QgsIdentifyResults::addNode(QString label)
@@ -157,6 +188,11 @@ void QgsIdentifyResults::setTitle(QString title)
   setCaption("Identify Results - " + title);
 }
 
+void QgsIdentifyResults::setColumnText ( int column, const QString & label )
+{
+  lstResults->setColumnText ( column, label );
+}
+
 // Run the action that was selected in the popup menu
 void QgsIdentifyResults::popupItemSelected(int id)
 {
@@ -170,3 +206,53 @@ void QgsIdentifyResults::showAllAttributes() {
     lstResults->setOpen(*qlvii, true);
 }
 
+void QgsIdentifyResults::clear()
+{
+  lstResults->clear();
+}
+
+void QgsIdentifyResults::setMessage( QString shortMsg, QString longMsg )
+{
+  new QListViewItem(lstResults, shortMsg, longMsg );
+}
+
+void QgsIdentifyResults::setActions( const QgsAttributeAction& actions  )
+{
+  mActions = actions;
+}
+
+void QgsIdentifyResults::clicked ( QListViewItem *item )
+{
+  if ( !item ) return;
+
+  if ( item->text(2) != "action" ) return;
+
+  int id = item->text(3).toInt();
+
+  QListViewItem* parent = item->parent();
+  QListViewItem* child;
+
+  if (item->parent() == 0)
+    child = item->firstChild();
+  else
+    child = parent->firstChild();
+
+  mValues.clear();
+
+  int j = 0;
+
+  while (child != 0)
+  {
+    if ( child->text(2) != "action" ) {
+      mValues.push_back(std::make_pair(child->text(0), child->text(1)));
+
+      if (child->text(0) == item->text(0))
+        mClickedOnValue = j;
+
+      ++j;
+    }
+    child = child->nextSibling();
+  }
+
+  mActions.doAction(id, mValues, mClickedOnValue);
+}
