@@ -30,6 +30,7 @@
 #include "qgsfeature.h"
 #include "qgsfield.h"
 #include "qgsrect.h"
+#include "qgsmaptopixel.h"
 #include "qgscoordinatetransform.h"
 
 #include "qgslabelattributes.h"
@@ -42,10 +43,10 @@
 #endif
 
 static const char * const ident_ =
-    "$Id: qgslabel.cpp,v 1.21 2004/12/01 01:07:36 mcoletti Exp $";
+    "$Id: qgslabel.cpp,v 1.24.2.4 2005/07/09 23:51:18 timlinux Exp $";
 
 
-QgsLabel::QgsLabel( std::vector<QgsField>& fields )
+QgsLabel::QgsLabel( std::vector<QgsField> const & fields )
 {
 #ifdef QGISDEBUG
     std::cerr << "QgsLabel::QgsLabel()" << std::endl;
@@ -83,8 +84,11 @@ QString QgsLabel::fieldValue ( int attr, QgsFeature *feature )
 }
 
 void QgsLabel::renderLabel( QPainter * painter, QgsRect *viewExtent,
-                            QgsCoordinateTransform *transform, QPaintDevice* device,
-                            QgsFeature *feature, bool selected, QgsLabelAttributes *classAttributes )
+                            const QgsCoordinateTransform& coordTransform,
+                            bool doCoordTransform,
+                            QgsMapToPixel *transform, QPaintDevice* device,
+                            QgsFeature *feature, bool selected, QgsLabelAttributes *classAttributes,
+       			    double sizeScale )
 {
 #if QGISDEBUG > 3
     std::cerr << "QgsLabel::renderLabel()" << std::endl;
@@ -96,7 +100,7 @@ void QgsLabel::renderLabel( QPainter * painter, QgsRect *viewExtent,
     QString text;
     double scale, x1, x2;
 
-    /* Clac scale (not nice) */
+    /* Calc scale (not nice) */
     QgsPoint point;
     point = transform->transform ( 0, 0 );
     x1 = point.x();
@@ -139,6 +143,8 @@ void QgsLabel::renderLabel( QPainter * painter, QgsRect *viewExtent,
     if (  mLabelAttributes->sizeType() == QgsLabelAttributes::MapUnits )
     {
         size *= scale;
+    } else {
+	size *= sizeScale;
     }
     font.setPointSizeFloat ( size );
 
@@ -199,6 +205,23 @@ void QgsLabel::renderLabel( QPainter * painter, QgsRect *viewExtent,
         point.setY ( value.toDouble() );
     }
 
+    // Convert point to projected units
+    if (doCoordTransform)
+    {
+      try
+      {
+	point = (const_cast<QgsCoordinateTransform&>(coordTransform)).transform(point);
+      }
+      catch(QgsCsException &cse)
+      {
+#ifdef QGISDEBUG
+	std::cout << "Caught transform error in QgsLabel::renderLabel(). "
+		  << "Skipping rendering this label" << std::endl;
+#endif	
+	return;
+      }
+    }
+    // and then to canvas units
     transform->transform(&point);
     x = point.x();
     y = point.y();
@@ -548,7 +571,7 @@ void QgsLabel::readXML( const QDomNode& node )
     std::cout << "QgsLabel::readXML() called for layer label properties \n" << std::endl;
 #endif
 
-    qDebug( "%s:%d QgsLabel::readXML() got node %s", __FILE__, __LINE__, node.nodeName().ascii() );
+    qDebug( "%s:%d QgsLabel::readXML() got node %s", __FILE__, __LINE__, (const char *)node.nodeName().local8Bit() );
 
     QDomNode scratchNode;       // DOM node re-used to get current QgsLabel attribute
     QDomElement el;
@@ -799,24 +822,24 @@ void QgsLabel::writeXML(std::ostream& xml)
     // else
     if ( mLabelAttributes->textIsSet() && !mLabelField[Text].isEmpty() )
     {
-        xml << "\t\t\t<label text=\"" << mLabelAttributes->text() << "\" field=\"" << mLabelField[Text] << "\" />\n";
+        xml << "\t\t\t<label text=\"" << (const char*)(mLabelAttributes->text().utf8()) << "\" field=\"" << (const char*)(mLabelField[Text].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->textIsSet() )
     {
-        xml << "\t\t\t<label text=\"" << mLabelAttributes->text() << "\" field=\"\" />\n";
+        xml << "\t\t\t<label text=\"" << (const char*)(mLabelAttributes->text().utf8()) << "\" field=\"\" />\n";
     }
     else
     {
-        xml << "\t\t\t<label text=\"" << mLabelAttributes->text() << "\" field=\"" << mLabelField[Text] << "\" />\n";
+        xml << "\t\t\t<label text=\"" << (const char*)(mLabelAttributes->text().utf8()) << "\" field=\"" << (const char*)(mLabelField[Text].utf8()) << "\" />\n";
     }
 
     if ( mLabelAttributes->familyIsSet() && ! mLabelAttributes->family().isNull() && mLabelField[Family].isNull())
     {
-        xml << "\t\t\t<family name=\"" << mLabelAttributes->family() << "\" field=\"" << mLabelField[Family] << "\" />\n";
+        xml << "\t\t\t<family name=\"" << mLabelAttributes->family().utf8() << "\" field=\"" << (const char*)(mLabelField[Family].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->familyIsSet() && ! mLabelAttributes->family().isNull() )
     {
-        xml << "\t\t\t<family name=\"" << mLabelAttributes->family() << "\" field=\"\" />\n";
+        xml << "\t\t\t<family name=\"" << mLabelAttributes->family().utf8() << "\" field=\"\" />\n";
     }
     else
     {
@@ -827,12 +850,12 @@ void QgsLabel::writeXML(std::ostream& xml)
     if ( mLabelAttributes->sizeIsSet() && !mLabelField[Size].isEmpty())
     {
         xml << "\t\t\t<size value=\"" << mLabelAttributes->size() << "\" units=\""
-            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->sizeType()) << "\" field=\"" << mLabelField[Size] << "\" />\n";
+            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->sizeType()).utf8() << "\" field=\"" << (const char*)(mLabelField[Size].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->sizeIsSet() )
     {
         xml << "\t\t\t<size value=\"" << mLabelAttributes->size() << "\" units=\""
-            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->sizeType()) << "\" field=\"\" />\n";
+            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->sizeType()).utf8() << "\" field=\"\" />\n";
     }
     else
     {
@@ -844,7 +867,7 @@ void QgsLabel::writeXML(std::ostream& xml)
     //bold
     if ( mLabelAttributes->boldIsSet() && !mLabelField[Bold].isEmpty() )
     {
-        xml << "\t\t\t<bold on=\"" << mLabelAttributes->bold() << "\" field=\"" << mLabelField[Bold] << "\" />\n";
+        xml << "\t\t\t<bold on=\"" << mLabelAttributes->bold() << "\" field=\"" << (const char*)(mLabelField[Bold].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->boldIsSet() )
     {
@@ -858,7 +881,7 @@ void QgsLabel::writeXML(std::ostream& xml)
     //italics
     if ( mLabelAttributes->italicIsSet() && ! mLabelField[Italic].isEmpty())
     {
-        xml << "\t\t\t<italic on=\"" << mLabelAttributes->italic() << "\" field=\"" << mLabelField[Italic] << "\" />\n";
+        xml << "\t\t\t<italic on=\"" << mLabelAttributes->italic() << "\" field=\"" << (const char*)(mLabelField[Italic].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->italicIsSet() )
     {
@@ -871,7 +894,7 @@ void QgsLabel::writeXML(std::ostream& xml)
     //underline
     if ( mLabelAttributes->underlineIsSet() && !mLabelField[Underline].isEmpty())
     {
-        xml << "\t\t\t<underline on=\"" << mLabelAttributes->underline() << "\" field=\"" << mLabelField[Underline] << "\" />\n";
+        xml << "\t\t\t<underline on=\"" << mLabelAttributes->underline() << "\" field=\"" << (const char*)(mLabelField[Underline].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->underlineIsSet() )
     {
@@ -885,7 +908,7 @@ void QgsLabel::writeXML(std::ostream& xml)
     if ( mLabelAttributes->colorIsSet() && ! mLabelField[Color].isNull() )
     {
         xml << "\t\t\t<color red=\"" << mLabelAttributes->color().red() << "\" green=\"" << mLabelAttributes->color().green()
-            << "\" blue=\"" << mLabelAttributes->color().blue() << "\" field=\"" << mLabelField[Color] << "\" />\n";
+            << "\" blue=\"" << mLabelAttributes->color().blue() << "\" field=\"" << (const char*)(mLabelField[Color].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->colorIsSet() )
     {
@@ -901,7 +924,7 @@ void QgsLabel::writeXML(std::ostream& xml)
     /* X */
     if (! mLabelField[XCoordinate].isEmpty() )
     {
-      xml << "\t\t\t<x field=\"" << mLabelField[XCoordinate] << "\" />\n";
+      xml << "\t\t\t<x field=\"" << (const char*)(mLabelField[XCoordinate].utf8()) << "\" />\n";
     }
     else
     {
@@ -911,7 +934,7 @@ void QgsLabel::writeXML(std::ostream& xml)
     /* Y */
     if (! mLabelField[YCoordinate].isEmpty() )
     {
-      xml << "\t\t\t<y field=\"" << mLabelField[YCoordinate] << "\" />\n";
+      xml << "\t\t\t<y field=\"" << (const char*)(mLabelField[YCoordinate].utf8()) << "\" />\n";
     }
     else
     {
@@ -921,16 +944,16 @@ void QgsLabel::writeXML(std::ostream& xml)
     // offset
     if ( mLabelAttributes->offsetIsSet() )
     {
-        xml << "\t\t\t<offset  units=\"" << QgsLabelAttributes::unitsName(mLabelAttributes->offsetType())
-            << "\" x=\"" << mLabelAttributes->xOffset() << "\" xfield=\"" << mLabelField[XOffset]
-            << "\" y=\"" << mLabelAttributes->yOffset() << "\" yfield=\"" << mLabelField[YOffset]
+            xml << "\t\t\t<offset  units=\"" << QgsLabelAttributes::unitsName(mLabelAttributes->offsetType()).utf8()
+            << "\" x=\"" << mLabelAttributes->xOffset() << "\" xfield=\"" << (const char*)(mLabelField[XOffset].utf8())
+            << "\" y=\"" << mLabelAttributes->yOffset() << "\" yfield=\"" << (const char*)(mLabelField[YOffset].utf8())
             << "\" />\n";
     }
 
     // Angle
     if ( mLabelAttributes->angleIsSet() )
     {
-        xml << "\t\t\t<angle value=\"" << mLabelAttributes->angle() << "\" field=\"" << mLabelField[Angle] << "\" />\n";
+        xml << "\t\t\t<angle value=\"" << mLabelAttributes->angle() << "\" field=\"" << (const char*)(mLabelField[Angle].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->angleIsSet() )
     {
@@ -944,15 +967,15 @@ void QgsLabel::writeXML(std::ostream& xml)
     // alignment
     if ( mLabelAttributes->alignmentIsSet() )
     {
-        xml << "\t\t\t<alignment value=\"" << QgsLabelAttributes::alignmentName(mLabelAttributes->alignment())
-            << "\" field=\"" << mLabelField[Alignment] << "\" />\n";
+      xml << "\t\t\t<alignment value=\"" << QgsLabelAttributes::alignmentName(mLabelAttributes->alignment()).utf8()
+            << "\" field=\"" << (const char*)(mLabelField[Alignment].utf8()) << "\" />\n";
     }
 
 
     if ( mLabelAttributes->bufferColorIsSet() && ! mLabelField[BufferColor].isNull() )
     {
         xml << "\t\t\t<buffercolor red=\"" << mLabelAttributes->bufferColor().red() << "\" green=\"" << mLabelAttributes->bufferColor().green()
-            << "\" blue=\"" << mLabelAttributes->bufferColor().blue() << "\" field=\"" << mLabelField[BufferColor] << "\" />\n";
+            << "\" blue=\"" << mLabelAttributes->bufferColor().blue() << "\" field=\"" << (const char*)(mLabelField[BufferColor].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->bufferColorIsSet() )
     {
@@ -969,12 +992,12 @@ void QgsLabel::writeXML(std::ostream& xml)
     if ( mLabelAttributes->bufferSizeIsSet() && ! mLabelField[BufferSize].isNull() )
     {
         xml << "\t\t\t<buffersize value=\"" << mLabelAttributes->bufferSize() << "\" units=\""
-            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->bufferSizeType()) << "\" field=\"" << mLabelField[BufferSize] << "\" />\n";
+            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->bufferSizeType()).utf8() << "\" field=\"" << (const char*)(mLabelField[BufferSize].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->bufferSizeIsSet() )
     {
         xml << "\t\t\t<buffersize value=\"" << mLabelAttributes->bufferSize() << "\" units=\""
-            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->bufferSizeType()) << "\" field=\"" << "\" />\n";
+            << (const char *)QgsLabelAttributes::unitsName(mLabelAttributes->bufferSizeType()).utf8() << "\" field=\"" << "\" />\n";
     }
     else
     {
@@ -985,7 +1008,7 @@ void QgsLabel::writeXML(std::ostream& xml)
 
     if ( mLabelAttributes->bufferEnabled() && ! mLabelField[BufferEnabled].isNull() )
     {
-        xml << "\t\t\t<bufferenabled on=\"" << mLabelAttributes->bufferEnabled() << "\" field=\"" << mLabelField[BufferEnabled] << "\" />\n";
+        xml << "\t\t\t<bufferenabled on=\"" << mLabelAttributes->bufferEnabled() << "\" field=\"" << (const char*)(mLabelField[BufferEnabled].utf8()) << "\" />\n";
     }
     else if ( mLabelAttributes->bufferEnabled())
     {
