@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgslegend.cpp,v 1.26 2004/11/27 19:19:16 gsherman Exp $ */
+ /* $Id: qgslegend.cpp,v 1.27.2.1 2005/07/09 23:51:18 timlinux Exp $ */
 #include <map>
 
 
@@ -36,7 +36,7 @@
 #include "qgisapp.h"
 
 
-static const char *const ident_ = "$Id: qgslegend.cpp,v 1.26 2004/11/27 19:19:16 gsherman Exp $";
+static const char *const ident_ = "$Id: qgslegend.cpp,v 1.27.2.1 2005/07/09 23:51:18 timlinux Exp $";
 
 const int AUTOSCROLL_MARGIN = 16;
 
@@ -108,7 +108,7 @@ static QgsLegendItem *findLegendItem_(QgsLegend * legend, QString const &name)
 
       if (li)
         {
-          std::cerr << "comparing " << li->layerID() << " and " << name << "\n";
+          std::cerr << "comparing " << li->layerID().local8Bit() << " and " << name.local8Bit() << "\n";
           if (li->layerID() == name)
             {
               return li;
@@ -212,7 +212,7 @@ void QgsLegend::addLayer(QgsMapLayer * layer)
 
   layer->initContextMenu(mQgisApp);
 
-  const char * layerName = layer->name(); // debugger probe
+  const char * layerName = layer->name().local8Bit(); // debugger probe
 
   QgsLegendItem *legend_item = new QgsLegendItem(layer, this, mQgisApp->actionInOverview);
 
@@ -489,9 +489,12 @@ void QgsLegend::updateLegendItem( QListViewItem * li )
         return;
     }
 
-    if ( qli->layer()->showInOverviewStatus() && ! mQgisApp->actionInOverview->isOn() )
+    if ( qli->layer()->showInOverviewStatus())
     {
-        mQgisApp->actionInOverview->setOn(true);
+	if(!mQgisApp->actionInOverview->isOn())
+	{
+	    mQgisApp->actionInOverview->setOn(true);
+	}
     }
     else
     {
