@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsludialog.h,v 1.3 2004/10/16 21:59:14 gsherman Exp $ */
+/* $Id: qgsludialog.h,v 1.3.6.1 2005/08/31 03:45:17 telwertowski Exp $ */
 
 #ifndef QGSLUDIALOG_H
 #define QGSLUDIALOG_H
@@ -29,7 +29,7 @@ class QgsLUDialog: public QgsLUDialogBase
 {
     Q_OBJECT
  public:
-    QgsLUDialog();
+    QgsLUDialog(QWidget *parent=0, const char *name=0, bool modal=true);
     ~QgsLUDialog();
     QString lowerValue() const;
     void setLowerValue(QString val);
