@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmapcanvas.h,v 1.62.2.5 2004/12/12 00:04:30 mhugent Exp $ */
+/* $Id: qgsmapcanvas.h,v 1.72.2.5 2005/10/24 00:00:18 g_j_m Exp $ */
 
 #ifndef QGSMAPCANVAS_H
 #define QGSMAPCANVAS_H
@@ -40,22 +40,20 @@
 #include <qgspoint.h>
 #endif
 
-#ifndef QGSSCALECALCULATOR_H
-#include <qgsscalecalculator.h>
-#endif
+#include <qgis.h>
 
 class QRect;
 class QColor;
 class QPaintDevice;
 class QMouseEvent;
 
-class QgsCoordinateTransform;
+class QgsMapToPixel;
 class QgsMapLayer;
 class QgsMapLayerInterface;
 class QgsLegend;
 class QgsLegendView;
 class QgsAcetateObject;
-
+class QgsMeasure;
 
 
 /*! \class QgsMapCanvas
@@ -160,13 +158,13 @@ class QgsMapCanvas : public QWidget
     std::list < QString > const & zOrders() const;
     std::list < QString >       & zOrders();
     //! Set map units (needed by project properties dialog)
-    void setMapUnits(QgsScaleCalculator::units mapUnits);
+    void setMapUnits(QGis::units mapUnits);
     //! Get the current canvas map units
 
-    QgsScaleCalculator::units mapUnits() const;
+    QGis::units mapUnits() const;
 
     //! Get the current coordinate transform
-    QgsCoordinateTransform * getCoordinateTransform();
+    QgsMapToPixel * getCoordinateTransform();
     //! Declare the legend class as a friend of the map canvas
     //friend class QgsLegend;
 
@@ -223,6 +221,15 @@ public slots:
      */
      void addAcetateObject(QString key, QgsAcetateObject *obj);
 
+     /**Removes an acetate object from the collection and deletes the object*/
+     void removeAcetateObject(const QString& key);
+
+     /**Removes all entries of mCapturePoints and sets mLineEditing and mPolygonEditing
+	to false (removes the digitising lines from the screen)
+     @param norepaint true: there is no repaint at all. False: QgsMapCanvas
+  decides, if a repaint is necessary or not*/
+     void removeDigitizingLines(bool norepaint=false);
+
     //! The painter device parameter is optional - if ommitted it will default
     // to the pmCanvas (ie the gui map display). The idea is that you can pass
     // an alternative device such as one that will be used for printing or
@@ -271,6 +278,11 @@ public slots:
      */
     void recalculateExtents();
 
+    /** A simple helper method to find out if on the fly projections are enabled or not */
+    bool projectionsEnabled();
+
+    /** The map units may have changed, so cope with that */
+    void mapUnitsChanged();
 
 signals:
     /** Let the owner know how far we are with render operations */
@@ -279,6 +291,7 @@ signals:
     void xyCoordinates(QgsPoint & p);
     /** emits mouse position when the canvas is clicked */
     void xyClickCoordinates(QgsPoint &p);
+    void xyClickCoordinates(QgsPoint &p, Qt::ButtonState button);
 
     //! Emitted when the scale of the map changes
     void scaleChanged(QString);
@@ -310,8 +323,11 @@ signals:
      */
     void removedAll();
 
-private:
+    /** emitted when right mouse button is pressed with zoom tool
+     *  QgisApp should catch it and reset tool to the last non zoom tool */
+    void stopZoom();
 
+private:
     /// this class is non-copyable
     /**
        @note
@@ -338,6 +354,27 @@ private:
        @todo XXX shouldn't this be in mCanvasProperties?
     */
     std::list<QgsPoint> mCaptureList;
+    
+    /**Stores the last position of the mouse cursor when digitising*/
+    QgsPoint mDigitMovePoint;
+
+    /**Stores, if mCaptureList is used for line editing
+     this is needed for the editing rubber band*/
+    bool mLineEditing;
+
+    /**Stores, if mCaptureList is used for polygon editing
+     this is needed for the editing rubber band*/
+    bool mPolygonEditing;
+
+    /**Draws a line from the last point of mCaptureList (if last is true, else from the first point)
+       to mDigitMovePoint using Qt::XorROP. The settings for QPen are read from the QgsProject singleton*/
+    void drawLineToDigitisingCursor(QPainter* paint, bool last = true);
+
+    //! Overridden key press event
+    void keyPressEvent(QKeyEvent * e);
+
+    //! Overridden key release event
+    void keyReleaseEvent(QKeyEvent * e);
 
     //! Overridden mouse move event
     void mouseMoveEvent(QMouseEvent * e);
@@ -367,8 +404,17 @@ private:
     //! Updates the z order for layers on the map
     void updateZpos();
 
+    //! Ends pan action and redraws the canvas.
+    void panActionEnd(QPoint releasePoint);
 
+    //! Called when mouse is moving and pan is activated
+    void panAction(QMouseEvent * event);
 
+    //! Helper function to inverse project a point if projections
+    // are enabled. Failsafe, returns the sent point if anything fails.
+    // @whenmsg is a part fo the error message.
+
+    QgsPoint maybeInversePoint(QgsPoint point, const char whenmsg[]);
     //! detrmines whether the user can interact with the canvas using a mouse
     //(useful for locking the overview canvas)
     bool mUserInteractionAllowed;
@@ -383,6 +429,9 @@ private:
   */
   void connectNotify( const char * signal );
 
+    //! Measure tool
+    QgsMeasure *mMeasure;
+
 }; // class QgsMapCanvas
 
 #endif
