@@ -1,8 +1,8 @@
 /****************************************************************************
 ** QgsMapCanvas meta object code from reading C++ file 'qgsmapcanvas.h'
 **
-** Created: Fri Dec 17 09:40:20 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:08:55 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,7 +14,7 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -71,53 +71,67 @@ QMetaObject* QgsMapCanvas::staticMetaObject()
 	{ "obj", &static_QUType_ptr, "QgsAcetateObject", QUParameter::In }
     };
     static const QUMethod slot_5 = {"addAcetateObject", 2, param_slot_5 };
-    static const QUMethod slot_6 = {"render", 0, 0 };
-    static const QUParameter param_slot_7[] = {
+    static const QUParameter param_slot_6[] = {
+	{ "key", &static_QUType_QString, 0, QUParameter::In }
+    };
+    static const QUMethod slot_6 = {"removeAcetateObject", 1, param_slot_6 };
+    static const QUMethod slot_7 = {"removeDigitizingLines", 0, 0 };
+    static const QUParameter param_slot_8[] = {
+	{ "norepaint", &static_QUType_bool, 0, QUParameter::In }
+    };
+    static const QUMethod slot_8 = {"removeDigitizingLines", 1, param_slot_8 };
+    static const QUMethod slot_9 = {"render", 0, 0 };
+    static const QUParameter param_slot_10[] = {
 	{ "theQPaintDevice", &static_QUType_ptr, "QPaintDevice", QUParameter::In }
     };
-    static const QUMethod slot_7 = {"render", 1, param_slot_7 };
-    static const QUParameter param_slot_8[] = {
+    static const QUMethod slot_10 = {"render", 1, param_slot_10 };
+    static const QUParameter param_slot_11[] = {
 	{ "theFileName", &static_QUType_QString, 0, QUParameter::In }
     };
-    static const QUMethod slot_8 = {"saveAsImage", 1, param_slot_8 };
-    static const QUParameter param_slot_9[] = {
+    static const QUMethod slot_11 = {"saveAsImage", 1, param_slot_11 };
+    static const QUParameter param_slot_12[] = {
 	{ "theFileName", &static_QUType_QString, 0, QUParameter::In },
 	{ "QPixmap", &static_QUType_varptr, "\x06", QUParameter::In }
     };
-    static const QUMethod slot_9 = {"saveAsImage", 2, param_slot_9 };
-    static const QUParameter param_slot_10[] = {
+    static const QUMethod slot_12 = {"saveAsImage", 2, param_slot_12 };
+    static const QUParameter param_slot_13[] = {
 	{ "theFileName", &static_QUType_QString, 0, QUParameter::In },
 	{ "QPixmap", &static_QUType_varptr, "\x06", QUParameter::In },
 	{ 0, &static_QUType_QString, 0, QUParameter::In }
     };
-    static const QUMethod slot_10 = {"saveAsImage", 3, param_slot_10 };
-    static const QUMethod slot_11 = {"layerStateChange", 0, 0 };
-    static const QUParameter param_slot_12[] = {
+    static const QUMethod slot_13 = {"saveAsImage", 3, param_slot_13 };
+    static const QUMethod slot_14 = {"layerStateChange", 0, 0 };
+    static const QUParameter param_slot_15[] = {
 	{ "lv", &static_QUType_ptr, "QgsLegend", QUParameter::In }
     };
-    static const QUMethod slot_12 = {"setZOrderFromLegend", 1, param_slot_12 };
-    static const QUParameter param_slot_13[] = {
+    static const QUMethod slot_15 = {"setZOrderFromLegend", 1, param_slot_15 };
+    static const QUParameter param_slot_16[] = {
 	{ 0, &static_QUType_bool, 0, QUParameter::In }
     };
-    static const QUMethod slot_13 = {"userInteractionAllowed", 1, param_slot_13 };
-    static const QUParameter param_slot_14[] = {
+    static const QUMethod slot_16 = {"userInteractionAllowed", 1, param_slot_16 };
+    static const QUParameter param_slot_17[] = {
 	{ 0, &static_QUType_bool, 0, QUParameter::Out }
     };
-    static const QUMethod slot_14 = {"isUserInteractionAllowed", 1, param_slot_14 };
-    static const QUParameter param_slot_15[] = {
+    static const QUMethod slot_17 = {"isUserInteractionAllowed", 1, param_slot_17 };
+    static const QUParameter param_slot_18[] = {
 	{ "theFlag", &static_QUType_bool, 0, QUParameter::In }
     };
-    static const QUMethod slot_15 = {"setRenderFlag", 1, param_slot_15 };
-    static const QUParameter param_slot_16[] = {
+    static const QUMethod slot_18 = {"setRenderFlag", 1, param_slot_18 };
+    static const QUParameter param_slot_19[] = {
 	{ 0, &static_QUType_bool, 0, QUParameter::Out }
     };
-    static const QUMethod slot_16 = {"renderFlag", 1, param_slot_16 };
-    static const QUParameter param_slot_17[] = {
+    static const QUMethod slot_19 = {"renderFlag", 1, param_slot_19 };
+    static const QUParameter param_slot_20[] = {
 	{ "maplayer", &static_QUType_ptr, "QgsMapLayer", QUParameter::In },
 	{ "visible", &static_QUType_bool, 0, QUParameter::In }
     };
-    static const QUMethod slot_17 = {"showInOverview", 2, param_slot_17 };
-    static const QUMethod slot_18 = {"recalculateExtents", 0, 0 };
+    static const QUMethod slot_20 = {"showInOverview", 2, param_slot_20 };
+    static const QUMethod slot_21 = {"recalculateExtents", 0, 0 };
+    static const QUParameter param_slot_22[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::Out }
+    };
+    static const QUMethod slot_22 = {"projectionsEnabled", 1, param_slot_22 };
+    static const QUMethod slot_23 = {"mapUnitsChanged", 0, 0 };
     static const QMetaData slot_tbl[] = {
 	{ "addLayer(QgsMapLayer*)", &slot_0, QMetaData::Public },
 	{ "addLayer(QgsMapLayerInterface*)", &slot_1, QMetaData::Public },
@@ -125,19 +139,24 @@ QMetaObject* QgsMapCanvas::staticMetaObject()
 	{ "removeAll()", &slot_3, QMetaData::Public },
 	{ "refresh()", &slot_4, QMetaData::Public },
 	{ "addAcetateObject(QString,QgsAcetateObject*)", &slot_5, QMetaData::Public },
-	{ "render()", &slot_6, QMetaData::Public },
-	{ "render(QPaintDevice*)", &slot_7, QMetaData::Public },
-	{ "saveAsImage(QString)", &slot_8, QMetaData::Public },
-	{ "saveAsImage(QString,QPixmap*)", &slot_9, QMetaData::Public },
-	{ "saveAsImage(QString,QPixmap*,QString)", &slot_10, QMetaData::Public },
-	{ "layerStateChange()", &slot_11, QMetaData::Public },
-	{ "setZOrderFromLegend(QgsLegend*)", &slot_12, QMetaData::Public },
-	{ "userInteractionAllowed(bool)", &slot_13, QMetaData::Public },
-	{ "isUserInteractionAllowed()", &slot_14, QMetaData::Public },
-	{ "setRenderFlag(bool)", &slot_15, QMetaData::Public },
-	{ "renderFlag()", &slot_16, QMetaData::Public },
-	{ "showInOverview(QgsMapLayer*,bool)", &slot_17, QMetaData::Public },
-	{ "recalculateExtents()", &slot_18, QMetaData::Public }
+	{ "removeAcetateObject(const QString&)", &slot_6, QMetaData::Public },
+	{ "removeDigitizingLines()", &slot_7, QMetaData::Public },
+	{ "removeDigitizingLines(bool)", &slot_8, QMetaData::Public },
+	{ "render()", &slot_9, QMetaData::Public },
+	{ "render(QPaintDevice*)", &slot_10, QMetaData::Public },
+	{ "saveAsImage(QString)", &slot_11, QMetaData::Public },
+	{ "saveAsImage(QString,QPixmap*)", &slot_12, QMetaData::Public },
+	{ "saveAsImage(QString,QPixmap*,QString)", &slot_13, QMetaData::Public },
+	{ "layerStateChange()", &slot_14, QMetaData::Public },
+	{ "setZOrderFromLegend(QgsLegend*)", &slot_15, QMetaData::Public },
+	{ "userInteractionAllowed(bool)", &slot_16, QMetaData::Public },
+	{ "isUserInteractionAllowed()", &slot_17, QMetaData::Public },
+	{ "setRenderFlag(bool)", &slot_18, QMetaData::Public },
+	{ "renderFlag()", &slot_19, QMetaData::Public },
+	{ "showInOverview(QgsMapLayer*,bool)", &slot_20, QMetaData::Public },
+	{ "recalculateExtents()", &slot_21, QMetaData::Public },
+	{ "projectionsEnabled()", &slot_22, QMetaData::Public },
+	{ "mapUnitsChanged()", &slot_23, QMetaData::Public }
     };
     static const QUParameter param_signal_0[] = {
 	{ 0, &static_QUType_int, 0, QUParameter::In },
@@ -153,41 +172,49 @@ QMetaObject* QgsMapCanvas::staticMetaObject()
     };
     static const QUMethod signal_2 = {"xyClickCoordinates", 1, param_signal_2 };
     static const QUParameter param_signal_3[] = {
+	{ "p", &static_QUType_ptr, "QgsPoint", QUParameter::InOut },
+	{ "button", &static_QUType_ptr, "Qt::ButtonState", QUParameter::In }
+    };
+    static const QUMethod signal_3 = {"xyClickCoordinates", 2, param_signal_3 };
+    static const QUParameter param_signal_4[] = {
 	{ 0, &static_QUType_QString, 0, QUParameter::In }
     };
-    static const QUMethod signal_3 = {"scaleChanged", 1, param_signal_3 };
-    static const QUParameter param_signal_4[] = {
+    static const QUMethod signal_4 = {"scaleChanged", 1, param_signal_4 };
+    static const QUParameter param_signal_5[] = {
 	{ 0, &static_QUType_ptr, "QgsRect", QUParameter::In }
     };
-    static const QUMethod signal_4 = {"extentsChanged", 1, param_signal_4 };
-    static const QUParameter param_signal_5[] = {
+    static const QUMethod signal_5 = {"extentsChanged", 1, param_signal_5 };
+    static const QUParameter param_signal_6[] = {
 	{ 0, &static_QUType_ptr, "QPainter", QUParameter::In }
     };
-    static const QUMethod signal_5 = {"renderComplete", 1, param_signal_5 };
-    static const QUParameter param_signal_6[] = {
+    static const QUMethod signal_6 = {"renderComplete", 1, param_signal_6 };
+    static const QUParameter param_signal_7[] = {
 	{ "lyr", &static_QUType_ptr, "QgsMapLayer", QUParameter::In }
     };
-    static const QUMethod signal_6 = {"addedLayer", 1, param_signal_6 };
-    static const QUParameter param_signal_7[] = {
+    static const QUMethod signal_7 = {"addedLayer", 1, param_signal_7 };
+    static const QUParameter param_signal_8[] = {
 	{ "layer_key", &static_QUType_QString, 0, QUParameter::In }
     };
-    static const QUMethod signal_7 = {"removedLayer", 1, param_signal_7 };
-    static const QUMethod signal_8 = {"removedAll", 0, 0 };
+    static const QUMethod signal_8 = {"removedLayer", 1, param_signal_8 };
+    static const QUMethod signal_9 = {"removedAll", 0, 0 };
+    static const QUMethod signal_10 = {"stopZoom", 0, 0 };
     static const QMetaData signal_tbl[] = {
 	{ "setProgress(int,int)", &signal_0, QMetaData::Public },
 	{ "xyCoordinates(QgsPoint&)", &signal_1, QMetaData::Public },
 	{ "xyClickCoordinates(QgsPoint&)", &signal_2, QMetaData::Public },
-	{ "scaleChanged(QString)", &signal_3, QMetaData::Public },
-	{ "extentsChanged(QgsRect)", &signal_4, QMetaData::Public },
-	{ "renderComplete(QPainter*)", &signal_5, QMetaData::Public },
-	{ "addedLayer(QgsMapLayer*)", &signal_6, QMetaData::Public },
-	{ "removedLayer(QString)", &signal_7, QMetaData::Public },
-	{ "removedAll()", &signal_8, QMetaData::Public }
+	{ "xyClickCoordinates(QgsPoint&,Qt::ButtonState)", &signal_3, QMetaData::Public },
+	{ "scaleChanged(QString)", &signal_4, QMetaData::Public },
+	{ "extentsChanged(QgsRect)", &signal_5, QMetaData::Public },
+	{ "renderComplete(QPainter*)", &signal_6, QMetaData::Public },
+	{ "addedLayer(QgsMapLayer*)", &signal_7, QMetaData::Public },
+	{ "removedLayer(QString)", &signal_8, QMetaData::Public },
+	{ "removedAll()", &signal_9, QMetaData::Public },
+	{ "stopZoom()", &signal_10, QMetaData::Public }
     };
     metaObj = QMetaObject::new_metaobject(
 	"QgsMapCanvas", parentObject,
-	slot_tbl, 19,
-	signal_tbl, 9,
+	slot_tbl, 24,
+	signal_tbl, 11,
 #ifndef QT_NO_PROPERTIES
 	0, 0,
 	0, 0,
@@ -247,10 +274,24 @@ void QgsMapCanvas::xyClickCoordinates( QgsPoint& t0 )
     activate_signal( clist, o );
 }
 
+// SIGNAL xyClickCoordinates
+void QgsMapCanvas::xyClickCoordinates( QgsPoint& t0, Qt::ButtonState t1 )
+{
+    if ( signalsBlocked() )
+	return;
+    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 3 );
+    if ( !clist )
+	return;
+    QUObject o[3];
+    static_QUType_ptr.set(o+1,&t0);
+    static_QUType_ptr.set(o+2,&t1);
+    activate_signal( clist, o );
+}
+
 // SIGNAL scaleChanged
 void QgsMapCanvas::scaleChanged( QString t0 )
 {
-    activate_signal( staticMetaObject()->signalOffset() + 3, t0 );
+    activate_signal( staticMetaObject()->signalOffset() + 4, t0 );
 }
 
 // SIGNAL extentsChanged
@@ -258,7 +299,7 @@ void QgsMapCanvas::extentsChanged( QgsRect t0 )
 {
     if ( signalsBlocked() )
 	return;
-    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 4 );
+    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 5 );
     if ( !clist )
 	return;
     QUObject o[2];
@@ -271,7 +312,7 @@ void QgsMapCanvas::renderComplete( QPainter* t0 )
 {
     if ( signalsBlocked() )
 	return;
-    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 5 );
+    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 6 );
     if ( !clist )
 	return;
     QUObject o[2];
@@ -284,7 +325,7 @@ void QgsMapCanvas::addedLayer( QgsMapLayer* t0 )
 {
     if ( signalsBlocked() )
 	return;
-    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 6 );
+    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 7 );
     if ( !clist )
 	return;
     QUObject o[2];
@@ -295,13 +336,19 @@ void QgsMapCanvas::addedLayer( QgsMapLayer* t0 )
 // SIGNAL removedLayer
 void QgsMapCanvas::removedLayer( QString t0 )
 {
-    activate_signal( staticMetaObject()->signalOffset() + 7, t0 );
+    activate_signal( staticMetaObject()->signalOffset() + 8, t0 );
 }
 
 // SIGNAL removedAll
 void QgsMapCanvas::removedAll()
 {
-    activate_signal( staticMetaObject()->signalOffset() + 8 );
+    activate_signal( staticMetaObject()->signalOffset() + 9 );
+}
+
+// SIGNAL stopZoom
+void QgsMapCanvas::stopZoom()
+{
+    activate_signal( staticMetaObject()->signalOffset() + 10 );
 }
 
 bool QgsMapCanvas::qt_invoke( int _id, QUObject* _o )
@@ -313,19 +360,24 @@ bool QgsMapCanvas::qt_invoke( int _id, QUObject* _o )
     case 3: removeAll(); break;
     case 4: refresh(); break;
     case 5: addAcetateObject((QString)static_QUType_QString.get(_o+1),(QgsAcetateObject*)static_QUType_ptr.get(_o+2)); break;
-    case 6: render(); break;
-    case 7: render((QPaintDevice*)static_QUType_ptr.get(_o+1)); break;
-    case 8: saveAsImage((QString)static_QUType_QString.get(_o+1)); break;
-    case 9: saveAsImage((QString)static_QUType_QString.get(_o+1),(QPixmap*)static_QUType_varptr.get(_o+2)); break;
-    case 10: saveAsImage((QString)static_QUType_QString.get(_o+1),(QPixmap*)static_QUType_varptr.get(_o+2),(QString)static_QUType_QString.get(_o+3)); break;
-    case 11: layerStateChange(); break;
-    case 12: setZOrderFromLegend((QgsLegend*)static_QUType_ptr.get(_o+1)); break;
-    case 13: userInteractionAllowed((bool)static_QUType_bool.get(_o+1)); break;
-    case 14: static_QUType_bool.set(_o,isUserInteractionAllowed()); break;
-    case 15: setRenderFlag((bool)static_QUType_bool.get(_o+1)); break;
-    case 16: static_QUType_bool.set(_o,renderFlag()); break;
-    case 17: showInOverview((QgsMapLayer*)static_QUType_ptr.get(_o+1),(bool)static_QUType_bool.get(_o+2)); break;
-    case 18: recalculateExtents(); break;
+    case 6: removeAcetateObject((const QString&)static_QUType_QString.get(_o+1)); break;
+    case 7: removeDigitizingLines(); break;
+    case 8: removeDigitizingLines((bool)static_QUType_bool.get(_o+1)); break;
+    case 9: render(); break;
+    case 10: render((QPaintDevice*)static_QUType_ptr.get(_o+1)); break;
+    case 11: saveAsImage((QString)static_QUType_QString.get(_o+1)); break;
+    case 12: saveAsImage((QString)static_QUType_QString.get(_o+1),(QPixmap*)static_QUType_varptr.get(_o+2)); break;
+    case 13: saveAsImage((QString)static_QUType_QString.get(_o+1),(QPixmap*)static_QUType_varptr.get(_o+2),(QString)static_QUType_QString.get(_o+3)); break;
+    case 14: layerStateChange(); break;
+    case 15: setZOrderFromLegend((QgsLegend*)static_QUType_ptr.get(_o+1)); break;
+    case 16: userInteractionAllowed((bool)static_QUType_bool.get(_o+1)); break;
+    case 17: static_QUType_bool.set(_o,isUserInteractionAllowed()); break;
+    case 18: setRenderFlag((bool)static_QUType_bool.get(_o+1)); break;
+    case 19: static_QUType_bool.set(_o,renderFlag()); break;
+    case 20: showInOverview((QgsMapLayer*)static_QUType_ptr.get(_o+1),(bool)static_QUType_bool.get(_o+2)); break;
+    case 21: recalculateExtents(); break;
+    case 22: static_QUType_bool.set(_o,projectionsEnabled()); break;
+    case 23: mapUnitsChanged(); break;
     default:
 	return QWidget::qt_invoke( _id, _o );
     }
@@ -338,12 +390,14 @@ bool QgsMapCanvas::qt_emit( int _id, QUObject* _o )
     case 0: setProgress((int)static_QUType_int.get(_o+1),(int)static_QUType_int.get(_o+2)); break;
     case 1: xyCoordinates((QgsPoint&)*((QgsPoint*)static_QUType_ptr.get(_o+1))); break;
     case 2: xyClickCoordinates((QgsPoint&)*((QgsPoint*)static_QUType_ptr.get(_o+1))); break;
-    case 3: scaleChanged((QString)static_QUType_QString.get(_o+1)); break;
-    case 4: extentsChanged((QgsRect)(*((QgsRect*)static_QUType_ptr.get(_o+1)))); break;
-    case 5: renderComplete((QPainter*)static_QUType_ptr.get(_o+1)); break;
-    case 6: addedLayer((QgsMapLayer*)static_QUType_ptr.get(_o+1)); break;
-    case 7: removedLayer((QString)static_QUType_QString.get(_o+1)); break;
-    case 8: removedAll(); break;
+    case 3: xyClickCoordinates((QgsPoint&)*((QgsPoint*)static_QUType_ptr.get(_o+1)),(Qt::ButtonState)(*((Qt::ButtonState*)static_QUType_ptr.get(_o+2)))); break;
+    case 4: scaleChanged((QString)static_QUType_QString.get(_o+1)); break;
+    case 5: extentsChanged((QgsRect)(*((QgsRect*)static_QUType_ptr.get(_o+1)))); break;
+    case 6: renderComplete((QPainter*)static_QUType_ptr.get(_o+1)); break;
+    case 7: addedLayer((QgsMapLayer*)static_QUType_ptr.get(_o+1)); break;
+    case 8: removedLayer((QString)static_QUType_QString.get(_o+1)); break;
+    case 9: removedAll(); break;
+    case 10: stopZoom(); break;
     default:
 	return QWidget::qt_emit(_id,_o);
     }
