@@ -14,10 +14,12 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmaplayer.cpp,v 1.56.2.1 2004/12/05 21:19:21 g_j_m Exp $ */
+/* $Id: qgsmaplayer.cpp,v 1.67.2.12 2005/09/21 22:51:25 timlinux Exp $ */
 
 #include <cfloat>
 #include <iostream>
+#include <limits>
+#include <cmath>
 
 #include <qapplication.h>
 #include <qdatetime.h>
@@ -30,6 +32,7 @@
 #include <qevent.h>
 
 #include "qgsrect.h"
+#include "qgsproject.h"
 #include "qgssymbol.h"
 #include "qgsmaplayer.h"
 #include "qgslegenditem.h"
@@ -42,6 +45,7 @@ QgsMapLayer::QgsMapLayer(int type,
                          QString source)
         : internalName(lyrname),
         ID(""),
+	mCoordinateTransform(NULL),
         layerType(type),
         dataSource(source),
         m_legendItem(0),
@@ -58,6 +62,7 @@ QgsMapLayer::QgsMapLayer(int type,
     // Generate the unique ID of this layer
     QDateTime dt = QDateTime::currentDateTime();
     ID = lyrname + dt.toString("yyyyMMddhhmmsszzz");
+    ID.replace(" ", "_");
 
 #if defined(WIN32) || defined(Q_OS_MACX)
 
@@ -66,13 +71,15 @@ QgsMapLayer::QgsMapLayer(int type,
 
     mInOverviewPixmap.load(QString(PKGDATAPATH) + QString("/images/icons/inoverview.png"));
     mEditablePixmap.load(QString(PKGDATAPATH) + QString("/images/icons/editable.png"));
-
+    mProjectionErrorPixmap.load(QString(PKGDATAPATH) + QString("/images/icons/icon_projection_problem.png"));
     //mActionInOverview = new QAction( "in Overview", "Ctrl+O", this );
 
     //set some generous  defaults for scale based visibility
     mMinScale = 0;
     mMaxScale = 100000000;
     mScaleBasedVisibility = false;
+    
+
 
 }
 
@@ -121,20 +128,23 @@ const QgsRect QgsMapLayer::extent()
 QgsRect QgsMapLayer::calculateExtent()
 {
     //just to prevent any crashes
-    QgsRect rect(DBL_MAX, DBL_MAX, DBL_MIN, DBL_MIN);
+    QgsRect rect;
+    
+    rect.setMinimal();
     return rect;
 }
+
 void QgsMapLayer::draw(QPainter *, QgsRect * viewExtent, int yTransform)
 {
     //  std::cout << "In QgsMapLayer::draw" << std::endl;
 }
 
-void QgsMapLayer::draw(QPainter *, QgsRect *, QgsCoordinateTransform *,QPaintDevice * )
+void QgsMapLayer::draw(QPainter *, QgsRect *, QgsMapToPixel *,QPaintDevice * )
 {
     //  std::cout << "In QgsMapLayer::draw" << std::endl;
 }
 
-void QgsMapLayer::drawLabels(QPainter *, QgsRect *, QgsCoordinateTransform *,QPaintDevice * )
+void QgsMapLayer::drawLabels(QPainter *, QgsRect *, QgsMapToPixel *,QPaintDevice * )
 {
     //  std::cout << "In QgsMapLayer::draw" << std::endl;
 }
@@ -186,28 +196,44 @@ bool QgsMapLayer::readXML( QDomNode & layer_node )
     }
     setMinScale(element.attribute("minScale").toFloat());
     setMaxScale(element.attribute("maxScale").toFloat());
+
     // set data source
     QDomNode mnl = layer_node.namedItem("datasource");
     QDomElement mne = mnl.toElement();
     dataSource = mne.text();
 
-    const char * dataSourceStr = dataSource; // debugger probe
+    const char * dataSourceStr = dataSource.local8Bit(); // debugger probe
 
     // the internal name is just the data source basename
     QFileInfo dataSourceFileInfo( dataSource );
     internalName = dataSourceFileInfo.baseName();
 
+    // set ID
+    mnl = layer_node.namedItem("id");
+    if ( ! mnl.isNull() ) 
+    {
+        mne = mnl.toElement();
+        if ( ! mne.isNull() && mne.text().length() > 10 ) { // should be at least 17 (yyyyMMddhhmmsszzz)
+	    ID = mne.text();
+	}
+    }
+
     // set name
     mnl = layer_node.namedItem("layername");
     mne = mnl.toElement();
     setLayerName( mne.text() );
 
-    const char * layerNameStr = mne.text(); // debugger probe
+    const char * layerNameStr = mne.text().local8Bit(); // debugger probe
 
-    // process zorder
-    mnl = layer_node.namedItem("zorder");
-    mne = mnl.toElement();
-    // XXX and do what with it?
+
+
+    //read srs
+    QDomNode srsNode = layer_node.namedItem("coordinatetransform");
+    if( ! srsNode.isNull()  )
+    {
+       mCoordinateTransform=new QgsCoordinateTransform();
+       mCoordinateTransform->readXML(srsNode);
+    }
 
     // now let the children grab what they need from the DOM node.
     return readXML_( layer_node );
@@ -262,6 +288,13 @@ bool QgsMapLayer::writeXML( QDomNode & layer_node, QDomDocument & document )
     maplayer.setAttribute( "minScale", minScale() );
     maplayer.setAttribute( "maxScale", maxScale() );
 
+    // ID 
+    QDomElement id = document.createElement( "id" );
+    QDomText idText = document.createTextNode( getLayerID() );
+    id.appendChild( idText );
+
+    maplayer.appendChild( id );
+
     // data source
     QDomElement dataSource = document.createElement( "datasource" );
     QDomText dataSourceText = document.createTextNode( source() );
@@ -281,6 +314,9 @@ bool QgsMapLayer::writeXML( QDomNode & layer_node, QDomDocument & document )
     // This is no longer stored in the project file. It is superflous since the layers
     // are written and read in the proper order.
 
+    //write the projection 
+    mCoordinateTransform->writeXML(maplayer,document);
+
     // now append layer node to map layer node
 
     layer_node.appendChild( maplayer );
@@ -338,7 +374,7 @@ void QgsMapLayer::inOverview( bool b )
     mShowInOverview = b;
 
     if ( updateNecessary ) // update the show in overview popup menu item
-    {
+    {	
         updateOverviewPopupItem();
         updateItemPixmap();
 
@@ -392,6 +428,24 @@ void QgsMapLayer::updateItemPixmap()
     }
 }
 
+void QgsMapLayer::invalidTransformInput()
+{
+#ifdef QGISDEBUG
+  std::cout << " QgsMapLayer::invalidTransformInput() called" << std::endl;
+#endif
+    if (m_legendItem)             // XXX should we know about our legend?
+    {
+        QPixmap pix=*(this->legendPixmap());
+        if(mShowInOverview)
+        {
+            //add overview glasses to the pixmap
+            QPainter p(&pix);
+            p.drawPixmap(60,0,mProjectionErrorPixmap);
+        }
+        ((QCheckListItem *) m_legendItem)->setPixmap(0,pix);
+    }
+}
+
 void QgsMapLayer::updateOverviewPopupItem()
 {
     if (mShowInOverviewItemId != 0)
@@ -514,5 +568,94 @@ void QgsMapLayer::initContextMenu(QgisApp * app)
 void QgsMapLayer::keyPressed ( QKeyEvent * e )
 {
   if (e->key()==Qt::Key_Escape) mDrawingCancelled = true;
-  std::cout << e->ascii() << " pressed in maplayer !" << std::endl;
+// The following statment causes a crash on WIN32 and should be 
+// enclosed in an #ifdef QGISDEBUG if its really necessary. Its
+// commented out for now. [gsherman]
+//  std::cout << e->text().local8Bit() << " pressed in maplayer !" << std::endl;
+  e->ignore();
+}
+
+    /** Accessor for the coordinate transformation object */
+QgsCoordinateTransform * QgsMapLayer::coordinateTransform() 
+{
+#ifdef QGISDEBUG
+ std::cout << "Maplayer asked for coordinateTransform which is...." ;
+ if (!mCoordinateTransform)
+ {
+   std::cout << "*NOT* valid" << std::endl;
+ }
+ else
+ {
+   std::cout << "valid" << std::endl;
+ }
+ 
+#endif
+  
+ return mCoordinateTransform;
+}
+
+bool QgsMapLayer::projectionsEnabled() const
+{
+  if (QgsProject::instance()->readNumEntry("SpatialRefSys","/ProjectionsEnabled",0)!=0)
+  {
+    return true;
+  }
+  else
+  {
+    return false;
+  }
+}
+
+bool QgsMapLayer::projectExtent(QgsRect& extent, QgsRect& r2)
+{
+  bool split = false;
+
+  if (projectionsEnabled())
+  {
+    try
+    {
+#ifdef QGISDEBUG
+      std::cerr << "Getting extent of canvas in layers CS. Canvas is " 
+                << extent << '\n'; 
+#endif
+      // Split the extent into two if the source SRS is
+      // geographic and the extent crosses the split in
+      // geographic coordinates (usually +/- 180 degrees,
+      // and is assumed to be so here), and draw each
+      // extent separately.
+      static const double splitCoord = 180.0;
+
+      if (mCoordinateTransform->sourceSRS().geographicFlag())
+      {
+        // Note: ll = lower left point
+        //   and ur = upper right point
+        QgsPoint ll = mCoordinateTransform->transform(
+                          extent.xMin(), extent.yMin(), 
+                          QgsCoordinateTransform::INVERSE);
+
+        QgsPoint ur = mCoordinateTransform->transform(
+                          extent.xMax(), extent.yMax(), 
+                          QgsCoordinateTransform::INVERSE);
+
+        if (ll.x() > ur.x())
+        {
+          extent.set(ll, QgsPoint(splitCoord, ur.y()));
+          r2.set(QgsPoint(-splitCoord, ll.y()), ur);
+          split = true;
+        }
+        else // no need to split
+          extent = mCoordinateTransform->transformBoundingBox(extent, QgsCoordinateTransform::INVERSE);
+      }
+      else // can't cross 180
+        extent = mCoordinateTransform->transformBoundingBox(extent, QgsCoordinateTransform::INVERSE);
+    }
+    catch (QgsCsException &cse)
+      {
+        qDebug( "Transform error caught in %s line %d:\n%s", 
+                __FILE__, __LINE__, cse.what());
+        extent = QgsRect(-DBL_MAX, -DBL_MAX, DBL_MAX, DBL_MAX);
+        r2     = QgsRect(-DBL_MAX, -DBL_MAX, DBL_MAX, DBL_MAX);
+      }
+  }
+  return split;
 }
