@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmaplayer.h,v 1.59.2.1 2004/12/04 02:04:29 timlinux Exp $ */
+/* $Id: qgsmaplayer.h,v 1.70.2.4 2005/07/06 05:45:14 timlinux Exp $ */
 
 #ifndef QGSMAPLAYER_H
 #define QGSMAPLAYER_H
@@ -27,11 +27,14 @@
 
 #include <qgsrect.h>
 #include <qgis.h>
-#include <qgscoordinatetransform.h>
+#include <qgsmaptopixel.h>
 #include <qgisapp.h>
 #include <qgssymbol.h>
 #include <qgsfield.h>
 
+#include <qgscoordinatetransform.h>
+
+
 class QgsFeature;
 class QPopupMenu;
 class QgsLegendItem;
@@ -97,8 +100,8 @@ public:
 
 
     virtual void draw(QPainter *, QgsRect *, int);
-    virtual void draw(QPainter *, QgsRect *, QgsCoordinateTransform * ,QPaintDevice *);
-    virtual void drawLabels(QPainter *, QgsRect *, QgsCoordinateTransform * ,QPaintDevice *);
+    virtual void draw(QPainter *, QgsRect *, QgsMapToPixel * ,QPaintDevice *);
+    virtual void drawLabels(QPainter *, QgsRect *, QgsMapToPixel * ,QPaintDevice *);
     /*! Identify the feature(s) in this layer that are contained in the search rectangle
      */
     virtual void identify(QgsRect *)
@@ -267,7 +270,24 @@ public:
     */
     bool writeXML( QDomNode & layer_node, QDomDocument & document );
 
+    /** Accessor for the coordinate transformation object */
+    QgsCoordinateTransform * coordinateTransform();
+
+    /** A simple helper method to find out if on the fly projections 
+        are enabled or not */
+    bool projectionsEnabled() const;
+    
+    // Convenience function to project an extent into the layer source
+    // SRS, but also split it into two extents if it crosses
+    // the +/- 180 degree line. Modifies the given extent to be in the
+    // source SRS coordinates, and if it was split, returns true, and
+    // also sets the contents of the r2 parameter
+    bool projectExtent(QgsRect& extent, QgsRect& r2);
+
 public  slots:
+   //! event handler for when a coordinate transofrm fails due to bad vertex error
+   virtual void invalidTransformInput();
+
 
     //! keyPress event so we can check if cancel was pressed
     void keyPressed ( QKeyEvent * e );
@@ -323,6 +343,8 @@ public  slots:
         return mScaleBasedVisibility;
     };
 
+    /** Used to ask the layer for its projection as a WKT string. Must be reimplemented by each provider. */
+    virtual QString getProjectionWKT()  = 0 ;
 signals:
 
     void visibilityChanged(void);
@@ -347,12 +369,12 @@ signals:
 
 protected:
 
+  
     /** called by readXML(), used by children to read state specific to them from
         project files.
     */
     virtual bool readXML_( QDomNode & layer_node );
 
-
     /** called by writeXML(), used by children to write state specific to them to
         project files.
     */
@@ -376,7 +398,9 @@ protected:
 
     /**Pixmap used in the legend item*/
     QPixmap m_legendPixmap;
-    //
+
+    /** Pixmap to show a bogus vertex was encoutnered in this layer (applies to vector layers only) */
+   QPixmap mProjectionErrorPixmap;
     //! A little pixmap to show if this layer is represented in overview or now
     QPixmap mInOverviewPixmap;
 
@@ -411,6 +435,10 @@ protected:
     //   QAction* mActionInOverview;
     /** A flag to let the draw() render loop know if the user has requested drawing be cancelled */
     bool mDrawingCancelled;
+
+    //! A QgsCoordinateTransform is used for on the fly reprojection of map layers
+    QgsCoordinateTransform * mCoordinateTransform;    
+
 private:                       // Private attributes
 
     /// QgsMapLayer not copyable
@@ -428,6 +456,7 @@ private:                       // Private attributes
     //! Tag for embedding additional information
     QString tag;
 
+    
     /**  true if visible ? */
     bool m_visible;
 
@@ -436,7 +465,6 @@ private:                       // Private attributes
     */
     void connectNotify( const char * signal );
 
-
     /** Minimum scale at which this layer should be displayed */
     float mMinScale;
     /** Maximum scale at which this layer should be displayed */
