@@ -1,8 +1,8 @@
 /****************************************************************************
 ** QgsMapLayer meta object code from reading C++ file 'qgsmaplayer.h'
 **
-** Created: Fri Dec 17 09:40:20 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:08:55 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,7 +14,7 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -52,50 +52,57 @@ QMetaObject* QgsMapLayer::staticMetaObject()
     if ( metaObj )
 	return metaObj;
     QMetaObject* parentObject = QObject::staticMetaObject();
-    static const QUParameter param_slot_0[] = {
+    static const QUMethod slot_0 = {"invalidTransformInput", 0, 0 };
+    static const QUParameter param_slot_1[] = {
 	{ "e", &static_QUType_ptr, "QKeyEvent", QUParameter::In }
     };
-    static const QUMethod slot_0 = {"keyPressed", 1, param_slot_0 };
-    static const QUParameter param_slot_1[] = {
+    static const QUMethod slot_1 = {"keyPressed", 1, param_slot_1 };
+    static const QUParameter param_slot_2[] = {
 	{ "vis", &static_QUType_bool, 0, QUParameter::In }
     };
-    static const QUMethod slot_1 = {"setVisible", 1, param_slot_1 };
-    static const QUMethod slot_2 = {"updateItemPixmap", 0, 0 };
-    static const QUMethod slot_3 = {"updateOverviewPopupItem", 0, 0 };
-    static const QUParameter param_slot_4[] = {
+    static const QUMethod slot_2 = {"setVisible", 1, param_slot_2 };
+    static const QUMethod slot_3 = {"updateItemPixmap", 0, 0 };
+    static const QUMethod slot_4 = {"updateOverviewPopupItem", 0, 0 };
+    static const QUParameter param_slot_5[] = {
 	{ 0, &static_QUType_bool, 0, QUParameter::In }
     };
-    static const QUMethod slot_4 = {"inOverview", 1, param_slot_4 };
-    static const QUParameter param_slot_5[] = {
+    static const QUMethod slot_5 = {"inOverview", 1, param_slot_5 };
+    static const QUParameter param_slot_6[] = {
 	{ "theMinScale", &static_QUType_ptr, "float", QUParameter::In }
     };
-    static const QUMethod slot_5 = {"setMinScale", 1, param_slot_5 };
-    static const QUMethod slot_6 = {"minScale", 0, 0 };
-    static const QUParameter param_slot_7[] = {
+    static const QUMethod slot_6 = {"setMinScale", 1, param_slot_6 };
+    static const QUMethod slot_7 = {"minScale", 0, 0 };
+    static const QUParameter param_slot_8[] = {
 	{ "theMaxScale", &static_QUType_ptr, "float", QUParameter::In }
     };
-    static const QUMethod slot_7 = {"setMaxScale", 1, param_slot_7 };
-    static const QUMethod slot_8 = {"maxScale", 0, 0 };
-    static const QUParameter param_slot_9[] = {
+    static const QUMethod slot_8 = {"setMaxScale", 1, param_slot_8 };
+    static const QUMethod slot_9 = {"maxScale", 0, 0 };
+    static const QUParameter param_slot_10[] = {
 	{ "theVisibilityFlag", &static_QUType_bool, 0, QUParameter::In }
     };
-    static const QUMethod slot_9 = {"setScaleBasedVisibility", 1, param_slot_9 };
-    static const QUParameter param_slot_10[] = {
+    static const QUMethod slot_10 = {"setScaleBasedVisibility", 1, param_slot_10 };
+    static const QUParameter param_slot_11[] = {
 	{ 0, &static_QUType_bool, 0, QUParameter::Out }
     };
-    static const QUMethod slot_10 = {"scaleBasedVisibility", 1, param_slot_10 };
+    static const QUMethod slot_11 = {"scaleBasedVisibility", 1, param_slot_11 };
+    static const QUParameter param_slot_12[] = {
+	{ 0, &static_QUType_QString, 0, QUParameter::Out }
+    };
+    static const QUMethod slot_12 = {"getProjectionWKT", 1, param_slot_12 };
     static const QMetaData slot_tbl[] = {
-	{ "keyPressed(QKeyEvent*)", &slot_0, QMetaData::Public },
-	{ "setVisible(bool)", &slot_1, QMetaData::Public },
-	{ "updateItemPixmap()", &slot_2, QMetaData::Public },
-	{ "updateOverviewPopupItem()", &slot_3, QMetaData::Public },
-	{ "inOverview(bool)", &slot_4, QMetaData::Public },
-	{ "setMinScale(float)", &slot_5, QMetaData::Public },
-	{ "minScale()", &slot_6, QMetaData::Public },
-	{ "setMaxScale(float)", &slot_7, QMetaData::Public },
-	{ "maxScale()", &slot_8, QMetaData::Public },
-	{ "setScaleBasedVisibility(bool)", &slot_9, QMetaData::Public },
-	{ "scaleBasedVisibility()", &slot_10, QMetaData::Public }
+	{ "invalidTransformInput()", &slot_0, QMetaData::Public },
+	{ "keyPressed(QKeyEvent*)", &slot_1, QMetaData::Public },
+	{ "setVisible(bool)", &slot_2, QMetaData::Public },
+	{ "updateItemPixmap()", &slot_3, QMetaData::Public },
+	{ "updateOverviewPopupItem()", &slot_4, QMetaData::Public },
+	{ "inOverview(bool)", &slot_5, QMetaData::Public },
+	{ "setMinScale(float)", &slot_6, QMetaData::Public },
+	{ "minScale()", &slot_7, QMetaData::Public },
+	{ "setMaxScale(float)", &slot_8, QMetaData::Public },
+	{ "maxScale()", &slot_9, QMetaData::Public },
+	{ "setScaleBasedVisibility(bool)", &slot_10, QMetaData::Public },
+	{ "scaleBasedVisibility()", &slot_11, QMetaData::Public },
+	{ "getProjectionWKT()", &slot_12, QMetaData::Public }
     };
     static const QUMethod signal_0 = {"visibilityChanged", 0, 0 };
     static const QUParameter param_signal_1[] = {
@@ -124,7 +131,7 @@ QMetaObject* QgsMapLayer::staticMetaObject()
     };
     metaObj = QMetaObject::new_metaobject(
 	"QgsMapLayer", parentObject,
-	slot_tbl, 11,
+	slot_tbl, 13,
 	signal_tbl, 6,
 #ifndef QT_NO_PROPERTIES
 	0, 0,
@@ -200,17 +207,19 @@ void QgsMapLayer::recalculateExtents()
 bool QgsMapLayer::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
-    case 0: keyPressed((QKeyEvent*)static_QUType_ptr.get(_o+1)); break;
-    case 1: setVisible((bool)static_QUType_bool.get(_o+1)); break;
-    case 2: updateItemPixmap(); break;
-    case 3: updateOverviewPopupItem(); break;
-    case 4: inOverview((bool)static_QUType_bool.get(_o+1)); break;
-    case 5: setMinScale((float)(*((float*)static_QUType_ptr.get(_o+1)))); break;
-    case 6: minScale(); break;
-    case 7: setMaxScale((float)(*((float*)static_QUType_ptr.get(_o+1)))); break;
-    case 8: maxScale(); break;
-    case 9: setScaleBasedVisibility((bool)static_QUType_bool.get(_o+1)); break;
-    case 10: static_QUType_bool.set(_o,scaleBasedVisibility()); break;
+    case 0: invalidTransformInput(); break;
+    case 1: keyPressed((QKeyEvent*)static_QUType_ptr.get(_o+1)); break;
+    case 2: setVisible((bool)static_QUType_bool.get(_o+1)); break;
+    case 3: updateItemPixmap(); break;
+    case 4: updateOverviewPopupItem(); break;
+    case 5: inOverview((bool)static_QUType_bool.get(_o+1)); break;
+    case 6: setMinScale((float)(*((float*)static_QUType_ptr.get(_o+1)))); break;
+    case 7: minScale(); break;
+    case 8: setMaxScale((float)(*((float*)static_QUType_ptr.get(_o+1)))); break;
+    case 9: maxScale(); break;
+    case 10: setScaleBasedVisibility((bool)static_QUType_bool.get(_o+1)); break;
+    case 11: static_QUType_bool.set(_o,scaleBasedVisibility()); break;
+    case 12: static_QUType_QString.set(_o,getProjectionWKT()); break;
     default:
 	return QObject::qt_invoke( _id, _o );
     }
