@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmarkerdialog.cpp,v 1.11 2004/11/14 08:42:46 telwertowski Exp $ */
+/* $Id: qgsmarkerdialog.cpp,v 1.11.6.1 2005/07/09 23:51:19 timlinux Exp $ */
 
 #include "qgsmarkerdialog.h"
 #include "qgssvgcache.h"
@@ -81,7 +81,7 @@ void QgsMarkerDialog::visualizeMarkers(QString directory)
     
     for(QStringList::Iterator it = files.begin(); it != files.end(); ++it )
     {
-	qWarning(*it);
+	qWarning((*it).local8Bit());
 	
 	//render the SVG file to a pixmap and put it into mIconView
 	QPixmap pix = QgsSVGCache::instance().getPixmap(mCurrentDir + "/" + 
