@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmarkersymbol.h,v 1.12 2004/10/22 19:04:03 mcoletti Exp $ */
+/* $Id: qgsmarkersymbol.h,v 1.13 2004/12/22 21:30:34 mhugent Exp $ */
 
 #ifndef QGSMARKERSYMBOL_H
 #define QGSMARKERSYMBOL_H
@@ -39,6 +39,9 @@ class QgsMarkerSymbol : public QgsSymbol
     const QString& picture() const;
     /**Returns the scale factor*/
     double scaleFactor();
+    /**Writes the contents of the symbol to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & item, QDomDocument & document );
  protected:
     /**Path to the SVG image*/
     QString mSvgPath;
