@@ -14,13 +14,14 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgsnewconnection.cpp,v 1.17 2004/11/23 03:50:33 gsherman Exp $ */
+ /* $Id: qgsnewconnection.cpp,v 1.17.6.2 2005/07/09 23:51:19 timlinux Exp $ */
 #include <iostream>
 #include <qsettings.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qmessagebox.h>
 #include "qgsnewconnection.h"
+#include "qgscontexthelp.h"
 extern "C"
 {
 #include <libpq-fe.h>
@@ -77,7 +78,7 @@ void QgsNewConnection::testConnection()
     " port=" + txtPort->text() +
     " user=" + txtUsername->text() + 
     " password=" + txtPassword->text();
-  PGconn *pd = PQconnectdb((const char *) connInfo);
+  PGconn *pd = PQconnectdb(connInfo.local8Bit());
 //  std::cout << pd->ErrorMessage();
   if (PQstatus(pd) == CONNECTION_OK)
     {
@@ -112,7 +113,10 @@ void QgsNewConnection::saveConnection()
     }
   accept();
 }
-
+void QgsNewConnection::helpInfo()
+{
+  QgsContextHelp::run(context_id);
+}
 /* void QgsNewConnection::saveConnection()
 {
 	QSettings settings;
