@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgsnewconnection.h,v 1.8 2004/06/12 18:27:11 gsherman Exp $ */
+ /* $Id: qgsnewconnection.h,v 1.8.10.1 2005/07/06 06:02:54 gsherman Exp $ */
 #ifndef QGSNEWCONNECTION_H
 #define QGSNEWCONNECTION_H
 #ifdef WIN32
@@ -29,7 +29,7 @@
 class QgsNewConnection : public QgsNewConnectionBase 
 {
   Q_OBJECT
- public:
+  public:
     //! Constructor
     QgsNewConnection(QString connName= QString::null);
     //! Destructor
@@ -38,6 +38,10 @@ class QgsNewConnection : public QgsNewConnectionBase
     void testConnection();
     //! Saves the connection to ~/.qt/qgisrc
     void saveConnection();
+  public slots:
+    void helpInfo();
+  private:
+    static const int context_id = 821572257;
 };
 
 #endif //  QGSNEWCONNECTIONBASE_H
