@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgspoint.cpp,v 1.16 2004/10/21 17:27:37 mcoletti Exp $ */
+ /* $Id: qgspoint.cpp,v 1.17.4.2 2005/05/24 09:04:57 g_j_m Exp $ */
 
 
 #include "qgspoint.h"
@@ -22,6 +22,11 @@
 #include <qtextstream.h>
 
 
+QgsPoint::QgsPoint(const QgsPoint& p)
+{
+  m_x = p.x();
+  m_y = p.y();
+}
 
 QString QgsPoint::stringRep() const
 {
@@ -45,6 +50,10 @@ QString QgsPoint::wellKnownText()
   return QString("POINT(%1 %2)").arg(QString::number(m_x, 'f', 18)).arg(QString::number(m_y, 'f', 18));
 }
 
+double QgsPoint::sqrDist(double x, double y) const
+{
+    return (m_x-x)*(m_x-x)+(m_y-y)*(m_y-y);
+}
 
 // operators
 bool QgsPoint::operator==(const QgsPoint & other)
@@ -73,3 +82,9 @@ QgsPoint & QgsPoint::operator=(const QgsPoint & other)
 
   return *this;
 }
+
+void QgsPoint::multiply(const double& scalar)
+{
+  m_x *= scalar;
+  m_y *= scalar;
+}
