@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgspoint.h,v 1.13 2004/10/26 17:28:02 mcoletti Exp $ */
+/* $Id: qgspoint.h,v 1.15.2.3 2005/07/09 23:51:19 timlinux Exp $ */
 
 #ifndef QGSPOINT_H
 #define QGSPOINT_H
@@ -32,6 +32,9 @@ class QgsPoint
   QgsPoint()
   {}
     
+  /*! Create a point from another point */
+  QgsPoint(const QgsPoint& p);
+
   /*! Create a point from x,y coordinates
    * @param x x coordinate
    * @param y y coordinate
@@ -59,6 +62,12 @@ class QgsPoint
       m_y = y;
   }
     
+  /*! Sets the x and y value of the point */
+  void set(double x, double y)
+  {
+    m_x = x;
+    m_y = y;
+  }  
     
   /*! Get the x value of the point
    * @return x coordinate
@@ -88,14 +97,20 @@ class QgsPoint
    */
   QString wellKnownText();
 
+  /**Returns the squared distance between this point and x,y*/
+  double sqrDist(double x, double y) const;
+
   //! equality operator
   bool operator==(const QgsPoint &other);
     
   //! Inequality operator
   bool operator!=(const QgsPoint &other);
     
-  /// Assignment
+  //! Assignment
   QgsPoint & operator=(const QgsPoint &other);
+
+  //! Multiply x and y by the given value
+  void multiply(const double& scalar);
   
  private:
 
@@ -118,8 +133,9 @@ inline bool operator==(const QgsPoint &p1, const QgsPoint &p2)
 
 inline std::ostream& operator << (std::ostream& os, const QgsPoint &p)
 {
-   os << p.stringRep();
-   return os;
+  // Use Local8Bit for printouts
+  os << p.stringRep().local8Bit();
+  return os;
 }
 
   
