@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrangerenderitem.h,v 1.5 2004/10/16 21:59:14 gsherman Exp $ */
+/* $Id: qgsrangerenderitem.h,v 1.6 2004/12/22 21:30:34 mhugent Exp $ */
 
 #ifndef QGSRANGERENDERITEM_H
 #define QGSRANGERENDERITEM_H
@@ -29,6 +29,9 @@ class QgsRangeRenderItem: public QgsRenderItem
     QgsRangeRenderItem(QgsSymbol* symbol, QString _value, QString u_value, QString _label);
     void setUpperValue(QString value);
     const QString& upper_value() const;
+    /**Writes the contents of the item to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & parent, QDomDocument & document );
  protected:
     /**Upper value for a range (the lower value is QgsRenderItem::value)*/
     QString m_upper_value;
