@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrasterlayer.h,v 1.51 2004/11/15 21:52:57 mhugent Exp $ */
+/* $Id: qgsrasterlayer.h,v 1.61.2.2 2005/10/16 23:35:33 timlinux Exp $ */
 
 /** \file qgsrasterlayer.h
  *  \brief This class provides qgis with the ability to render raster datasets
@@ -168,7 +168,9 @@ The [type] part of the variable should be the type class of the variable written
  
 #include <qvaluevector.h>
 #include <qvaluelist.h> 
+#include <qvaluevector.h> 
 #include <qslider.h>
+#include <qdatetime.h>
 #include "qgspoint.h"
 #include "qgsmaplayer.h"
 #include "qgscolortable.h"
@@ -180,6 +182,7 @@ The [type] part of the variable should be the type class of the variable written
 //
 class QgsRect;
 class QgsRasterLayerProperties;
+class QgsIdentifyResults;
 class GDALDataset;
 class GDALRasterBand;
 class QImage;
@@ -219,8 +222,13 @@ struct RasterBandStats
     /** \brief The number of cells in the band. Equivalent to height x width. 
      * TODO: check if NO_DATA are excluded!*/
     int elementCountInt;    
-    /** \brief A histogram storing the distribution of values within the raster. */
-    int histogram[256];
+    /** \brief Store the histogram for a given layer */
+    typedef QValueVector<int> HistogramVector;
+    HistogramVector * histogramVector;
+    /** \brief whteher histogram values are estimated or completely calculated */
+    bool histogramEstimatedFlag;
+    /** whehter histogram compuation should include out of range values */
+    bool histogramOutOfRangeFlag;
     /** Color table */
     QgsColorTable colorTable;
 };
@@ -235,11 +243,13 @@ typedef QValueVector<RasterBandStats> RasterStatsVector;
  */
 struct RasterViewPort
 {
-    /** \brief  The offset from the left hand edge of the raster for the rectangle that will be drawn to screen.
-     * TODO Check this explanation is correc!*/
+    /** \brief  The offset (in source raster pixel coordinates) from the left hand edge of the source raster for the rectangle that will be drawn to screen. */
+    float rectXOffsetFloat;
+    /** \brief  The offset (in source raster pixel coordinates) from the top edge of the source raster for the rectangle that will be drawn to screen. */
+    float rectYOffsetFloat;
+    /** \brief  The offset (in source raster pixel coordinates) from the left hand edge of the source raster for the rectangle that will be drawn to screen - truncated to an integer. */
     int rectXOffsetInt;
-    /** \brief  The offset from the bottom edge of the raster for the rectangle that will be drawn to screen.
-     * TODO Check this explanation is correc!*/
+    /** \brief  The offset (in source raster pixel coordinates) from the top edge of the source raster for the rectangle that will be drawn to screen - truncated to an integer. */
     int rectYOffsetInt;
     /** \brief Lower left X dimension of clipped raster image in raster pixel space.
      *  RasterIO will do the scaling for us, so for example, if the user is zoomed in a long way, there may only 
@@ -353,6 +363,11 @@ public:
     /** \brief The destuctor.  */
     ~QgsRasterLayer();
 
+    /** \brief Identify raster value(s) found in center of the search rectangle */
+    void identify(QgsRect *);
+
+    /** \brief Query gdal to find out the WKT projection string for this layer. This implements the virtual method of the same name defined in QgsMapLayer*/
+    QString getProjectionWKT();
 
     /** \brief Draws a thumbnail of the rasterlayer into the supplied pixmap pointer */
      void drawThumbnail(QPixmap * theQPixmap);
@@ -361,10 +376,12 @@ public:
      QPixmap getPaletteAsPixmap();
      
     /** \brief This is called when the view on the rasterlayer needs to be refreshed (redrawn).  */
-    void draw(QPainter * theQPainter, QgsRect * theViewExtent, QgsCoordinateTransform * theQgsCoordinateTransform, QPaintDevice* dst);
+    void draw(QPainter * theQPainter, QgsRect * theViewExtent, 
+              QgsMapToPixel * theQgsMapToPixel, QPaintDevice* dst);
 
     /** \brief This is an overloaded version of the above function that is called by both draw above and drawThumbnail */
-    void draw (QPainter * theQPainter, RasterViewPort * myRasterViewPort);
+    void draw(QPainter * theQPainter, RasterViewPort * myRasterViewPort,
+              QgsMapToPixel * theQgsMapToPixel = 0);
     
     //
     // Accessors for image height and width
@@ -746,7 +763,11 @@ public:
     /** \brief Similar to above but returns a pointer. Implemented for qgsmaplayer interface. 
      * Always overlays legend name!*/
     QPixmap * legendPixmap(); 
-
+    
+    /** \brief Use this method when you want an annotated legend suitable for print output etc. 
+     * @param int theLabelCountInt Number of vertical labels to display (defaults to 3)
+     * */
+    QPixmap getDetailedLegendQPixmap(int theLabelCount);
     /** tailor the right-click context menu with raster layer only stuff 
 
       @note called by QgsMapLayer::initContextMenu();
@@ -771,6 +792,8 @@ public:
     /**Currently returns always false*/
     bool isEditable() const;
     
+    /** Return time stamp for given file name */
+    static QDateTime lastModified ( QString name );
     
 public slots:    
 
@@ -797,7 +820,19 @@ public slots:
      * invokes an instance of the QgsRasterLayerProperties dialog box.*/
     /* virtual */ void showLayerProperties();
 
+  /** Populate the histogram vector for a given layer
+  * @param theBandNoInt - which band to compute the histogram for
+  * @param theBinCountInt - how many 'bins' to categorise the data into
+  * @param theIgnoreOutOfRangeFlag - whether to ignore values that are out of range (default=true)
+  * @param theThoroughBandScanFlag - whether to visit each cell when computing the histogram (default=false)
+  */
+  void populateHistogram(int theBandNoInt, int theBinCountInt=256,bool theIgnoreOutOfRangeFlag=true,bool theThoroughBandScanFlag=false);
 
+    /** \brief Color table 
+     *  \param band number
+     *  \return pointer to color table
+     */
+    QgsColorTable *colorTable ( int theBandNoInt );
  protected:
 
     /** reads vector layer specific state from project file DOM node.
@@ -834,10 +869,16 @@ private:
     //
 
     /** \brief Drawing routine for single band grayscale image.  */
-    void drawSingleBandGray(QPainter * theQPainter, RasterViewPort * theRasterViewPort,int theBandNoInt);
+    void drawSingleBandGray(QPainter * theQPainter, 
+                            RasterViewPort * theRasterViewPort,
+                            QgsMapToPixel * theQgsMapToPixel,
+                            int theBandNoInt);
 
     /** \brief Drawing routine for single band grayscale image, rendered in pseudocolor.  */
-    void drawSingleBandPseudoColor(QPainter * theQPainter, RasterViewPort * theRasterViewPort,int theBandNoInt);
+    void drawSingleBandPseudoColor(QPainter * theQPainter, 
+                                   RasterViewPort * theRasterViewPort,
+                                   QgsMapToPixel * theQgsMapToPixel,
+                                   int theBandNoInt);
 
 
     //
@@ -846,25 +887,29 @@ private:
     
     /** \brief Drawing routine for paletted image, rendered as a single band image in color.  */
     void drawPalettedSingleBandColor(QPainter * theQPainter,
-                                RasterViewPort * theRasterViewPort,
-                                int theBandNoInt);
+                                     RasterViewPort * theRasterViewPort,
+                                     QgsMapToPixel * theQgsMapToPixel,
+                                     int theBandNoInt);
     
     /** \brief Drawing routine for paletted image, rendered as a single band image in grayscale.  */
     void drawPalettedSingleBandGray(QPainter * theQPainter,
-                                RasterViewPort * theRasterViewPort,
-                                int theBandNoInt,
-                                QString theColorQString);
+                                    RasterViewPort * theRasterViewPort,
+                                    QgsMapToPixel * theQgsMapToPixel,
+                                    int theBandNoInt,
+                                    QString theColorQString);
 
     /** \brief Drawing routine for paletted image, rendered as a single band image in pseudocolor.  */
     void drawPalettedSingleBandPseudoColor(QPainter * theQPainter,
-                                RasterViewPort * theRasterViewPort,
-                                int theBandNoInt,
-                                QString theColorQString);
+                                           RasterViewPort * theRasterViewPort,
+                                           QgsMapToPixel * theQgsMapToPixel,
+                                           int theBandNoInt,
+                                           QString theColorQString);
 
     /** \brief Drawing routine for paletted multiband image.  */
     void drawPalettedMultiBandColor(QPainter * theQPainter,
-                                RasterViewPort * theRasterViewPort,
-                                int theBandNoInt);
+                                    RasterViewPort * theRasterViewPort,
+                                    QgsMapToPixel * theQgsMapToPixel,                                
+                                    int theBandNoInt);
 
     //
     // Multiband Layers
@@ -872,17 +917,21 @@ private:
     
     /** \brief Drawing routine for multiband image, rendered as a single band image in grayscale.  */
     void drawMultiBandSingleBandGray(QPainter * theQPainter,
-                                RasterViewPort * theRasterViewPort, 
-                                int theBandNoInt);
+                                     RasterViewPort * theRasterViewPort, 
+                                     QgsMapToPixel * theQgsMapToPixel,
+                                     int theBandNoInt);
 
     /** \brief Drawing routine for multiband image, rendered as a single band image in pseudocolor.  */
     void drawMultiBandSingleBandPseudoColor(QPainter * theQPainter, 
-                                RasterViewPort * theRasterViewPort, 
-                                int theBandNoInt);
+                                            RasterViewPort * theRasterViewPort, 
+                                            QgsMapToPixel * theQgsMapToPixel,
+                                            int theBandNoInt);
 
     /** \brief Drawing routine for multiband image  */
-    void drawMultiBandColor(QPainter * theQPainter, RasterViewPort * theRasterViewPort);
-
+    void drawMultiBandColor(QPainter * theQPainter, 
+                            RasterViewPort * theRasterViewPort,
+                            QgsMapToPixel * theQgsMapToPixel);
+                                            
     /** \brief Read color table from GDAL raster band */
     void readColorTable ( GDALRasterBand *gdalBand, QgsColorTable *theColorTable );
 
@@ -897,11 +946,6 @@ private:
      */
     inline double readValue ( void *data, GDALDataType type, int index );
 
-    /** \brief Color table 
-     *  \param band number
-     *  \return pointer to color table
-     */
-    QgsColorTable *colorTable ( int theBandNoInt );
 
     /**
        Load the given raster file
@@ -913,6 +957,12 @@ private:
        Called from ctor if a raster image given there
      */
     bool readFile( QString const & fileName );
+    
+    /** \brief Close data set and release related data */
+    void closeDataset ();
+
+    /** \brief Update the layer if it is outdated */
+    bool update ();
 
     //
     // Private member vars
@@ -973,11 +1023,6 @@ private:
     RasterPyramidList mPyramidList;
     //Transparency slider for popup menu
     QSlider * mTransparencySlider; 
-    //we need to do the tr() stuff outside of the main drawing loops becauses tr() is a 
-    //time consuming operation nd we dont want to do it in the loop!
-    QString redTranslatedQString;
-    QString greenTranslatedQString;
-    QString blueTranslatedQString;
 
     /* raster properties dialog 
 
@@ -985,6 +1030,11 @@ private:
     */
     QgsRasterLayerProperties * mLayerProperties;
     
+    //! Pointer to the identify results dialog
+    QgsIdentifyResults *mIdentifyResults;
+
+    //! Timestamp, the last modified time of the data source when the layer was created
+    QDateTime mLastModified;
 };
 
 #endif
