@@ -16,7 +16,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrasterlayerproperties.h,v 1.11 2004/10/21 17:27:38 mcoletti Exp $ */
+/* $Id: qgsrasterlayerproperties.h,v 1.14.2.2 2005/07/31 05:03:14 telwertowski Exp $ */
 #ifndef QGSRASTERLAYERPROPERTIES_H
 #define QGSRASTERLAYERPROPERTIES_H
 #ifdef WIN32
@@ -39,7 +39,7 @@ class QgsRasterLayerProperties : public QgsRasterLayerPropertiesBase
         /** \brief Constructor
          * @param ml Map layer for which properties will be displayed
          */
-        QgsRasterLayerProperties(QgsMapLayer *lyr);
+        QgsRasterLayerProperties(QgsMapLayer *lyr, QWidget *parent=0, const char *name=0, bool modal=true);
         /** \brief Destructor */
         ~QgsRasterLayerProperties();
         /** \brief Applies the settings made in the dialog without closing the box */
@@ -68,6 +68,10 @@ class QgsRasterLayerProperties : public QgsRasterLayerPropertiesBase
         void rbtnSingleBand_toggled( bool );
         /** \brief slot executed when the three band radio button is pressed. */
         void rbtnThreeBand_toggled( bool );
+        /** \brief slot executed when user wishes to refresh raster histogram */
+        void QgsRasterLayerProperties::pbnHistRefresh_clicked();
+        /** Override the SRS specified when the layer was loaded */
+        void pbnChangeSpatialRefSys_clicked();
 
         /** synchronize state with associated raster layer */
         void sync();
