@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrect.h,v 1.22 2004/11/11 06:02:25 gsherman Exp $ */
+/* $Id: qgsrect.h,v 1.27.2.3 2005/07/09 23:51:20 timlinux Exp $ */
 
 #ifndef QGSRECT_H
 #define QGSRECT_H
@@ -45,6 +45,12 @@ class QgsRect
     QgsRect(const QgsRect &other);
     //! Destructor
     ~QgsRect();
+    //! Set the rectangle from two QgsPoints. The rectangle is
+    //normalised after construction. 
+    void set(const QgsPoint& p1, const QgsPoint& p2);
+    //! Set the rectangle from four points. The rectangle is
+    //  normalised after construction. 
+    void set(double xmin, double ymin, double xmax, double ymax);
     //! Set the minimum x value
     void setXmin(double x);
     //! Set the maximum x value
@@ -53,6 +59,9 @@ class QgsRect
     void setYmin(double y);
     //! Set the maximum y value
     void setYmax(double y);
+    //! Set a rectangle so that min corner is at max
+    // and max corner is at min. It is NOT normalized.
+    void setMinimal();
     //! Get the x maximum value (right side of rectangle)
     double xMax() const;
     //! Get the x maximum value (right side of rectangle)
@@ -75,10 +84,16 @@ class QgsRect
     void expand(double, QgsPoint *c = 0);
     //! return the intersection with the given rectangle
     QgsRect intersect(QgsRect *rect);
+    //! expand the rectangle so that covers both the original rectangle and the given rectangle
+    void combineExtentWith(QgsRect *rect);
+    //! expand the rectangle so that covers both the original rectangle and the given point
+    void combineExtentWith(double x, double y);
     //! test if rectangle is empty
     bool isEmpty();
+    //! returns string representation in WKT form
+    QString asWKTCoords() const;
     //! returns string representation of form xmin,ymin xmax,ymax
-    QString stringRep() const;
+    QString stringRep(bool automaticPrecision = false) const;
     //! overloaded stringRep that allows precision of numbers to be set
     QString stringRep(int thePrecision) const;
     //! returns rectangle s a polygon 
@@ -91,17 +106,19 @@ class QgsRect
      * @param r1 QgsRect to assign from
      */
     QgsRect & operator=(const QgsRect &r1);
- private:
+ 
+protected:
+
+    // These are protected instead of private so that things like
+    // the QgsPostGisBox3d can get at them.
     
     double xmin;
     double ymin;
     double xmax;
     double ymax;
+   
 };
 
-inline QgsRect::QgsRect(double minX, double minY, double maxX, double maxY):xmin(minX), ymin(minY), xmax(maxX), ymax(maxY)
-{
-}
 
 inline QgsRect::~QgsRect()
 {
@@ -163,7 +180,7 @@ inline QgsPoint QgsRect::center() const
 }
 inline std::ostream& operator << (std::ostream& os, const QgsRect &r)
 {
-    return os << r.stringRep();
+  return os << r.stringRep().local8Bit();
 }
   
 #endif // QGSRECT_H
