@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrenderitem.cpp,v 1.13 2004/11/15 05:27:11 gsherman Exp $ */
+/* $Id: qgsrenderitem.cpp,v 1.14 2004/12/22 21:30:34 mhugent Exp $ */
 #include <qstring.h>
 #include <cassert>
 #include "qgsrenderitem.h"
@@ -58,9 +58,29 @@ void QgsRenderItem::setValue(QString value)
 {
     mValue=value;
 }
+
 QgsSymbol* QgsRenderItem::getSymbol()
 {
   assert(this != 0);
     return mSymbol;
 }
 
+bool QgsRenderItem::writeXML( QDomNode & parent, QDomDocument & document )
+{
+    bool returnval=false;
+    QDomElement renderitem=document.createElement("renderitem");
+    parent.appendChild(renderitem);
+    QDomElement value=document.createElement("value");
+    QDomText valuetxt=document.createTextNode(mValue);
+    value.appendChild(valuetxt);
+    renderitem.appendChild(value);
+    if(mSymbol)
+    {
+	returnval=mSymbol->writeXML(renderitem,document);
+    }
+    QDomElement label=document.createElement("label");
+    QDomText labeltxt=document.createTextNode(mLabel);
+    label.appendChild(labeltxt);
+    renderitem.appendChild(label);
+    return returnval;
+}
