@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrenderitem.h,v 1.10 2004/11/12 00:33:41 gsherman Exp $ */
+/* $Id: qgsrenderitem.h,v 1.11 2004/12/22 21:30:34 mhugent Exp $ */
 #ifndef QGSRENDERITEM_H
 #define QGSRENDERITEM_H
 #include <map>
@@ -63,7 +63,9 @@ class QgsRenderItem {
     const QString& label() const;
     /**Returns the value of the field*/
     const QString& value() const; 
-
+    /**Writes the contents of the item to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & parent, QDomDocument & document );
 };
 
 
