@@ -15,11 +15,13 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsscalecalculator.h,v 1.2 2004/10/26 17:28:03 mcoletti Exp $ */
+/* $Id: qgsscalecalculator.h,v 1.4 2005/05/12 03:21:56 g_j_m Exp $ */
 
 #ifndef QGSSCALECALCULATOR_H
 #define QGSSCALECALCULATOR_H
 
+#include <qgis.h>
+
 class QString;
 class QgsRect;
 
@@ -32,25 +34,14 @@ class QgsScaleCalculator
 {
   public:
 
-    /**
-     * Enum for defining map units
-     */
-    typedef enum
-    {
-        METERS,
-        FEET,
-        DEGREES
-    } units;
-
-
     /**
      * Constructor
      * @param dpi Monitor resolution in dots per inch
      * @param mapUnits Units of the data on the map. Must match a value from the
-     * QgsScaleCalculator::units enum (METERS, FEET, DEGREES)
+     * QGis::units enum (METERS, FEET, DEGREES)
      */
     QgsScaleCalculator(int dpi = 0, 
-                       units mapUnits = METERS);
+                       QGis::units mapUnits = QGis::METERS);
 
     //! Destructor
     ~QgsScaleCalculator();
@@ -65,7 +56,7 @@ class QgsScaleCalculator
      * Set the map units
      * @param mapUnits Units of the data on the map. Must match a value from the
      */
-    void setMapUnits(QgsScaleCalculator::units mapUnits);
+    void setMapUnits(QGis::units mapUnits);
 
     /**
      * Calculate the scale
@@ -89,7 +80,7 @@ class QgsScaleCalculator
     int mDpi;
 
     //! map unit member
-    units mMapUnits;
+    QGis::units mMapUnits;
 };
 
 #endif // #ifndef QGSSCALECALCULATOR_H
