@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgssimadialog.cpp,v 1.29 2004/11/14 08:42:46 telwertowski Exp $ */
+/* $Id: qgssimadialog.cpp,v 1.30.2.1 2005/07/09 23:51:20 timlinux Exp $ */
 
 #include "qgssimadialog.h"
 #include "qgssimarenderer.h"
@@ -82,7 +82,7 @@ QgsSiMaDialog::QgsSiMaDialog(QgsVectorLayer* vectorlayer): QgsSiMaDialogBase(),
 #endif
         mCurrentDir=QString(PKGDATAPATH)+"/svg/";
 #ifdef QGISDEBUG
-  qWarning("mCurrentDir in constructor: "+mCurrentDir);
+  qWarning(("mCurrentDir in constructor: "+mCurrentDir).local8Bit());
 #endif
         visualizeMarkers(mCurrentDir);
         mDirectoryEdit->setText(mCurrentDir);
@@ -106,7 +106,7 @@ void QgsSiMaDialog::apply()
     QgsMarkerSymbol* ms= new QgsMarkerSymbol();
     QString string(mSelectedMarker);
 #ifdef QGISDEBUG
-    qWarning(string);
+    qWarning(string.local8Bit());
 #endif
 
     ms->setPicture(string);
@@ -199,7 +199,7 @@ void QgsSiMaDialog::setMarker(const QString& file, double scaleFactor) {
       mIconView->setSelected(item, true);
       
       // set the scale factor
-      mScaleSpin->setValue(scaleFactor * 100.0);
+      mScaleSpin->setValue((int)scaleFactor * 100.0);
     }
   }
   emit settingsChanged();
@@ -215,7 +215,11 @@ double QgsSiMaDialog::getScaleFactor() const {
 
 void QgsSiMaDialog::mIconView_selectionChanged(QIconViewItem * theIconViewItem)
 {
+#ifdef Q_OS_MACX
+    mSelectedMarker=mCurrentDir+"/"+theIconViewItem->text();
+#else
     mSelectedMarker=mCurrentDir+theIconViewItem->text();
+#endif
 
     //draw the SVG-Image on the button
     double scalefactor=mScaleSpin->value()/100.0;
@@ -263,7 +267,7 @@ void QgsSiMaDialog::visualizeMarkers(QString directory)
     for(QStringList::Iterator it = files.begin(); it != files.end(); ++it )
     {
 #ifdef QGISDEBUG
-        qWarning(*it);
+        qWarning((*it).local8Bit());
 #endif
 	QPixmap pix = QgsSVGCache::instance().getPixmap(mCurrentDir + 
 							"/" + (*it), 1);
