@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgssimarenderer.cpp,v 1.20 2004/11/27 12:41:02 mhugent Exp $ */
+ /* $Id: qgssimarenderer.cpp,v 1.23.2.1 2005/07/09 23:51:20 timlinux Exp $ */
 
 #include "qgssimarenderer.h"
 #include "qgssimadialog.h"
@@ -61,7 +61,8 @@ void QgsSiMaRenderer::initializeSymbology(QgsVectorLayer* layer, QgsDlgVectorLay
     }
 }
 
-void QgsSiMaRenderer::renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected)
+void QgsSiMaRenderer::renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, 
+	    double* scalefactor, bool selected, int oversampling, double widthScale)
 {
     p->setPen(Qt::NoPen);
     p->setBrush(Qt::NoBrush);
@@ -142,11 +143,11 @@ void QgsSiMaRenderer::readXML(const QDomNode& rnode, QgsVectorLayer& vl)
     msy->setPen(pen);
     msy->setPicture(svgpath);
 #ifdef QGISDEBUG
-    qWarning("the svgpath: "+svgpath);
+    qWarning(("the svgpath: "+svgpath).local8Bit());
 #endif
     msy->setScaleFactor(scalefactor);
 #ifdef QGISDEBUG
-    qWarning("the scalefactor: "+QString::number(scalefactor,'f',2));
+    qWarning(("the scalefactor: "+QString::number(scalefactor,'f',2)).local8Bit());
 #endif
     QgsRenderItem* ri = new QgsRenderItem();
     ri->setSymbol(msy);
@@ -170,17 +171,18 @@ void QgsSiMaRenderer::writeXML(std::ostream& xml)
 #ifdef QGISDEBUG
     qWarning("in QgsSiMaRenderer::writeXML");
     qWarning("label seems to make problems");
-    qWarning(this->item()->label());
+    qWarning((this->item()->label()).local8Bit());
 #endif
+    // Always use utf8 for XML?
     xml << "\t\t<singlemarker>\n";
     xml << "\t\t\t<renderitem>\n";
-    xml << "\t\t\t\t<value>" + this->item()->value() + "</value>\n";
+    xml << "\t\t\t\t<value>" + this->item()->value().utf8() + "</value>\n";
 
     QgsMarkerSymbol *markersymbol = dynamic_cast<QgsMarkerSymbol*>(this->item()->getSymbol());
     if(markersymbol)
     {
 	xml << "\t\t\t\t<markersymbol>\n";
-	xml << "\t\t\t\t\t<svgpath>" << (const char *) markersymbol->picture() << "</svgpath>\n";
+	xml << "\t\t\t\t\t<svgpath>" << (const char *) markersymbol->picture().utf8() << "</svgpath>\n";
 	xml << "\t\t\t\t\t<scalefactor>"  << markersymbol->scaleFactor() << "</scalefactor>\n";
 	xml << "\t\t\t\t\t<outlinecolor red=\"" 
     << markersymbol->pen().color().red() 
@@ -189,7 +191,7 @@ void QgsSiMaRenderer::writeXML(std::ostream& xml)
     << "\" blue=\"" 
     << markersymbol->pen().color().blue()
     << "\" />\n";
-	xml << "\t\t\t\t\t<outlinestyle>" << (const char *) QgsSymbologyUtils::penStyle2QString(markersymbol->pen().style()) << "</outlinestyle>\n";
+	xml << "\t\t\t\t\t<outlinestyle>" << (const char *) QgsSymbologyUtils::penStyle2QString(markersymbol->pen().style()).utf8() << "</outlinestyle>\n";
 	xml << "\t\t\t\t\t<outlinewidth>" <<  markersymbol->pen().width() << "</outlinewidth>\n";
 	xml << "\t\t\t\t\t<fillcolor red=\"" << markersymbol->brush().color().red() 
     << "\" green=\"" 
@@ -198,10 +200,10 @@ void QgsSiMaRenderer::writeXML(std::ostream& xml)
     << markersymbol->brush().color().blue()
     << "\" />\n";
 	xml << "\t\t\t\t\t<fillpattern>" 
-    << (const char *)QgsSymbologyUtils::brushStyle2QString(markersymbol->brush().style())
+    << (const char *)QgsSymbologyUtils::brushStyle2QString(markersymbol->brush().style()).utf8()
 	  << "</fillpattern>\n";
 	  xml << "\t\t\t\t</markersymbol>\n";
-	  xml << "\t\t\t\t<label>" + this->item()->label() + "</label>\n";
+	  xml << "\t\t\t\t<label>" + this->item()->label().utf8() + "</label>\n";
 	xml << "\t\t\t</renderitem>\n";
 	xml << "\t\t</singlemarker>\n";
     }else
@@ -220,3 +222,22 @@ QString QgsSiMaRenderer::name()
 {
     return "Single Marker";
 }
+
+bool QgsSiMaRenderer::writeXML( QDomNode & layer_node, QDomDocument & document )
+{
+    bool returnvalue=false;
+    QDomNode singlemarker=document.createElement("singlemarker");
+    layer_node.appendChild(singlemarker);
+    if(mItem)
+    {
+	returnvalue=mItem->writeXML(singlemarker,document);
+    }
+    return returnvalue;
+}
+
+const std::list<QgsRenderItem*> QgsSiMaRenderer::items() const
+{
+    std::list<QgsRenderItem*> list;
+    list.push_back(mItem);
+    return list;
+}
