@@ -15,7 +15,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- /* $Id: qgssimarenderer.h,v 1.15 2004/10/26 17:28:03 mcoletti Exp $ */
+ /* $Id: qgssimarenderer.h,v 1.19 2005/04/02 09:42:53 rabla Exp $ */
 
 #ifndef QGSSIMARENDERER_H
 #define QGSSIMARENDERER_H
@@ -32,26 +32,34 @@ class QgsSiMaRenderer: public QgsRenderer
     /**Replaces the current mItem by ri*/
     void addItem(QgsRenderItem* ri);
     void initializeSymbology(QgsVectorLayer* layer, QgsDlgVectorLayerProperties* pr=0);
-    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected);
+    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected, int oversampling = 1, double widthScale = 1.);
     /**Reads the renderer configuration from an XML file
      @param rnode the DOM node to read 
      @param vl the vector layer which will be associated with the renderer*/
     virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
     /**Writes the contents of the renderer to a configuration file*/
     virtual void writeXML(std::ostream& xml);
+    /**Writes the contents of the renderer to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & layer_node, QDomDocument & document );
     bool needsAttributes();
     /**Returns an empty list, since no classification attributes are used*/
     virtual std::list<int> classificationAttributes();
     QgsRenderItem* item();
     /**Returns the renderers name*/
     QString name();
+    /**Return symbology items*/
+    const std::list<QgsRenderItem*> items() const;
  protected:
     QgsRenderItem* mItem;
 };
 
 inline QgsSiMaRenderer::QgsSiMaRenderer()
 {
-    mItem=new QgsRenderItem(new QgsMarkerSymbol(),"","");
+  //call superclass method to set up selection colour
+  initialiseSelectionColor();
+
+  mItem=new QgsRenderItem(new QgsMarkerSymbol(),"","");
 }
 
 inline QgsSiMaRenderer::~QgsSiMaRenderer()
