@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgssinglesymrenderer.h,v 1.17 2004/10/26 17:28:03 mcoletti Exp $ */
+/* $Id: qgssinglesymrenderer.h,v 1.23 2005/04/02 09:42:53 rabla Exp $ */
 
 #ifndef QGSSINGLESYMRENDERER_H
 #define QGSSINGLESYMRENDERER_H
@@ -23,7 +23,7 @@
 #include "qgsrenderitem.h"
 #include "qgspoint.h"
 #include "qpainter.h"
-#include "qgscoordinatetransform.h"
+#include "qgsmaptopixel.h"
 #include "qgsdlgvectorlayerproperties.h"
 class QgsFeature;
 
@@ -38,7 +38,7 @@ class QgsSingleSymRenderer: public QgsRenderer
     /**Returns a pointer to mItem*/
     QgsRenderItem* item();
     /**Renders an OGRFeature*/
-    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected);
+    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected, int oversampling = 1, double widthScale = 1.);
     /**Sets the initial symbology configuration for a layer. Besides of applying default symbology settings, an instance of the corresponding renderer dialog is created and associated with the layer (or with the property dialog, if pr is not 0). Finally, a pixmap for the legend is drawn (or, if pr is not 0, it is stored in the property dialog, until the settings are applied).
        @param layer the vector layer associated with the renderer
        @param pr the property dialog. This is only needed if the renderer is created from the property dialog and not yet associated with the vector layer, otherwise 0*/
@@ -48,17 +48,20 @@ class QgsSingleSymRenderer: public QgsRenderer
      @param vl the vector layer which will be associated with the renderer*/
     virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
     /**Writes the contents of the renderer to a configuration file*/
-    virtual void writeXML(std::ostream& xml);
+    /*virtual void writeXML(std::ostream& xml);*/
+    /**Writes the contents of the renderer to a configuration file
+     @ return true in case of success*/
+    virtual bool writeXML( QDomNode & layer_node, QDomDocument & document );
     /**Returns false, no attributes neede for single symbol*/
     bool needsAttributes();
     /**Returns an empty list, since no classification attributes are used*/
     virtual std::list<int> classificationAttributes();
     /**Returns the renderers name*/
     virtual QString name();
+    /**Return symbology items*/
+    const std::list<QgsRenderItem*> items() const;
  protected:
     QgsRenderItem* mItem;
-    /**Color to draw selected features*/
-    QColor mSelectionColor;
 };
 
 inline QgsRenderItem* QgsSingleSymRenderer::item()
