@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgssisydialog.cpp,v 1.40.2.2 2004/12/06 23:20:44 mhugent Exp $ */
+/* $Id: qgssisydialog.cpp,v 1.45.2.1 2005/07/09 23:51:20 timlinux Exp $ */
 #include <iostream>
 #include <qgssisydialog.h>
 #include <qpushbutton.h>
@@ -27,6 +27,7 @@
 #include <qbuttongroup.h>
 #include <qbrush.h>
 #include <qpen.h>
+#include <qcombobox.h>
 
 #include "qgsvectorlayer.h"
 #include "qgslegenditem.h"
@@ -35,6 +36,9 @@
 #include "qgspatterndialog.h"
 #include "qgssymbologyutils.h"
 #include "qgslinestyledialog.h"
+#include "qgsmarkercatalogue.h"
+#include "qgssymbol.h"
+#include "qgssvgcache.h"
 
 QgsSiSyDialog::QgsSiSyDialog():QgsSiSyDialogBase(), mVectorLayer(0)
 {
@@ -49,6 +53,58 @@ QgsSiSyDialog::QgsSiSyDialog(QgsVectorLayer * layer):QgsSiSyDialogBase(), mVecto
     qWarning("constructor QgsSiSyDialog called WITH a layer");
 #endif
 
+    //
+    //set point symbol combo box
+    //
+
+    // If this layer doesn't have points, break out of the following
+    // two loops after the first iteration. This gives one point
+    // symbol in the dialog, etc so that other code can rely on such a
+    // fact, but avoids the long time required to load all of the
+    // available symbols when they are not needed.
+
+    QStringList ml = QgsMarkerCatalogue::instance()->list();
+    mMarkers.clear();
+
+    int size = 29;
+    int maxwidth = 0;
+    QPen pen (QColor(0,0,255));
+    QBrush brush ( QColor(220,220,220), Qt::SolidPattern );
+
+    // Get maximum symbol width - this is probably slow
+    for ( QStringList::iterator it = ml.begin(); it != ml.end(); ++it ) {
+    
+      QPicture pic = QgsMarkerCatalogue::instance()->marker ( *it, size,
+      	                pen, brush, QgsSVGCache::instance().getOversampling() );
+
+      QRect br = pic.boundingRect();
+
+      if ( br.width() > maxwidth ) maxwidth = br.width();
+
+      if (layer->vectorType() != QGis::Point)
+	break;
+    }
+    
+    for ( QStringList::iterator it = ml.begin(); it != ml.end(); ++it ) {
+      mMarkers.push_back ( *it );
+
+      QPicture pic = QgsMarkerCatalogue::instance()->marker ( *it, size,
+		      pen, brush, QgsSVGCache::instance().getOversampling() );
+
+      QRect br = pic.boundingRect();
+
+      QPixmap pm( 10+maxwidth, 10+br.height() );
+      pm.fill(QColor(255,255,255));
+      QPainter p;
+      p.begin(&pm);
+      p.drawPicture ( 5-br.x()+(maxwidth-br.width())/2 , 5-br.y(), pic);
+      p.end();
+      mPointSymbolComboBox->insertItem ( pm );
+
+      if (layer->vectorType() != QGis::Point)
+	break;
+    }
+
     //
     //set outline / line style
     //
@@ -101,94 +157,10 @@ QgsSiSyDialog::QgsSiSyDialog(QgsVectorLayer * layer):QgsSiSyDialogBase(), mVecto
             // get the renderer item first
             QgsRenderItem *ri = renderer->item();
             //if(ri)
-            outlinewidthspinbox->setValue(renderer->item()->getSymbol()->pen().width());
-            outlinewidthspinbox->setMinValue(1);//set line width 1 as minimum to avoid confusion between line width 0 and no pen line style
-            lblFillColor->setPaletteBackgroundColor(renderer->item()->getSymbol()->brush().color());
 
-
-            lblOutlineColor->setPaletteBackgroundColor(renderer->item()->getSymbol()->pen().color());
-
-            //stylebutton->setName(QgsSymbologyUtils::penStyle2Char(renderer->item()->getSymbol()->pen().style()));
-            //stylebutton->setPixmap(QgsSymbologyUtils::char2LinePixmap(stylebutton->name()));
-            //load the icons stored in QgsSymbologyUtils.cpp (to avoid redundancy)
-
-            QPen myPen = renderer->item()->getSymbol()->pen();
-
-            switch ( myPen.style() )
-            {
-                case Qt::NoPen :
-                    pbnLineNoPen->setOn(true);
-                    break;
-                case Qt::DashLine :
-                    pbnLineDash->setOn(true);
-                    break;
-                case Qt::DotLine :
-                    pbnLineDot->setOn(true);
-                    break;
-                case Qt::DashDotLine :
-                    pbnLineDashDot->setOn(true);
-                    break;
-                case Qt::DashDotDotLine :
-                    pbnLineDashDotDot->setOn(true);
-                    break;
-                default :
-                    pbnLineSolid->setOn(true); // default to solid
-                    break;
-            }
-
-            QBrush myBrush = renderer->item()->getSymbol()->brush();
-
-            switch ( myBrush.style() )
-            {
-                case Qt::SolidPattern :
-                    solid->setOn(true);
-                    break;
-                case Qt::HorPattern :
-                    horizontal->setOn(true);
-                    break;
-                case Qt::VerPattern :
-                    vertical->setOn(true);
-                    break;
-                case  Qt::CrossPattern :
-                    cross->setOn(true);
-                    break;
-                case Qt::BDiagPattern :
-                    bdiag->setOn(true);
-                    break;
-                case Qt::FDiagPattern :
-                    fdiag->setOn(true);
-                    break;
-                case Qt::DiagCrossPattern :
-                    diagcross->setOn(true);
-                    break;
-                case Qt::Dense1Pattern :
-                    dense1->setOn(true);
-                    break;
-                case Qt::Dense2Pattern :
-                    dense2->setOn(true);
-                    break;
-                case Qt::Dense3Pattern :
-                    dense3->setOn(true);
-                    break;
-                case Qt::Dense4Pattern :
-                    dense4->setOn(true);
-                    break;
-                case Qt::Dense5Pattern :
-                    dense5->setOn(true);
-                    break;
-                case Qt::Dense6Pattern :
-                    dense6->setOn(true);
-                    break;
-                case Qt::Dense7Pattern :
-                    dense7->setOn(true);
-                    break;
-                case Qt::NoBrush :
-                    nopen->setOn(true);
-                    break;
-                default :
-                    solid->setOn(true);
-                    break;
-            }
+	    // Set 
+	    set ( renderer->item()->getSymbol() );
+	    
         }
         else
         {
@@ -200,6 +172,12 @@ QgsSiSyDialog::QgsSiSyDialog(QgsVectorLayer * layer):QgsSiSyDialogBase(), mVecto
             lblFillColor->unsetPalette();
             btnFillColor->setEnabled(false);
             grpPattern->setEnabled(false);
+            mGroupPoint->setEnabled(false);
+        }
+	
+        if (mVectorLayer && mVectorLayer->vectorType() == QGis::Polygon) {
+            mGroupPoint->setEnabled(false);
+
         }
         //do the signal/slot connections
         QObject::connect(btnOutlineColor, SIGNAL(clicked()), this, SLOT(selectOutlineColor()));
@@ -207,6 +185,8 @@ QgsSiSyDialog::QgsSiSyDialog(QgsVectorLayer * layer):QgsSiSyDialogBase(), mVecto
         QObject::connect(btnFillColor, SIGNAL(clicked()), this, SLOT(selectFillColor()));
         QObject::connect(outlinewidthspinbox, SIGNAL(valueChanged(int)), this, SLOT(resendSettingsChanged()));
         QObject::connect(mLabelEdit, SIGNAL(textChanged(const QString&)), this, SLOT(resendSettingsChanged()));
+        QObject::connect(mPointSymbolComboBox, SIGNAL(activated(int)), this, SLOT(resendSettingsChanged()));
+        QObject::connect(mPointSizeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(resendSettingsChanged()));
 
 	//connect fill style and line style buttons
 	QObject::connect(pbnLineSolid, SIGNAL(clicked()), this, SLOT(resendSettingsChanged()));
@@ -246,44 +226,56 @@ QgsSiSyDialog::~QgsSiSyDialog()
 
 void QgsSiSyDialog::selectOutlineColor()
 {
-    lblOutlineColor->setPaletteBackgroundColor(QColorDialog::getColor(QColor(black),this));
+    QColor c = QColorDialog::getColor(lblOutlineColor->paletteBackgroundColor(),this);
+    
+    if ( c.isValid() ) {
+        lblOutlineColor->setPaletteBackgroundColor(c);
+        emit settingsChanged();
+    }
+    
     setActiveWindow();
-    emit settingsChanged();
 }
 
 void QgsSiSyDialog::selectFillColor()
 {
-    lblFillColor->setPaletteBackgroundColor(QColorDialog::getColor(QColor(black),this));
+    QColor c = QColorDialog::getColor(lblFillColor->paletteBackgroundColor(),this);
+
+    if ( c.isValid() ) {
+        lblFillColor->setPaletteBackgroundColor(c);
+        emit settingsChanged();
+    }
+
     setActiveWindow();
-    emit settingsChanged();
 }
 
-
-
-void QgsSiSyDialog::apply()
+void QgsSiSyDialog::apply( QgsSymbol *sy )
 {
     //query the values of the widgets and set the symbology of the vector layer
-    QgsSymbol* sy = new QgsSymbol();
     sy->brush().setColor(lblFillColor->paletteBackgroundColor());
     sy->pen().setWidth(outlinewidthspinbox->value());
     sy->pen().setColor(lblOutlineColor->paletteBackgroundColor());
 
-
+    //
+    // Apply point symbol
+    // 
+    sy->setNamedPointSymbol( mMarkers[mPointSymbolComboBox->currentItem()] ) ;
+    sy->setPointSize ( mPointSizeSpinBox->value() );
+    
     //
     // Apply the line style
     //
     if  (pbnLineNoPen->isOn())
-        (sy->pen().setStyle(Qt::NoPen));
+        (sy->setLineStyle(Qt::NoPen));
     else if  (pbnLineDash->isOn())
-        (sy->pen().setStyle(Qt::DashLine));
+        (sy->setLineStyle(Qt::DashLine));
     else if  (pbnLineDot->isOn())
-        (sy->pen().setStyle(Qt::DotLine)) ;
+        (sy->setLineStyle(Qt::DotLine)) ;
     else if  (pbnLineDashDot->isOn())
-        (sy->pen().setStyle(Qt::DashDotLine));
+        (sy->setLineStyle(Qt::DashDotLine));
     else if  (pbnLineDashDotDot->isOn())
-        (sy->pen().setStyle(Qt::DashDotDotLine)) ;
+        (sy->setLineStyle(Qt::DashDotDotLine)) ;
     else
-        (sy->pen().setStyle(Qt::SolidLine)); //default to solid
+        (sy->setLineStyle(Qt::SolidLine)); //default to solid
 
 
     //
@@ -292,65 +284,70 @@ void QgsSiSyDialog::apply()
 
     if (solid->isOn())
     {
-        sy->brush().setStyle(Qt::SolidPattern);
+        sy->setFillStyle(Qt::SolidPattern);
     }
     else if (fdiag->isOn())
     {
-        sy->brush().setStyle(Qt::FDiagPattern);
+        sy->setFillStyle(Qt::FDiagPattern);
     }
     else if (dense4->isOn())
     {
-        sy->brush().setStyle(Qt::Dense4Pattern);
+        sy->setFillStyle(Qt::Dense4Pattern);
     }
     else if (horizontal->isOn())
     {
-        sy->brush().setStyle(Qt::HorPattern);
+        sy->setFillStyle(Qt::HorPattern);
     }
     else if (dense5->isOn())
     {
-        sy->brush().setStyle(Qt::Dense5Pattern);
+        sy->setFillStyle(Qt::Dense5Pattern);
     }
     else if (diagcross->isOn())
     {
-        sy->brush().setStyle(Qt::DiagCrossPattern);
+        sy->setFillStyle(Qt::DiagCrossPattern);
     }
     else if (dense1->isOn())
     {
-        sy->brush().setStyle(Qt::Dense1Pattern);
+        sy->setFillStyle(Qt::Dense1Pattern);
     }
     else if (dense6->isOn())
     {
-        sy->brush().setStyle(Qt::Dense6Pattern);
+        sy->setFillStyle(Qt::Dense6Pattern);
     }
     else if (vertical->isOn())
     {
-        sy->brush().setStyle(Qt::VerPattern);
+        sy->setFillStyle(Qt::VerPattern);
     }
     else if (dense7->isOn())
     {
-        sy->brush().setStyle(Qt::Dense7Pattern);
+        sy->setFillStyle(Qt::Dense7Pattern);
     }
     else if (cross->isOn())
     {
-        sy->brush().setStyle(Qt::CrossPattern);
+        sy->setFillStyle(Qt::CrossPattern);
     }
     else if (dense2->isOn())
     {
-        sy->brush().setStyle(Qt::Dense2Pattern);
+        sy->setFillStyle(Qt::Dense2Pattern);
     }
     else if (bdiag->isOn())
     {
-        sy->brush().setStyle(Qt::BDiagPattern);
+        sy->setFillStyle(Qt::BDiagPattern);
     }
     else if (dense3->isOn())
     {
-        sy->brush().setStyle(Qt::Dense3Pattern);
+        sy->setFillStyle(Qt::Dense3Pattern);
     }
     else if (nopen->isOn())
     {
-        sy->brush().setStyle(Qt::NoBrush);
+        sy->setFillStyle(Qt::NoBrush);
     }
+}
 
+void QgsSiSyDialog::apply()
+{
+    QgsSymbol* sy = new QgsSymbol();
+    apply(sy);
 
     QgsRenderItem* ri = new QgsRenderItem(sy, "blabla", "blabla");
 
@@ -402,7 +399,9 @@ void QgsSiSyDialog::apply()
         p.drawLine(10, pix->height() - 25, 25, pix->height() - 10);
         break;
     case QGis::Point:
-        p.drawRect(20, pix->height() - 17, 5, 5);
+        //p.drawRect(20, pix->height() - 17, 5, 5);
+	QPixmap pm = sy->getPointSymbolAsPixmap();
+	p.drawPixmap ( (int) (17-pm.width()/2), (int) ((pix->height()-pm.height())/2), pm );
     }
 
     p.setPen(Qt::black);
@@ -419,6 +418,110 @@ void QgsSiSyDialog::apply()
     mVectorLayer->triggerRepaint();
 }
 
+void QgsSiSyDialog::set ( QgsSymbol *sy ) 
+{
+	// Set point symbol
+        for ( int i = 0; i < mMarkers.size(); i++ ) {
+	    if ( mMarkers[i] ==  sy->pointSymbolName() ) {
+	        mPointSymbolComboBox->setCurrentItem ( i );
+		break;
+	    }
+	}
+	mPointSizeSpinBox->setValue ( sy->pointSize() );
+	
+	outlinewidthspinbox->setValue(sy->pen().width());
+
+	//set line width 1 as minimum to avoid confusion between line width 0 and no pen line style
+	// ... but, drawLine is not correct with width > 0 -> until solved set to 0
+	outlinewidthspinbox->setMinValue(0);
+
+	lblFillColor->setPaletteBackgroundColor(sy->brush().color());
+
+	lblOutlineColor->setPaletteBackgroundColor(sy->pen().color());
+
+	//stylebutton->setName(QgsSymbologyUtils::penStyle2Char(sy->pen().style()));
+	//stylebutton->setPixmap(QgsSymbologyUtils::char2LinePixmap(stylebutton->name()));
+	//load the icons stored in QgsSymbologyUtils.cpp (to avoid redundancy)
+
+	QPen myPen = sy->pen();
+
+	switch ( myPen.style() )
+	{
+	    case Qt::NoPen :
+		pbnLineNoPen->setOn(true);
+		break;
+	    case Qt::DashLine :
+		pbnLineDash->setOn(true);
+		break;
+	    case Qt::DotLine :
+		pbnLineDot->setOn(true);
+		break;
+	    case Qt::DashDotLine :
+		pbnLineDashDot->setOn(true);
+		break;
+	    case Qt::DashDotDotLine :
+		pbnLineDashDotDot->setOn(true);
+		break;
+	    default :
+		pbnLineSolid->setOn(true); // default to solid
+		break;
+	}
+
+	QBrush myBrush = sy->brush();
+
+	switch ( myBrush.style() )
+	{
+	    case Qt::SolidPattern :
+		solid->setOn(true);
+		break;
+	    case Qt::HorPattern :
+		horizontal->setOn(true);
+		break;
+	    case Qt::VerPattern :
+		vertical->setOn(true);
+		break;
+	    case  Qt::CrossPattern :
+		cross->setOn(true);
+		break;
+	    case Qt::BDiagPattern :
+		bdiag->setOn(true);
+		break;
+	    case Qt::FDiagPattern :
+		fdiag->setOn(true);
+		break;
+	    case Qt::DiagCrossPattern :
+		diagcross->setOn(true);
+		break;
+	    case Qt::Dense1Pattern :
+		dense1->setOn(true);
+		break;
+	    case Qt::Dense2Pattern :
+		dense2->setOn(true);
+		break;
+	    case Qt::Dense3Pattern :
+		dense3->setOn(true);
+		break;
+	    case Qt::Dense4Pattern :
+		dense4->setOn(true);
+		break;
+	    case Qt::Dense5Pattern :
+		dense5->setOn(true);
+		break;
+	    case Qt::Dense6Pattern :
+		dense6->setOn(true);
+		break;
+	    case Qt::Dense7Pattern :
+		dense7->setOn(true);
+		break;
+	    case Qt::NoBrush :
+		nopen->setOn(true);
+		break;
+	    default :
+		solid->setOn(true);
+		break;
+	}
+}
+
 void QgsSiSyDialog::setOutlineColor(QColor& c)
 {
     lblOutlineColor->setPaletteBackgroundColor(c);
@@ -449,7 +552,7 @@ void QgsSiSyDialog::setFillColor(QColor& c)
 void QgsSiSyDialog::setFillStyle(Qt::BrushStyle fstyle)
 {
 #ifdef QGISDEBUG
-    qWarning("Setting fill style: "+QgsSymbologyUtils::brushStyle2QString(fstyle));
+    qWarning(("Setting fill style: "+QgsSymbologyUtils::brushStyle2QString(fstyle)).local8Bit());
 #endif
 
     // XXX use switch instead
