@@ -14,16 +14,23 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgssisydialog.h,v 1.14.2.1 2004/12/06 23:20:45 mhugent Exp $ */
+/* $Id: qgssisydialog.h,v 1.17 2005/03/18 17:23:57 rabla Exp $ */
 
 #ifndef QGSSISYDIALOG_H
 #define QGSSISYDIALOG_H
+
+#include <iostream>
+#include <vector>
+
 #ifdef WIN32
 #include "qgssisydialogbase.h"
 #else
 #include "qgssisydialogbase.uic.h"
 #endif
 
+class QString;
+
+class QgsSymbol;
 class QgsVectorLayer;
 
 /**QgsSiSyDialog is a dialog to set symbology for the legend type 'single symbol'*/
@@ -50,8 +57,12 @@ public:
 protected:
     QgsVectorLayer* mVectorLayer;
 public slots:
+    /* set from QgsSymbol */
+    void set(QgsSymbol *sy);
     /**applies the changes to the vector layer*/
     void apply();
+    /**applies the changes to the QgsSymbol */
+    void apply( QgsSymbol *sy);
     /**emits the signal settingsChanged()*/
     void resendSettingsChanged();
 
@@ -62,6 +73,9 @@ private:
     /**Default constructor is privat to not use is*/
     QgsSiSyDialog();
 
+    /** vector of marker names for combo items */
+    std::vector<QString> mMarkers;
+
 signals:
     void settingsChanged();
 };
