@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsvectorlayer.h,v 1.40.2.1 2004/12/02 06:32:40 gsherman Exp $ */
+/* $Id: qgsvectorlayer.h,v 1.69.2.2 2005/10/05 08:54:43 g_j_m Exp $ */
 
 #ifndef QGSVECTORLAYER_H
 #define QGSVECTORLAYER_H
@@ -22,10 +22,10 @@
 class QPainter;
 class QgsRect;
 class QLibrary;
-class QgsCoordinateTransform;
+class QgsMapToPixel;
 class OGRLayer;
 class OGRDataSource;
-class QgsDataProvider;
+class QgsData;
 class QgsRenderer;
 class QgsLegendItem;
 class QgsDlgVectorLayerProperties;
@@ -48,15 +48,15 @@ class QgsLabel;
 
 class QgsVectorLayer : public QgsMapLayer
 {
-    Q_OBJECT;
+  Q_OBJECT;
 
- public:
+public:
 
   //! Constructor
-    QgsVectorLayer(QString baseName = 0, QString path = 0, QString providerLib = 0);
+  QgsVectorLayer(QString baseName = 0, QString path = 0, QString providerLib = 0);
 
   //! Destructor
-   virtual ~QgsVectorLayer();
+  virtual ~QgsVectorLayer();
 
   //! Identify feature found within the search rectangle
   void identify(QgsRect *);
@@ -64,14 +64,20 @@ class QgsVectorLayer : public QgsMapLayer
   //! Select features found within the search rectangle
   void select(QgsRect * rect, bool lock);
 
+  //!Select not selected features and deselect selected ones
+  void invertSelection();
+
   //! Display the attribute table
   void table();
 
-  //! Set the primary display field to be used in the identify results dialog 
+  //! Resize and fill the attribute table
+  void fillTable(QgsAttributeTable* t);
+
+  //! Set the primary display field to be used in the identify results dialog
   void setDisplayField(QString fldName=0);
 
   //! Returns the primary display field name used in the identify results dialog
-  const QString displayField() const { return fieldIndex; }
+const QString displayField() const { return fieldIndex; }
 
   //! Initialize the context menu
   void initContextMenu(QgisApp * app);
@@ -89,20 +95,37 @@ class QgsVectorLayer : public QgsMapLayer
 
      @todo XXX should this return bool?  Throw exceptions?
   */
-  void setDataProvider( QString const & provider );
+  bool setDataProvider( QString const & provider );
+  
+  //! Setup the coordinate system tranformation for the layer
+  void setCoordinateSystem();
 
   QgsVectorDataProvider * getDataProvider();
 
-
+  /** \brief Query data provider to find out the WKT projection string for this layer. This implements the virtual method of the same name defined in QgsMapLayer*/
+  QString getProjectionWKT();
+  /*!
+   * Gets the SRID of the layer by querying the underlying data provider
+   * @return The SRID if the provider is able to provide it, otherwise 0
+   */
+  int getProjectionSrid();
   QgsLabel *label();
 
   QgsAttributeAction* actions() { return &mActions; }
 
-  public slots:
+ signals:
+  /**This signal is emitted when the layer leaves editing mode.
+     The purpose is to tell QgsMapCanvas to remove the lines of
+     (unfinished) features
+  @param norepaint true: there is no repaint at all. False: QgsMapCanvas
+  decides, if a repaint is necessary or not*/
+  void editingStopped(bool norepaint);
+
+public slots:
 
   void inOverview( bool );
 
-   /**Sets the 'tabledisplay' to 0 again*/
+  /**Sets the 'tabledisplay' to 0 again*/
   void invalidateTableDisplay();
   void select(int number);
   void removeSelection();
@@ -120,12 +143,12 @@ class QgsVectorLayer : public QgsMapLayer
   /**Sets m_propertiesDialog*/
   void setLayerProperties(QgsDlgVectorLayerProperties * properties);
   /**Returns point, line or polygon*/
-    QGis::VectorType vectorType();
+  QGis::VectorType vectorType();
   /**Returns a pointer to the properties dialog*/
   QgsDlgVectorLayerProperties *propertiesDialog();
   /** Return the context menu for the layer */
   QPopupMenu *contextMenu();
-    /**Returns the bounding box of the selected features. If there is no selection, the lower bounds are DBL_MAX and the upper bounds -DBL_MAX*/
+  /**Returns the bounding box of the selected features. If there is no selection, QgsRect(0,0,0,0) is returned*/
   virtual QgsRect bBoxOfSelected();
   //! Return the provider type for this layer
   QString providerType();
@@ -155,13 +178,13 @@ class QgsVectorLayer : public QgsMapLayer
   /* virtual */ bool writeXML_( QDomNode & layer_node, QDomDocument & doc );
 
 
-  /** 
+  /**
   * Get the first feature resulting from a select operation
   * @return QgsFeature
   */
   virtual QgsFeature * getFirstFeature(bool fetchAttributes=false) const;
 
-  /** 
+  /**
   * Get the next feature resulting from a select operation
   * @return QgsFeature
   */
@@ -182,7 +205,7 @@ class QgsVectorLayer : public QgsMapLayer
    * @return long containing number of features
    */
   virtual long featureCount() const;
-  
+
   /**
    * Update the feature count 
    * @return long containing the number of features in the datasource
@@ -227,11 +250,11 @@ class QgsVectorLayer : public QgsMapLayer
   /**Deletes the selected features
      @return true in case of success and false otherwise*/
   bool deleteSelectedFeatures();
-  
+
   /**Returns the default value for the attribute @c attr for the feature
      @c f. */
   QString getDefaultValue(const QString& attr, QgsFeature* f);
-  
+
   /**Set labels on */
   void setLabelOn( bool on );
 
@@ -262,20 +285,49 @@ class QgsVectorLayer : public QgsMapLayer
 
   //! Save as shapefile
   virtual void saveAsShapefile();
+
+  /**Snaps a point to the closest vertex if there is one within the snapping tolerance (mSnappingTolerance)
+     @param point the point which is set to the position of a vertex if there is one within the snapping tolerance.
+     If there is no point within this tolerance, point is left unchanged.
+     @param tolerance the snapping tolerance
+     @return true if the position of point has been changed and false else*/
+  bool snapPoint(QgsPoint& point, double tolerance);
+
+  /**Commits edited attributes. Depending on the feature id,
+     the changes are written to not commited features or redirected to
+     the data provider*/
+  bool commitAttributeChanges(const std::set<QString>& deleted,
+            const std::map<QString,QString>& added,
+            std::map<int,std::map<QString,QString> >& changed);
+
+  /** \brief Draws the layer using coordinate transformation
+   *  \param widthScale line width scale
+   *  \param symbolScale symbol scale
+   */
+  void draw(QPainter * p, QgsRect * viewExtent, QgsMapToPixel * cXf,  QPaintDevice * dst, double widthScale, double symbolScale, int oversampling = 1);
+
+  /** \brief Draws the layer labels using coordinate transformation
+   *  \param scale size scale, applied to all values in pixels
+   */
+  void drawLabels(QPainter * p, QgsRect * viewExtent, QgsMapToPixel * cXf,  QPaintDevice * dst, double scale);
+
+  
+ 
 protected:
   /**Pointer to the table display object if there is one, else a pointer to 0*/
-    QgsAttributeTableDisplay * tabledisplay;
+  QgsAttributeTableDisplay * tabledisplay;
   /**Vector holding the information which features are activated*/
   std::set<int> mSelected;
   std::set<int> mDeleted;
+  /**Features which are not commited*/
   std::list<QgsFeature*> mAddedFeatures;
-  /**Color to and fill the selected features*/
-  QColor selectionColor;
+  /**Changed attributes which are not commited  */
+  std::map<int,std::map<QString,QString> > mChangedAttributes;
   /**Renderer object which holds the information about how to display the features*/
   QgsRenderer *m_renderer;
   /**Label */
   QgsLabel *mLabel;
-  /**Display labels */ 
+  /**Display labels */
   bool mLabelOn;
   /**Dialog to set the properties*/
   QgsDlgVectorLayerProperties *m_propertiesDialog;
@@ -288,25 +340,52 @@ protected:
   /**Discards the edits*/
   bool rollBack();
 
-  protected slots:
+protected slots:
   void startEditing();
   void stopEditing();
 
-  void drawFeature(QPainter* p, QgsFeature* fet, QgsCoordinateTransform * cXf, QPicture* marker, double markerScaleFactor);
 
 private:                       // Private attributes
 
+  //! Draws features. May cause projections exceptions to be generated
+  // (i.e., code that calls this function needs to catch them
+  void drawFeature(QPainter* p, QgsFeature* fet, QgsMapToPixel * cXf, QPicture* marker, double markerScaleFactor, bool projectionsEnabledFlag );
+
   //! Draws the layer labels using coordinate transformation
-  void drawLabels(QPainter * p, QgsRect * viewExtent, QgsCoordinateTransform * cXf,  QPaintDevice * dst);
+  void drawLabels(QPainter * p, QgsRect * viewExtent, QgsMapToPixel * cXf,  QPaintDevice * dst);
 
-    /** tailor the right-click context menu with vector layer only stuff 
+  // Convenience function to transform the given point
+  void transformPoint(double& x, double& y, 
+      QgsMapToPixel* mtp, bool projectionsEnabledFlag);
+  
+  void transformPoints(std::vector<double>& x, std::vector<double>& y,
+      std::vector<double>& z,
+      QgsMapToPixel* mtp, bool projectionsEnabledFlag);
 
-      @note called by QgsMapLayer::initContextMenu();
-     */
-    void initContextMenu_(QgisApp *);
+  // Inverse projects the given rectangle if coordinate transforms are
+  // in effect. Alters the given rectangle
+  QgsRect inverseProjectRect(const QgsRect& r) const;
+
+  // Draw the linestring as given in the WKB format. Returns a pointer
+  // to the byte after the end of the line string binary data stream
+  // (WKB).
+  unsigned char* drawLineString(unsigned char* WKBlinestring, QPainter* p,
+      QgsMapToPixel* mtp, 
+      bool projectionsEnabledFlag);
+
+  // Draw the polygon as given in the WKB format. Returns a pointer to
+  // the byte after the end of the polygon binary data stream (WKB).
+  unsigned char* drawPolygon(unsigned char* WKBpolygon, QPainter* p, 
+      QgsMapToPixel* mtp, bool projectionsEnabledFlag);
+
+  /** tailor the right-click context menu with vector layer only stuff
+
+    @note called by QgsMapLayer::initContextMenu();
+   */
+  void initContextMenu_(QgisApp *);
 
   //! Draws the layer using coordinate transformation
-  void draw(QPainter * p, QgsRect * viewExtent, QgsCoordinateTransform * cXf,  QPaintDevice * dst);
+  void draw(QPainter * p, QgsRect * viewExtent, QgsMapToPixel * cXf,  QPaintDevice * dst);
   //! Pointer to data provider derived from the abastract base class QgsDataProvider
   QgsVectorDataProvider *dataProvider;
   //! index of the primary label field
@@ -317,11 +396,17 @@ private:                       // Private attributes
   bool valid;
   bool registered;
 
-  enum ENDIAN
+  /** constants for endian-ness
+    XDR is network, or big-endian, byte order
+    NDR is little-endian byte order
+  */
+  typedef enum ENDIAN
   {
-    NDR = 1,
-    XDR = 0
-  };
+    XDR = 0,
+    NDR = 1
+  }
+  endian_t;
+
   enum WKBTYPE
   {
     WKBPoint = 1,
@@ -332,7 +417,7 @@ private:                       // Private attributes
     WKBMultiPolygon
   };
 private:                       // Private methods
-  int endian();
+  endian_t endian();
   // pointer for loading the provider library
   QLibrary *myLib;
   //! Pointer to the identify results dialog
@@ -346,7 +431,7 @@ private:                       // Private methods
   int mMaximumScale;
   //! Flag to indicate if scale dependent rendering is in effect
   bool mScaleDependentRender;
-  
+
   /// vector layers are not copyable
   QgsVectorLayer( QgsVectorLayer const & rhs );
 
@@ -364,4 +449,35 @@ private:                       // Private methods
 
 };
 
+
+// Convenience function to transform the given point
+inline void QgsVectorLayer::transformPoint(double& x, 
+             double& y, 
+             QgsMapToPixel* mtp,
+             bool projectionsEnabledFlag)
+{
+  // transform the point
+  if (projectionsEnabledFlag)
+  {
+    double z = 0;
+    mCoordinateTransform->transformInPlace(x, y, z);
+  }
+
+  // transform from projected coordinate system to pixel 
+  // position on map canvas
+  mtp->transformInPlace(x, y);
+}
+
+inline void QgsVectorLayer::transformPoints(
+    std::vector<double>& x, std::vector<double>& y, std::vector<double>& z,
+    QgsMapToPixel* mtp, bool projectionsEnabledFlag)
+{
+  // transform the point
+  if (projectionsEnabledFlag)
+    mCoordinateTransform->transformInPlace(x, y, z);
+
+  // transform from projected coordinate system to pixel 
+  // position on map canvas
+  mtp->transformInPlace(x, y);
+}
 #endif
