@@ -1,8 +1,8 @@
 /****************************************************************************
 ** QgsVectorLayer meta object code from reading C++ file 'qgsvectorlayer.h'
 **
-** Created: Fri Dec 17 09:40:20 2004
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.3   edited Aug 5 16:40 $)
+** Created: Fri Nov 4 14:08:55 2005
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,7 +14,7 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.3. It"
+#error "This file was generated using the moc from 3.3.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -202,16 +202,48 @@ QMetaObject* QgsVectorLayer::staticMetaObject()
     };
     static const QUMethod slot_41 = {"isModified", 1, param_slot_41 };
     static const QUMethod slot_42 = {"saveAsShapefile", 0, 0 };
-    static const QUMethod slot_43 = {"startEditing", 0, 0 };
-    static const QUMethod slot_44 = {"stopEditing", 0, 0 };
+    static const QUParameter param_slot_43[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::Out },
+	{ "point", &static_QUType_ptr, "QgsPoint", QUParameter::InOut },
+	{ "tolerance", &static_QUType_double, 0, QUParameter::In }
+    };
+    static const QUMethod slot_43 = {"snapPoint", 3, param_slot_43 };
+    static const QUParameter param_slot_44[] = {
+	{ 0, &static_QUType_bool, 0, QUParameter::Out },
+	{ "deleted", &static_QUType_ptr, "std::set<QString>", QUParameter::In },
+	{ "added", &static_QUType_ptr, "std::map<QString,QString>", QUParameter::In },
+	{ "changed", &static_QUType_ptr, "std::map<int,std::map<QString,QString>>", QUParameter::InOut }
+    };
+    static const QUMethod slot_44 = {"commitAttributeChanges", 4, param_slot_44 };
     static const QUParameter param_slot_45[] = {
 	{ "p", &static_QUType_ptr, "QPainter", QUParameter::In },
-	{ "fet", &static_QUType_ptr, "QgsFeature", QUParameter::In },
-	{ "cXf", &static_QUType_ptr, "QgsCoordinateTransform", QUParameter::In },
-	{ "marker", &static_QUType_ptr, "QPicture", QUParameter::In },
-	{ "markerScaleFactor", &static_QUType_double, 0, QUParameter::In }
+	{ "viewExtent", &static_QUType_ptr, "QgsRect", QUParameter::In },
+	{ "cXf", &static_QUType_ptr, "QgsMapToPixel", QUParameter::In },
+	{ "dst", &static_QUType_ptr, "QPaintDevice", QUParameter::In },
+	{ "widthScale", &static_QUType_double, 0, QUParameter::In },
+	{ "symbolScale", &static_QUType_double, 0, QUParameter::In }
     };
-    static const QUMethod slot_45 = {"drawFeature", 5, param_slot_45 };
+    static const QUMethod slot_45 = {"draw", 6, param_slot_45 };
+    static const QUParameter param_slot_46[] = {
+	{ "p", &static_QUType_ptr, "QPainter", QUParameter::In },
+	{ "viewExtent", &static_QUType_ptr, "QgsRect", QUParameter::In },
+	{ "cXf", &static_QUType_ptr, "QgsMapToPixel", QUParameter::In },
+	{ "dst", &static_QUType_ptr, "QPaintDevice", QUParameter::In },
+	{ "widthScale", &static_QUType_double, 0, QUParameter::In },
+	{ "symbolScale", &static_QUType_double, 0, QUParameter::In },
+	{ "oversampling", &static_QUType_int, 0, QUParameter::In }
+    };
+    static const QUMethod slot_46 = {"draw", 7, param_slot_46 };
+    static const QUParameter param_slot_47[] = {
+	{ "p", &static_QUType_ptr, "QPainter", QUParameter::In },
+	{ "viewExtent", &static_QUType_ptr, "QgsRect", QUParameter::In },
+	{ "cXf", &static_QUType_ptr, "QgsMapToPixel", QUParameter::In },
+	{ "dst", &static_QUType_ptr, "QPaintDevice", QUParameter::In },
+	{ "scale", &static_QUType_double, 0, QUParameter::In }
+    };
+    static const QUMethod slot_47 = {"drawLabels", 5, param_slot_47 };
+    static const QUMethod slot_48 = {"startEditing", 0, 0 };
+    static const QUMethod slot_49 = {"stopEditing", 0, 0 };
     static const QMetaData slot_tbl[] = {
 	{ "inOverview(bool)", &slot_0, QMetaData::Public },
 	{ "invalidateTableDisplay()", &slot_1, QMetaData::Public },
@@ -256,14 +288,25 @@ QMetaObject* QgsVectorLayer::staticMetaObject()
 	{ "isEditable()", &slot_40, QMetaData::Public },
 	{ "isModified()", &slot_41, QMetaData::Public },
 	{ "saveAsShapefile()", &slot_42, QMetaData::Public },
-	{ "startEditing()", &slot_43, QMetaData::Protected },
-	{ "stopEditing()", &slot_44, QMetaData::Protected },
-	{ "drawFeature(QPainter*,QgsFeature*,QgsCoordinateTransform*,QPicture*,double)", &slot_45, QMetaData::Protected }
+	{ "snapPoint(QgsPoint&,double)", &slot_43, QMetaData::Public },
+	{ "commitAttributeChanges(const std::set<QString>&,const std::map<QString,QString>&,std::map<int,std::map<QString,QString>>&)", &slot_44, QMetaData::Public },
+	{ "draw(QPainter*,QgsRect*,QgsMapToPixel*,QPaintDevice*,double,double)", &slot_45, QMetaData::Public },
+	{ "draw(QPainter*,QgsRect*,QgsMapToPixel*,QPaintDevice*,double,double,int)", &slot_46, QMetaData::Public },
+	{ "drawLabels(QPainter*,QgsRect*,QgsMapToPixel*,QPaintDevice*,double)", &slot_47, QMetaData::Public },
+	{ "startEditing()", &slot_48, QMetaData::Protected },
+	{ "stopEditing()", &slot_49, QMetaData::Protected }
+    };
+    static const QUParameter param_signal_0[] = {
+	{ "norepaint", &static_QUType_bool, 0, QUParameter::In }
+    };
+    static const QUMethod signal_0 = {"editingStopped", 1, param_signal_0 };
+    static const QMetaData signal_tbl[] = {
+	{ "editingStopped(bool)", &signal_0, QMetaData::Public }
     };
     metaObj = QMetaObject::new_metaobject(
 	"QgsVectorLayer", parentObject,
-	slot_tbl, 46,
-	0, 0,
+	slot_tbl, 50,
+	signal_tbl, 1,
 #ifndef QT_NO_PROPERTIES
 	0, 0,
 	0, 0,
@@ -280,6 +323,12 @@ void* QgsVectorLayer::qt_cast( const char* clname )
     return QgsMapLayer::qt_cast( clname );
 }
 
+// SIGNAL editingStopped
+void QgsVectorLayer::editingStopped( bool t0 )
+{
+    activate_signal_bool( staticMetaObject()->signalOffset() + 0, t0 );
+}
+
 bool QgsVectorLayer::qt_invoke( int _id, QUObject* _o )
 {
     switch ( _id - staticMetaObject()->slotOffset() ) {
@@ -326,9 +375,13 @@ bool QgsVectorLayer::qt_invoke( int _id, QUObject* _o )
     case 40: static_QUType_bool.set(_o,isEditable()); break;
     case 41: static_QUType_bool.set(_o,isModified()); break;
     case 42: saveAsShapefile(); break;
-    case 43: startEditing(); break;
-    case 44: stopEditing(); break;
-    case 45: drawFeature((QPainter*)static_QUType_ptr.get(_o+1),(QgsFeature*)static_QUType_ptr.get(_o+2),(QgsCoordinateTransform*)static_QUType_ptr.get(_o+3),(QPicture*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5)); break;
+    case 43: static_QUType_bool.set(_o,snapPoint((QgsPoint&)*((QgsPoint*)static_QUType_ptr.get(_o+1)),(double)static_QUType_double.get(_o+2))); break;
+    case 44: static_QUType_bool.set(_o,commitAttributeChanges((const std::set<QString>&)*((const std::set<QString>*)static_QUType_ptr.get(_o+1)),(const std::map<QString,QString>&)*((const std::map<QString,QString>*)static_QUType_ptr.get(_o+2)),(std::map<int,std::map<QString,QString> >&)*((std::map<int,std::map<QString,QString> >*)static_QUType_ptr.get(_o+3)))); break;
+    case 45: draw((QPainter*)static_QUType_ptr.get(_o+1),(QgsRect*)static_QUType_ptr.get(_o+2),(QgsMapToPixel*)static_QUType_ptr.get(_o+3),(QPaintDevice*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5),(double)static_QUType_double.get(_o+6)); break;
+    case 46: draw((QPainter*)static_QUType_ptr.get(_o+1),(QgsRect*)static_QUType_ptr.get(_o+2),(QgsMapToPixel*)static_QUType_ptr.get(_o+3),(QPaintDevice*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5),(double)static_QUType_double.get(_o+6),(int)static_QUType_int.get(_o+7)); break;
+    case 47: drawLabels((QPainter*)static_QUType_ptr.get(_o+1),(QgsRect*)static_QUType_ptr.get(_o+2),(QgsMapToPixel*)static_QUType_ptr.get(_o+3),(QPaintDevice*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5)); break;
+    case 48: startEditing(); break;
+    case 49: stopEditing(); break;
     default:
 	return QgsMapLayer::qt_invoke( _id, _o );
     }
@@ -337,7 +390,12 @@ bool QgsVectorLayer::qt_invoke( int _id, QUObject* _o )
 
 bool QgsVectorLayer::qt_emit( int _id, QUObject* _o )
 {
-    return QgsMapLayer::qt_emit(_id,_o);
+    switch ( _id - staticMetaObject()->signalOffset() ) {
+    case 0: editingStopped((bool)static_QUType_bool.get(_o+1)); break;
+    default:
+	return QgsMapLayer::qt_emit(_id,_o);
+    }
+    return TRUE;
 }
 #ifndef QT_NO_PROPERTIES
 
