@@ -14,35 +14,48 @@
  *   (at your option) any later version.                                   *
  *    Based on an example provided by Trolltech                                                                     *
  ***************************************************************************/
-/* $Id: splashscreen.cpp,v 1.16.2.1 2004/12/03 00:01:24 timlinux Exp $ */
+/* $Id: splashscreen.cpp,v 1.19 2005/05/22 10:51:36 timlinux Exp $ */
 #include <qapplication.h>
 #include <qpainter.h>
 #include <qpixmap.h>
 #include "splashscreen.h"
 #include "qfont.h"
 #include "qgis.h"
+#include "qbitmap.h"
 #if defined(WIN32) || defined(Q_OS_MACX)
 QString PKGDATAPATH = qApp->applicationDirPath() + "/share/qgis";
 #endif
-#define STATUS_TEXT_X 10
-#define STATUS_TEXT_Y 10
+#define STATUS_TEXT_X 90
+#define STATUS_TEXT_Y 30
 SplashScreen::SplashScreen():QWidget(0, 0, WStyle_Customize | WStyle_Splash)
 {
-  splashImage.load(QString(PKGDATAPATH) + QString("/images/splash/splash.png"));
-  setErasePixmap(splashImage);
+  //set up masking
+  splashImage.load(QString(PKGDATAPATH) + QString("/images/splash/splash.png"), 0, Qt::ThresholdDither |   Qt::AvoidDither );
   resize(splashImage.size());
+  //
+  // NOTES! the mask must be a 1 BIT IMAGE or it wont work!
+  //
+  QPixmap myMaskPixmap( 564, 300, -1, QPixmap::BestOptim );  
+  myMaskPixmap.load( QString(PKGDATAPATH) + QString("/images/splash/splash_mask.png"), 0, Qt::ThresholdDither |   Qt::ThresholdAlphaDither | Qt::AvoidDither );
+  setBackgroundPixmap(splashImage);
+  setMask( myMaskPixmap.createHeuristicMask() );
+
+
+  setErasePixmap(splashImage);
+  
   QRect scr = QApplication::desktop()->screenGeometry();
   move(scr.center() - rect().center());
 
   QPainter painter(&splashImage);
-  painter.setPen(Qt::red);
-  QFont myQFont("arial", 16, QFont::Bold);
+  painter.setPen(Qt::black);
+  QFont myQFont("arial", 18, QFont::Bold);
   painter.setFont(myQFont);
 
-  QString myCaption = tr("Quantum GIS - ");
-  myCaption += QString("%1 ('%2')").arg(QGis::qgisVersion).arg(QGis::qgisReleaseName);
+  QString myCaption = tr("Version ");
+  // myCaption += QString("%1 ('%2')").arg(QGis::qgisVersion).arg(QGis::qgisReleaseName);
+  myCaption += QString("%1").arg(QGis::qgisVersion);
 
-  painter.drawText(STATUS_TEXT_X, 25, myCaption);
+  painter.drawText(150, 240, myCaption);
   repaint();
 
   show();
@@ -76,7 +89,7 @@ void SplashScreen::setStatus(const QString & message, int alignment, const QColo
   QPixmap textPix = splashImage;
   QPainter painter(&textPix, this);
   painter.setPen(color);
-  QFont myQFont("arial", 12, QFont::Bold);
+  QFont myQFont("arial", 10, QFont::Bold);
   painter.setFont(myQFont);
   painter.drawText(STATUS_TEXT_X, textPix.height() - STATUS_TEXT_Y, message);
   setErasePixmap(textPix);
