@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *  Based on an example by Trolltech                                                                       *
  ***************************************************************************/
-/* $Id: splashscreen.h,v 1.4 2004/10/16 21:59:14 gsherman Exp $ */
+/* $Id: splashscreen.h,v 1.5 2005/05/22 10:51:37 timlinux Exp $ */
 
 #ifndef SPLASHSCREEN_H
 #define SPLASHSCREEN_H
@@ -33,7 +33,7 @@ class SplashScreen : public QWidget
 public:
   SplashScreen();
 
-  void setStatus( const QString &message, int alignment = AlignLeft, const QColor &color = black );
+  void setStatus( const QString &message, int alignment = AlignLeft, const QColor &color = Qt::white );
   void finish( QWidget *mainWin );
   void repaint();
 
